@@ -2,16 +2,18 @@
 
 namespace Sabre\DAV\Exception;
 
+use Sabre\DAV;
+
 /**
  * InsufficientStorage
  *
  * This Exception can be thrown, when for example a harddisk is full or a quota is exceeded
  *
- * @copyright Copyright (C) 2007-2015 fruux GmbH (https://fruux.com/).
+ * @copyright Copyright (C) fruux GmbH (https://fruux.com/)
  * @author Evert Pot (http://evertpot.com/)
  * @license http://sabre.io/license/ Modified BSD License
  */
-class InsufficientStorage extends \Sabre\DAV\Exception {
+class InsufficientStorage extends DAV\Exception {
 
     /**
      * Returns the HTTP statuscode for this exception
