@@ -5,10 +5,12 @@ OC.L10N.register(
     "Personal" : "Personīgi",
     "Grant access" : "Piešķirt pieeju",
     "Access granted" : "Piešķirta pieeja",
+    "Enable encryption" : "Ieslēgt šifrēšanu",
     "Saved" : "Saglabāts",
-    "None" : "Nav",
     "Username" : "Lietotājvārds",
     "Password" : "Parole",
+    "Save" : "Saglabāt",
+    "None" : "Nav",
     "Port" : "Ports",
     "WebDAV" : "WebDAV",
     "URL" : "URL",
@@ -20,8 +22,7 @@ OC.L10N.register(
     "External Storage" : "Ārējā krātuve",
     "Folder name" : "Mapes nosaukums",
     "Configuration" : "Konfigurācija",
-    "Delete" : "Dzēst",
     "Add storage" : "Pievienot krātuvi",
-    "Enable User External Storage" : "Aktivēt lietotāja ārējo krātuvi"
+    "Delete" : "Dzēst"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
