@@ -1,6 +1,6 @@
 OC.L10N.register(
     "files_odfviewer",
     {
-    "Close" : "Mbyll"
+    "Close" : "Mbylle"
 },
 "nplurals=2; plural=(n != 1);");
