@@ -5,8 +5,10 @@ OC.L10N.register(
     "Restore" : "Վերականգնել",
     "Delete" : "Ջնջել",
     "Delete permanently" : "Ջնջել ընդմիշտ",
+    "Error" : "Սխալ",
     "No deleted files" : "Ջնջված ֆայլեր չկան",
     "Select all" : "Նշել բոլորը",
-    "Name" : "Անուն"
+    "Name" : "Անուն",
+    "Deleted" : "Ջնջված"
 },
 "nplurals=2; plural=(n != 1);");
