@@ -7,18 +7,17 @@
  * @author Georg Ehrke <georg@owncloud.com>
  * @author Jörn Friedrich Dreyer <jfd@butonic.de>
  * @author Lukas Reschke <lukas@owncloud.com>
- * @author Martin Mattel <martin.mattel@diemattels.at>
  * @author Morris Jobke <hey@morrisjobke.de>
  * @author Qingping Hou <dave2008713@gmail.com>
  * @author Robin Appelman <icewind@owncloud.com>
- * @author Robin McCorkell <rmccorkell@karoshi.org.uk>
- * @author Roeland Jago Douma <roeland@famdouma.nl>
+ * @author Robin McCorkell <robin@mccorkell.me.uk>
+ * @author Roeland Jago Douma <rullzer@owncloud.com>
  * @author Sjors van der Pluijm <sjors@desjors.nl>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Victor Dubiniuk <dubiniuk@owncloud.com>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2015, ownCloud, Inc.
+ * @copyright Copyright (c) 2016, ownCloud, Inc.
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -41,6 +40,8 @@ use OC\Files\Filesystem;
 use OC\Files\View;
 use OCA\Files_Trashbin\AppInfo\Application;
 use OCA\Files_Trashbin\Command\Expire;
+use OCP\Files\NotFoundException;
+use OCP\User;
 
 class Trashbin {
 
@@ -61,18 +62,41 @@ class Trashbin {
 	 * @param array $params
 	 */
 	public static function ensureFileScannedHook($params) {
-		self::getUidAndFilename($params['path']);
+		try {
+			self::getUidAndFilename($params['path']);
+		} catch (NotFoundException $e) {
+			// nothing to scan for non existing files
+		}
 	}
 
+	/**
+	 * get the UID of the owner of the file and the path to the file relative to
+	 * owners files folder
+	 *
+	 * @param string $filename
+	 * @return array
+	 * @throws \OC\User\NoUserException
+	 */
 	public static function getUidAndFilename($filename) {
-		$uid = \OC\Files\Filesystem::getOwner($filename);
-		\OC\Files\Filesystem::initMountPoints($uid);
-		if ($uid != \OCP\User::getUser()) {
-			$info = \OC\Files\Filesystem::getFileInfo($filename);
-			$ownerView = new \OC\Files\View('/' . $uid . '/files');
-			$filename = $ownerView->getPath($info['fileid']);
+		$uid = Filesystem::getOwner($filename);
+		$userManager = \OC::$server->getUserManager();
+		// if the user with the UID doesn't exists, e.g. because the UID points
+		// to a remote user with a federated cloud ID we use the current logged-in
+		// user. We need a valid local user to move the file to the right trash bin
+		if (!$userManager->userExists($uid)) {
+			$uid = User::getUser();
 		}
-		return array($uid, $filename);
+		Filesystem::initMountPoints($uid);
+		if ($uid != User::getUser()) {
+			$info = Filesystem::getFileInfo($filename);
+			$ownerView = new View('/' . $uid . '/files');
+			try {
+				$filename = $ownerView->getPath($info['fileid']);
+			} catch (NotFoundException $e) {
+				$filename = null;
+			}
+		}
+		return [$uid, $filename];
 	}
 
 	/**
@@ -116,7 +140,7 @@ class Trashbin {
 	}
 
 	private static function setUpTrash($user) {
-		$view = new \OC\Files\View('/' . $user);
+		$view = new View('/' . $user);
 		if (!$view->is_dir('files_trashbin')) {
 			$view->mkdir('files_trashbin');
 		}
@@ -137,7 +161,7 @@ class Trashbin {
 	 *
 	 * @param string $sourcePath
 	 * @param string $owner
-	 * @param $targetPath
+	 * @param string $targetPath
 	 * @param $user
 	 * @param integer $timestamp
 	 */
@@ -149,7 +173,7 @@ class Trashbin {
 
 		$sourceFilename = basename($sourcePath);
 
-		$view = new \OC\Files\View('/');
+		$view = new View('/');
 
 		$target = $user . '/files_trashbin/files/' . $targetFilename . '.d' . $timestamp;
 		$source = $owner . '/files_trashbin/files/' . $sourceFilename . '.d' . $timestamp;
@@ -176,12 +200,11 @@ class Trashbin {
 		// get the user for which the filesystem is setup
 		$root = Filesystem::getRoot();
 		list(, $user) = explode('/', $root);
-		$size = 0;
 		list($owner, $ownerPath) = self::getUidAndFilename($file_path);
 
-		$ownerView = new \OC\Files\View('/' . $owner);
+		$ownerView = new View('/' . $owner);
 		// file has been deleted in between
-		if (!$ownerView->file_exists('/files/' . $ownerPath)) {
+		if (is_null($ownerPath) || $ownerPath === '' || !$ownerView->file_exists('/files/' . $ownerPath)) {
 			return true;
 		}
 
@@ -197,8 +220,6 @@ class Trashbin {
 		$location = $path_parts['dirname'];
 		$timestamp = time();
 
-		$userTrashSize = self::getTrashbinSize($user);
-
 		// disable proxy to prevent recursive calls
 		$trashPath = '/files_trashbin/files/' . $filename . '.d' . $timestamp;
 
@@ -207,13 +228,13 @@ class Trashbin {
 		/** @var \OC\Files\Storage\Storage $sourceStorage */
 		list($sourceStorage, $sourceInternalPath) = $ownerView->resolvePath('/files/' . $ownerPath);
 		try {
-			$sizeOfAddedFiles = $sourceStorage->filesize($sourceInternalPath);
+			$moveSuccessful = true;
 			if ($trashStorage->file_exists($trashInternalPath)) {
 				$trashStorage->unlink($trashInternalPath);
 			}
 			$trashStorage->moveFromStorage($sourceStorage, $sourceInternalPath, $trashInternalPath);
 		} catch (\OCA\Files_Trashbin\Exceptions\CopyRecursiveException $e) {
-			$sizeOfAddedFiles = false;
+			$moveSuccessful = false;
 			if ($trashStorage->file_exists($trashInternalPath)) {
 				$trashStorage->unlink($trashInternalPath);
 			}
@@ -225,19 +246,18 @@ class Trashbin {
 			return false;
 		}
 
-		$ownerView->getUpdater()->rename('/files/' . $ownerPath, $trashPath);
+		$trashStorage->getUpdater()->renameFromStorage($sourceStorage, $sourceInternalPath, $trashInternalPath);
 
-		if ($sizeOfAddedFiles !== false) {
-			$size = $sizeOfAddedFiles;
+		if ($moveSuccessful) {
 			$query = \OC_DB::prepare("INSERT INTO `*PREFIX*files_trash` (`id`,`timestamp`,`location`,`user`) VALUES (?,?,?,?)");
 			$result = $query->execute(array($filename, $timestamp, $location, $owner));
 			if (!$result) {
 				\OCP\Util::writeLog('files_trashbin', 'trash bin database couldn\'t be updated', \OCP\Util::ERROR);
 			}
-			\OCP\Util::emitHook('\OCA\Files_Trashbin\Trashbin', 'post_moveToTrash', array('filePath' => \OC\Files\Filesystem::normalizePath($file_path),
-				'trashPath' => \OC\Files\Filesystem::normalizePath($filename . '.d' . $timestamp)));
+			\OCP\Util::emitHook('\OCA\Files_Trashbin\Trashbin', 'post_moveToTrash', array('filePath' => Filesystem::normalizePath($file_path),
+				'trashPath' => Filesystem::normalizePath($filename . '.d' . $timestamp)));
 
-			$size += self::retainVersions($filename, $owner, $ownerPath, $timestamp);
+			self::retainVersions($filename, $owner, $ownerPath, $timestamp);
 
 			// if owner !== user we need to also add a copy to the owners trash
 			if ($user !== $owner) {
@@ -245,17 +265,14 @@ class Trashbin {
 			}
 		}
 
-		$userTrashSize += $size;
-		self::scheduleExpire($userTrashSize, $user);
+		self::scheduleExpire($user);
 
 		// if owner !== user we also need to update the owners trash size
 		if ($owner !== $user) {
-			$ownerTrashSize = self::getTrashbinSize($owner);
-			$ownerTrashSize += $size;
-			self::scheduleExpire($ownerTrashSize, $owner);
+			self::scheduleExpire($owner);
 		}
 
-		return ($sizeOfAddedFiles === false) ? false : true;
+		return $moveSuccessful;
 	}
 
 	/**
@@ -265,18 +282,14 @@ class Trashbin {
 	 * @param string $owner owner user id
 	 * @param string $ownerPath path relative to the owner's home storage
 	 * @param integer $timestamp when the file was deleted
-	 *
-	 * @return int size of stored versions
 	 */
 	private static function retainVersions($filename, $owner, $ownerPath, $timestamp) {
-		$size = 0;
 		if (\OCP\App::isEnabled('files_versions') && !empty($ownerPath)) {
 
-			$user = \OCP\User::getUser();
-			$rootView = new \OC\Files\View('/');
+			$user = User::getUser();
+			$rootView = new View('/');
 
 			if ($rootView->is_dir($owner . '/files_versions/' . $ownerPath)) {
-				$size += self::calculateSize(new \OC\Files\View('/' . $owner . '/files_versions/' . $ownerPath));
 				if ($owner !== $user) {
 					self::copy_recursive($owner . '/files_versions/' . $ownerPath, $owner . '/files_trashbin/versions/' . basename($ownerPath) . '.d' . $timestamp, $rootView);
 				}
@@ -284,7 +297,6 @@ class Trashbin {
 			} else if ($versions = \OCA\Files_Versions\Storage::getVersions($owner, $ownerPath)) {
 
 				foreach ($versions as $v) {
-					$size += $rootView->filesize($owner . '/files_versions/' . $v['path'] . '.v' . $v['version']);
 					if ($owner !== $user) {
 						self::copy($rootView, $owner . '/files_versions' . $v['path'] . '.v' . $v['version'], $owner . '/files_trashbin/versions/' . $v['name'] . '.v' . $v['version'] . '.d' . $timestamp);
 					}
@@ -292,8 +304,6 @@ class Trashbin {
 				}
 			}
 		}
-
-		return $size;
 	}
 
 	/**
@@ -313,7 +323,7 @@ class Trashbin {
 
 		$result = $targetStorage->moveFromStorage($sourceStorage, $sourceInternalPath, $targetInternalPath);
 		if ($result) {
-			$view->getUpdater()->rename($source, $target);
+			$targetStorage->getUpdater()->renameFromStorage($sourceStorage, $sourceInternalPath, $targetInternalPath);
 		}
 		return $result;
 	}
@@ -335,7 +345,7 @@ class Trashbin {
 
 		$result = $targetStorage->copyFromStorage($sourceStorage, $sourceInternalPath, $targetInternalPath);
 		if ($result) {
-			$view->getUpdater()->update($target);
+			$targetStorage->getUpdater()->update($targetInternalPath);
 		}
 		return $result;
 	}
@@ -351,8 +361,8 @@ class Trashbin {
 	 * @return bool true on success, false otherwise
 	 */
 	public static function restore($file, $filename, $timestamp) {
-		$user = \OCP\User::getUser();
-		$view = new \OC\Files\View('/' . $user);
+		$user = User::getUser();
+		$view = new View('/' . $user);
 
 		$location = '';
 		if ($timestamp) {
@@ -373,8 +383,8 @@ class Trashbin {
 		// we need a  extension in case a file/dir with the same name already exists
 		$uniqueFilename = self::getUniqueFilename($location, $filename, $view);
 
-		$source = \OC\Files\Filesystem::normalizePath('files_trashbin/files/' . $file);
-		$target = \OC\Files\Filesystem::normalizePath('files/' . $location . '/' . $uniqueFilename);
+		$source = Filesystem::normalizePath('files_trashbin/files/' . $file);
+		$target = Filesystem::normalizePath('files/' . $location . '/' . $uniqueFilename);
 		if (!$view->file_exists($source)) {
 			return false;
 		}
@@ -389,8 +399,8 @@ class Trashbin {
 			$view->chroot('/' . $user . '/files');
 			$view->touch('/' . $location . '/' . $uniqueFilename, $mtime);
 			$view->chroot($fakeRoot);
-			\OCP\Util::emitHook('\OCA\Files_Trashbin\Trashbin', 'post_restore', array('filePath' => \OC\Files\Filesystem::normalizePath('/' . $location . '/' . $uniqueFilename),
-				'trashPath' => \OC\Files\Filesystem::normalizePath($file)));
+			\OCP\Util::emitHook('\OCA\Files_Trashbin\Trashbin', 'post_restore', array('filePath' => Filesystem::normalizePath('/' . $location . '/' . $uniqueFilename),
+				'trashPath' => Filesystem::normalizePath($file)));
 
 			self::restoreVersions($view, $file, $filename, $uniqueFilename, $location, $timestamp);
 
@@ -408,22 +418,22 @@ class Trashbin {
 	/**
 	 * restore versions from trash bin
 	 *
-	 * @param \OC\Files\View $view file view
+	 * @param View $view file view
 	 * @param string $file complete path to file
 	 * @param string $filename name of file once it was deleted
 	 * @param string $uniqueFilename new file name to restore the file without overwriting existing files
 	 * @param string $location location if file
 	 * @param int $timestamp deletion time
-	 * @return bool
+	 * @return false|null
 	 */
-	private static function restoreVersions(\OC\Files\View $view, $file, $filename, $uniqueFilename, $location, $timestamp) {
+	private static function restoreVersions(View $view, $file, $filename, $uniqueFilename, $location, $timestamp) {
 
 		if (\OCP\App::isEnabled('files_versions')) {
 
-			$user = \OCP\User::getUser();
-			$rootView = new \OC\Files\View('/');
+			$user = User::getUser();
+			$rootView = new View('/');
 
-			$target = \OC\Files\Filesystem::normalizePath('/' . $location . '/' . $uniqueFilename);
+			$target = Filesystem::normalizePath('/' . $location . '/' . $uniqueFilename);
 
 			list($owner, $ownerPath) = self::getUidAndFilename($target);
 
@@ -439,7 +449,7 @@ class Trashbin {
 			}
 
 			if ($view->is_dir('/files_trashbin/versions/' . $file)) {
-				$rootView->rename(\OC\Files\Filesystem::normalizePath($user . '/files_trashbin/versions/' . $file), \OC\Files\Filesystem::normalizePath($owner . '/files_versions/' . $ownerPath));
+				$rootView->rename(Filesystem::normalizePath($user . '/files_trashbin/versions/' . $file), Filesystem::normalizePath($owner . '/files_versions/' . $ownerPath));
 			} else if ($versions = self::getVersionsFromTrash($versionedFile, $timestamp, $user)) {
 				foreach ($versions as $v) {
 					if ($timestamp) {
@@ -456,8 +466,8 @@ class Trashbin {
 	 * delete all files from the trash
 	 */
 	public static function deleteAll() {
-		$user = \OCP\User::getUser();
-		$view = new \OC\Files\View('/' . $user);
+		$user = User::getUser();
+		$view = new View('/' . $user);
 		$view->deleteAll('files_trashbin');
 		$query = \OC_DB::prepare('DELETE FROM `*PREFIX*files_trash` WHERE `user`=?');
 		$query->execute(array($user));
@@ -477,7 +487,7 @@ class Trashbin {
 	 * @return int size of deleted files
 	 */
 	public static function delete($filename, $user, $timestamp = null) {
-		$view = new \OC\Files\View('/' . $user);
+		$view = new View('/' . $user);
 		$size = 0;
 
 		if ($timestamp) {
@@ -491,7 +501,7 @@ class Trashbin {
 		$size += self::deleteVersions($view, $file, $filename, $timestamp, $user);
 
 		if ($view->is_dir('/files_trashbin/files/' . $file)) {
-			$size += self::calculateSize(new \OC\Files\View('/' . $user . '/files_trashbin/files/' . $file));
+			$size += self::calculateSize(new View('/' . $user . '/files_trashbin/files/' . $file));
 		} else {
 			$size += $view->filesize('/files_trashbin/files/' . $file);
 		}
@@ -503,17 +513,18 @@ class Trashbin {
 	}
 
 	/**
-	 * @param \OC\Files\View $view
-	 * @param $file
-	 * @param $filename
-	 * @param $timestamp
+	 * @param View $view
+	 * @param string $file
+	 * @param string $filename
+	 * @param integer|null $timestamp
+	 * @param string $user
 	 * @return int
 	 */
-	private static function deleteVersions(\OC\Files\View $view, $file, $filename, $timestamp, $user) {
+	private static function deleteVersions(View $view, $file, $filename, $timestamp, $user) {
 		$size = 0;
 		if (\OCP\App::isEnabled('files_versions')) {
 			if ($view->is_dir('files_trashbin/versions/' . $file)) {
-				$size += self::calculateSize(new \OC\Files\view('/' . $user . '/files_trashbin/versions/' . $file));
+				$size += self::calculateSize(new View('/' . $user . '/files_trashbin/versions/' . $file));
 				$view->unlink('files_trashbin/versions/' . $file);
 			} else if ($versions = self::getVersionsFromTrash($filename, $timestamp, $user)) {
 				foreach ($versions as $v) {
@@ -538,8 +549,8 @@ class Trashbin {
 	 * @return bool true if file exists, otherwise false
 	 */
 	public static function file_exists($filename, $timestamp = null) {
-		$user = \OCP\User::getUser();
-		$view = new \OC\Files\View('/' . $user);
+		$user = User::getUser();
+		$view = new View('/' . $user);
 
 		if ($timestamp) {
 			$filename = $filename . '.d' . $timestamp;
@@ -547,7 +558,7 @@ class Trashbin {
 			$filename = $filename;
 		}
 
-		$target = \OC\Files\Filesystem::normalizePath('files_trashbin/files/' . $filename);
+		$target = Filesystem::normalizePath('files_trashbin/files/' . $filename);
 		return $view->file_exists($target);
 	}
 
@@ -570,16 +581,14 @@ class Trashbin {
 	 * @return int available free space for trash bin
 	 */
 	private static function calculateFreeSpace($trashbinSize, $user) {
-		$config = \OC::$server->getConfig();
-
 		$softQuota = true;
-		$quota = $config->getUserValue($user, 'files', 'quota', null);
-		$view = new \OC\Files\View('/' . $user);
-		if ($quota === null || $quota === 'default') {
-			$quota = $config->getAppValue('files', 'default_quota', null);
+		$userObject = \OC::$server->getUserManager()->get($user);
+		if(is_null($userObject)) {
+			return 0;
 		}
+		$quota = $userObject->getQuota();
 		if ($quota === null || $quota === 'none') {
-			$quota = \OC\Files\Filesystem::free_space('/');
+			$quota = Filesystem::free_space('/');
 			$softQuota = false;
 			// inf or unknown free space
 			if ($quota < 0) {
@@ -592,8 +601,11 @@ class Trashbin {
 		// calculate available space for trash bin
 		// subtract size of files and current trash bin size from quota
 		if ($softQuota) {
-			$rootInfo = $view->getFileInfo('/files/', false);
-			$free = $quota - $rootInfo['size']; // remaining free space for user
+			$userFolder = \OC::$server->getUserFolder($user);
+			if(is_null($userFolder)) {
+				return 0;
+			}
+			$free = $quota - $userFolder->getSize(); // remaining free space for user
 			if ($free > 0) {
 				$availableSpace = ($free * self::DEFAULTMAXSIZE / 100) - $trashbinSize; // how much space can be used for versions
 			} else {
@@ -618,41 +630,39 @@ class Trashbin {
 		$freeSpace = self::calculateFreeSpace($size, $user);
 
 		if ($freeSpace < 0) {
-			self::scheduleExpire($size, $user);
+			self::scheduleExpire($user);
 		}
 	}
 
 	/**
 	 * clean up the trash bin
 	 *
-	 * @param int $trashBinSize current size of the trash bin
 	 * @param string $user
 	 */
-	public static function expire($trashBinSize, $user) {
+	public static function expire($user) {
+		$trashBinSize = self::getTrashbinSize($user);
 		$availableSpace = self::calculateFreeSpace($trashBinSize, $user);
-		$size = 0;
 
 		$dirContent = Helper::getTrashFiles('/', $user, 'mtime');
 
 		// delete all files older then $retention_obligation
 		list($delSize, $count) = self::deleteExpiredFiles($dirContent, $user);
 
-		$size += $delSize;
-		$availableSpace += $size;
+		$availableSpace += $delSize;
 
 		// delete files from trash until we meet the trash bin size limit again
-		$size += self::deleteFiles(array_slice($dirContent, $count), $user, $availableSpace);
+		self::deleteFiles(array_slice($dirContent, $count), $user, $availableSpace);
 	}
 
-	/**@param int $trashBinSize current size of the trash bin
+	/**
 	 * @param string $user
 	 */
-	private static function scheduleExpire($trashBinSize, $user) {
+	private static function scheduleExpire($user) {
 		// let the admin disable auto expire
 		$application = new Application();
 		$expiration = $application->getContainer()->query('Expiration');
 		if ($expiration->isEnabled()) {
-			\OC::$server->getCommandBus()->push(new Expire($user, $trashBinSize));
+			\OC::$server->getCommandBus()->push(new Expire($user));
 		}
 	}
 
@@ -690,7 +700,7 @@ class Trashbin {
 	 *
 	 * @param array $files list of files sorted by mtime
 	 * @param string $user
-	 * @return array size of deleted files and number of deleted files
+	 * @return integer[] size of deleted files and number of deleted files
 	 */
 	public static function deleteExpiredFiles($files, $user) {
 		$application = new Application();
@@ -720,11 +730,11 @@ class Trashbin {
 	 *
 	 * @param string $source source path, relative to the users files directory
 	 * @param string $destination destination path relative to the users root directoy
-	 * @param \OC\Files\View $view file view for the users root directory
+	 * @param View $view file view for the users root directory
 	 * @return int
 	 * @throws Exceptions\CopyRecursiveException
 	 */
-	private static function copy_recursive($source, $destination, \OC\Files\View $view) {
+	private static function copy_recursive($source, $destination, View $view) {
 		$size = 0;
 		if ($view->is_dir($source)) {
 			$view->mkdir($destination);
@@ -761,7 +771,7 @@ class Trashbin {
 	 * @return array
 	 */
 	private static function getVersionsFromTrash($filename, $timestamp, $user) {
-		$view = new \OC\Files\View('/' . $user . '/files_trashbin/versions');
+		$view = new View('/' . $user . '/files_trashbin/versions');
 		$versions = array();
 
 		//force rescan of versions, local storage may not have updated the cache
@@ -799,10 +809,10 @@ class Trashbin {
 	 *
 	 * @param string $location where the file should be restored
 	 * @param string $filename name of the file
-	 * @param \OC\Files\View $view filesystem view relative to users root directory
+	 * @param View $view filesystem view relative to users root directory
 	 * @return string with unique extension
 	 */
-	private static function getUniqueFilename($location, $filename, \OC\Files\View $view) {
+	private static function getUniqueFilename($location, $filename, View $view) {
 		$ext = pathinfo($filename, PATHINFO_EXTENSION);
 		$name = pathinfo($filename, PATHINFO_FILENAME);
 		$l = \OC::$server->getL10N('files_trashbin');
@@ -831,7 +841,7 @@ class Trashbin {
 	/**
 	 * get the size from a given root folder
 	 *
-	 * @param \OC\Files\View $view file view on the root folder
+	 * @param View $view file view on the root folder
 	 * @return integer size of the folder
 	 */
 	private static function calculateSize($view) {
@@ -866,7 +876,7 @@ class Trashbin {
 	 * @return integer trash bin size
 	 */
 	private static function getTrashbinSize($user) {
-		$view = new \OC\Files\View('/' . $user);
+		$view = new View('/' . $user);
 		$fileInfo = $view->getFileInfo('/files_trashbin');
 		return isset($fileInfo['size']) ? $fileInfo['size'] : 0;
 	}
@@ -895,10 +905,10 @@ class Trashbin {
 	 */
 	public static function isEmpty($user) {
 
-		$view = new \OC\Files\View('/' . $user . '/files_trashbin');
+		$view = new View('/' . $user . '/files_trashbin');
 		if ($view->is_dir('/files') && $dh = $view->opendir('/files')) {
 			while ($file = readdir($dh)) {
-				if (!\OC\Files\Filesystem::isIgnoredDir($file)) {
+				if (!Filesystem::isIgnoredDir($file)) {
 					return false;
 				}
 			}
