@@ -5,10 +5,11 @@
  * @author Joas Schilling <nickvergessen@owncloud.com>
  * @author Morris Jobke <hey@morrisjobke.de>
  * @author Robin Appelman <icewind@owncloud.com>
- * @author Victor Dubiniuk <dubiniuk@owncloud.com>
+ * @author Roeland Jago Douma <rullzer@owncloud.com>
+ * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2015, ownCloud, Inc.
+ * @copyright Copyright (c) 2016, ownCloud, Inc.
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -29,6 +30,8 @@ use OCA\Files_Trashbin;
 
 /**
  * Class Test_Encryption
+ *
+ * @group DB
  */
 class Test_Trashbin extends \Test\TestCase {
 
@@ -65,14 +68,14 @@ class Test_Trashbin extends \Test\TestCase {
 		\OC::registerShareHooks();
 		$application = new \OCA\Files_Sharing\AppInfo\Application();
 		$application->registerMountProviders();
-		$application->setupPropagation();
 
 		//disable encryption
 		\OC_App::disable('encryption');
 
+		$config = \OC::$server->getConfig();
 		//configure trashbin
-		self::$rememberRetentionObligation = \OC_Config::getValue('trashbin_retention_obligation', Files_Trashbin\Expiration::DEFAULT_RETENTION_OBLIGATION);
-		\OC_Config::setValue('trashbin_retention_obligation', 'auto, 2');
+		self::$rememberRetentionObligation = $config->getSystemValue('trashbin_retention_obligation', Files_Trashbin\Expiration::DEFAULT_RETENTION_OBLIGATION);
+		$config->setSystemValue('trashbin_retention_obligation', 'auto, 2');
 
 		// register hooks
 		Files_Trashbin\Trashbin::registerHooks();
@@ -86,9 +89,10 @@ class Test_Trashbin extends \Test\TestCase {
 
 	public static function tearDownAfterClass() {
 		// cleanup test user
-		\OC_User::deleteUser(self::TEST_TRASHBIN_USER1);
+		$user = \OC::$server->getUserManager()->get(self::TEST_TRASHBIN_USER1);
+		if ($user !== null) { $user->delete(); }
 
-		\OC_Config::setValue('trashbin_retention_obligation', self::$rememberRetentionObligation);
+		\OC::$server->getConfig()->setSystemValue('trashbin_retention_obligation', self::$rememberRetentionObligation);
 
 		\OC_Hook::clear();
 
@@ -246,8 +250,8 @@ class Test_Trashbin extends \Test\TestCase {
 
 	/**
 	 * verify that the array contains the expected results
-	 * @param array $result
-	 * @param array $expected
+	 * @param OCP\Files\FileInfo[] $result
+	 * @param string[] $expected
 	 */
 	private function verifyArray($result, $expected) {
 		$this->assertSame(count($expected), count($result));
@@ -266,6 +270,11 @@ class Test_Trashbin extends \Test\TestCase {
 		}
 	}
 
+	/**
+	 * @param OCP\Files\FileInfo[] $files
+	 * @param string $trashRoot
+	 * @param integer $expireDate
+	 */
 	private function manipulateDeleteTime($files, $trashRoot, $expireDate) {
 		$counter = 0;
 		foreach ($files as &$file) {
@@ -625,12 +634,11 @@ class Test_Trashbin extends \Test\TestCase {
 	/**
 	 * @param string $user
 	 * @param bool $create
-	 * @param bool $password
 	 */
 	public static function loginHelper($user, $create = false) {
 		if ($create) {
 			try {
-				\OC_User::createUser($user, $user);
+				\OC::$server->getUserManager()->createUser($user, $user);
 			} catch(\Exception $e) { // catch username is already being used from previous aborted runs
 
 			}
@@ -648,11 +656,20 @@ class Test_Trashbin extends \Test\TestCase {
 
 // just a dummy class to make protected methods available for testing
 class TrashbinForTesting extends Files_Trashbin\Trashbin {
+
+	/**
+	 * @param OCP\Files\FileInfo[] $files
+	 * @param integer $limit
+	 */
 	public function dummyDeleteExpiredFiles($files, $limit) {
 		// dummy value for $retention_obligation because it is not needed here
 		return parent::deleteExpiredFiles($files, \Test_Trashbin::TEST_TRASHBIN_USER1, $limit, 0);
 	}
 
+	/**
+	 * @param OCP\Files\FileInfo[] $files
+	 * @param integer $availableSpace
+	 */
 	public function dummyDeleteFiles($files, $availableSpace) {
 		return parent::deleteFiles($files, \Test_Trashbin::TEST_TRASHBIN_USER1, $availableSpace);
 	}
