@@ -1,7 +1,7 @@
 OC.L10N.register(
     "impress",
     {
-    "Documentation" : "Notendahandbók",
+    "Documentation" : "Hjálparskjöl",
     "No Impress files are found in your ownCloud. Please upload a .impress file." : "Engar Impress skrár fundust í ownCloud uppsetningu þinni. Vinsamlegast settu inn .impress skrá.",
     "Name" : "Nafn",
     "Size" : "Stærð",
