@@ -6,8 +6,15 @@ OC.L10N.register(
     "The content of the legal notice has to be configured first" : "Pirmiausia turi būti sukonfigūruotas teisinio pranešimo turinys",
     "That configuration has to be done by the system administration." : "Šie nustatymai turi būti atlikti sistemos administratoriaus.",
     "Imprint" : "Imprint",
+    "Reference" : "Nuoroda",
     "Header left" : "Antraštė kairėje",
     "Header right" : "Antraštė dešinėje",
-    "Content" : "Turinys"
+    "As guest" : "Kaip svečias",
+    "Footer left" : "Poraštė kairėje",
+    "Footer right" : "Poraštė dešinėje",
+    "At login" : "Prisijungime",
+    "Application" : "Programa",
+    "Content" : "Turinys",
+    "You can use plain text, markdown notation or html markup with inline style attributes. " : "Galite naudoti įprastą tekstą, markdown arba html žymėjimą su stiliaus atributais."
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");
