@@ -1,6 +1,8 @@
 OC.L10N.register(
     "ownpad_lite",
     {
+    "Document was shared" : "Dokumento kunhaviĝis",
+    "User %s shared quick document %s with you." : "Uzanto %s kunhavigis rapidan dokumenton %s kun vi.",
     "My pad" : "Miaj skribaĵoj",
     "Settings" : "Agordo",
     "Pad Title" : "Titolo de la skribaĵo",
