@@ -2,15 +2,15 @@ OC.L10N.register(
     "ownpad_lite",
     {
     "Document was shared" : "Skjalinu var deilt",
-    "User %s shared quick document %s with you." : "Notandi %s deildi fljótlegu skjal %s með þér.",
-    "My pad" : "Blokkin mín",
+    "User %s shared quick document %s with you." : "Notandi %s deildi flýtiskjali %s með þér.",
+    "My pad" : "Skrifblokkin mín",
     "Settings" : "Stillingar",
-    "Pad Title" : "Nafn á blokk",
+    "Pad Title" : "Heiti á skrifblokk",
     "Open" : "Opna",
     "Share with" : "Deila með",
     "Share" : "Deila",
-    "Etherpad service URL" : "Etherpad þjónustu hlekkur",
-    "Username" : "Notendanafn",
+    "Etherpad service URL" : "Slóð á Etherpad-þjónustu",
+    "Username" : "Notandanafn",
     "Save" : "Vista"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
