@@ -2,8 +2,8 @@ OC.L10N.register(
     "user_migrate",
     {
     "Export" : "내보내기",
-    "Something went wrong while the export file was being generated" : "내보낼 파일을 생성하는 동안 문제가 발생하였습니다",
-    "An error has occurred" : "오류가 발생하였습니다",
+    "Something went wrong while the export file was being generated" : "내보낼 파일을 생성하는 동안 문제가 발생했습니다",
+    "An error has occurred" : "오류가 발생했습니다",
     "Account Export/Import" : "계정 내보내기 및 가져오기",
     "Import" : "가져오기"
 },
