@@ -1,7 +1,7 @@
 OC.L10N.register(
     "user_openid_provider",
     {
-    "OpenID Provider remembered sites" : "Þekktar OpenID veitur",
+    "OpenID Provider remembered sites" : "Þekktar OpenID-veitur",
     "Trusted" : "Treyst",
     "Denied" : "Hafnað",
     "Remove" : "Fjarlægja"
