@@ -16,17 +16,13 @@
 	var TEMPLATE =
 			'<ul id="shareWithList" class="shareWithList">' +
 			'{{#each sharees}}' +
-			'    {{#if isCollection}}' +
-			'    <li data-collection="{{collectionID}}">{{text}}</li>' +
-			'    {{/if}}' +
-			'    {{#unless isCollection}}' +
-			'    <li data-share-type="{{shareType}}" data-share-with="{{shareWith}}" title="{{shareWith}}">' +
-			'        <a href="#" class="unshare"><span class="icon-loading-small hidden"></span><img class="svg" alt="{{unshareLabel}}" title="{{unshareLabel}}" src="{{unshareImage}}" /></a>' +
+			'    <li data-share-id="{{shareId}}" data-share-type="{{shareType}}" data-share-with="{{shareWith}}">' +
+			'        <a href="#" class="unshare"><span class="icon-loading-small hidden"></span><span class="icon icon-delete"></span><span class="hidden-visually">{{unshareLabel}}</span></a>' +
 			'        {{#if avatarEnabled}}' +
 			'        <div class="avatar {{#if modSeed}}imageplaceholderseed{{/if}}" data-username="{{shareWith}}" {{#if modSeed}}data-seed="{{shareWith}} {{shareType}}"{{/if}}></div>' +
 			'        {{/if}}' +
-			'        <span class="username">{{shareWithDisplayName}}</span>' +
-			'        {{#if mailPublicNotificationEnabled}} {{#unless isRemoteShare}}' +
+			'        <span class="has-tooltip username" title="{{shareWith}}">{{shareWithDisplayName}}</span>' +
+			'        {{#if mailNotificationEnabled}} {{#unless isRemoteShare}}' +
 			'        <input id="mail-{{cid}}-{{shareWith}}" type="checkbox" name="mailNotification" class="mailNotification checkbox" {{#if wasMailSent}}checked="checked"{{/if}} />' +
 			'        <label for="mail-{{cid}}-{{shareWith}}">{{notifyByMailLabel}}</label>' +
 			'        {{/unless}} {{/if}}' +
@@ -56,7 +52,6 @@
 			'        </div>' +
 			'        {{/unless}}' +
 			'    </li>' +
-			'    {{/unless}}' +
 			'{{/each}}' +
 			'</ul>'
 		;
@@ -81,12 +76,6 @@
 		/** @type {Function} **/
 		_template: undefined,
 
-		/** @type {boolean} **/
-		showLink: true,
-
-		/** @type {object} **/
-		_collections: {},
-
 		events: {
 			'click .unshare': 'onUnshare',
 			'click .permissions': 'onPermissionChange',
@@ -107,23 +96,6 @@
 			});
 		},
 
-		processCollectionShare: function(shareIndex) {
-			var type = this.model.getCollectionType(shareIndex);
-			var id = this.model.getCollectionPath(shareIndex);
-			if(type !== 'file' && type !== 'folder') {
-				id = this.model.getCollectionSource(shareIndex);
-			}
-			var displayName = this.model.getShareWithDisplayName(shareIndex);
-			if(!_.isUndefined(this._collections[id])) {
-				this._collections[id].text = this._collections[id].text + ", " + displayName;
-			} else {
-				this._collections[id] = {};
-				this._collections[id].text = t('core', 'Shared in {item} with {user}', {'item': id, user: displayName});
-				this._collections[id].id = id;
-				this._collections[id].isCollection = true;
-			}
-		},
-
 		/**
 		 *
 		 * @param {OC.Share.Types.ShareInfo} shareInfo
@@ -156,6 +128,7 @@
 				shareWith: shareWith,
 				shareWithDisplayName: shareWithDisplayName,
 				shareType: shareType,
+				shareId: this.model.get('shares')[shareIndex].id,
 				modSeed: shareType !== OC.Share.SHARE_TYPE_USER,
 				isRemoteShare: shareType === OC.Share.SHARE_TYPE_REMOTE
 			});
@@ -164,10 +137,9 @@
 		getShareeList: function() {
 			var universal = {
 				avatarEnabled: this.configModel.areAvatarsEnabled(),
-				mailPublicNotificationEnabled: this.configModel.isMailPublicNotificationEnabled(),
+				mailNotificationEnabled: this.configModel.isMailNotificationEnabled(),
 				notifyByMailLabel: t('core', 'notify by email'),
 				unshareLabel: t('core', 'Unshare'),
-				unshareImage: OC.imagePath('core', 'actions/delete'),
 				canShareLabel: t('core', 'can share'),
 				canEditLabel: t('core', 'can edit'),
 				createPermissionLabel: t('core', 'create'),
@@ -187,8 +159,6 @@
 				deletePermission: OC.PERMISSION_DELETE
 			};
 
-			this._collections = {};
-
 			if(!this.model.hasUserShares()) {
 				return [];
 			}
@@ -196,15 +166,10 @@
 			var shares = this.model.get('shares');
 			var list = [];
 			for(var index = 0; index < shares.length; index++) {
-				if(this.model.isCollection(index)) {
-					this.processCollectionShare(index);
-				} else {
-					// first empty {} is necessary, otherwise we get in trouble
-					// with references
-					list.push(_.extend({}, universal, this.getShareeObject(index)));
-				}
+				// first empty {} is necessary, otherwise we get in trouble
+				// with references
+				list.push(_.extend({}, universal, this.getShareeObject(index)));
 			}
-			list = _.union(_.values(this._collections), list);
 
 			return list;
 		},
@@ -227,6 +192,10 @@
 				});
 			}
 
+			this.$el.find('.has-tooltip').tooltip({
+				placement: 'bottom'
+			});
+
 			this.delegateEvents();
 
 			return this;
@@ -244,6 +213,7 @@
 		},
 
 		onUnshare: function(event) {
+			var self = this;
 			var $element = $(event.target);
 			if (!$element.is('a')) {
 				$element = $element.closest('a');
@@ -257,17 +227,24 @@
 			$loading.removeClass('hidden');
 
 			var $li = $element.closest('li');
-			var shareType = $li.data('share-type');
-			var shareWith = $li.attr('data-share-with');
 
-			this.model.removeShare(shareType, shareWith);
+			var shareId = $li.data('share-id');
 
+			self.model.removeShare(shareId)
+				.done(function() {
+					$li.remove();
+				})
+				.fail(function() {
+					$loading.addClass('hidden');
+					OC.Notification.showTemporary(t('core', 'Could not unshare'));
+				});
 			return false;
 		},
 
 		onPermissionChange: function(event) {
 			var $element = $(event.target);
 			var $li = $element.closest('li');
+			var shareId = $li.data('share-id');
 			var shareType = $li.data('share-type');
 			var shareWith = $li.attr('data-share-with');
 
@@ -289,7 +266,7 @@
 				permissions |= $(checkbox).data('permissions');
 			});
 
-			this.model.setPermissions(shareType, shareWith, permissions);
+			this.model.updateShare(shareId, {permissions: permissions});
 		},
 
 		onCrudsToggle: function(event) {
