@@ -10,13 +10,16 @@ OC.L10N.register(
     "Updated \"%s\" to %s" : "Обновен \"%s\" до %s",
     "Repair warning: " : "Предупреждение при поправка:",
     "Repair error: " : "Грешка при поправка:",
-    "Following incompatible apps have been disabled: %s" : "Следните несъвместими приложения бяха изключени: %s",
     "Invalid file provided" : "Предоставен е невалиден файл",
     "No image or file provided" : "Не бяха доставени картинка или файл",
     "Unknown filetype" : "Непознат файлов тип",
     "Invalid image" : "Невалидно изображение",
     "No temporary profile picture available, try again" : "Не е налична временна профилна снимка, опитайте отново",
     "No crop data provided" : "Липсват данни за изрязването",
+    "Couldn't reset password because the token is invalid" : "Промяната на паролата е невъзможно, защото връзката за удостоверение не е валидна",
+    "Couldn't send reset email. Please make sure your username is correct." : "Неуспешно изпращане на имейл за възстановяване на паролата. Моля, уверете се, че потребителското име е правилно.",
+    "%s password reset" : "Паролата на %s е променена.",
+    "Couldn't send reset email. Please contact your administrator." : "Изпращането на електронна поща е неуспешно. Моля, свържете се с вашия администратор.",
     "Sunday" : "Неделя",
     "Monday" : "Понеделник",
     "Tuesday" : "Вторник",
@@ -57,8 +60,8 @@ OC.L10N.register(
     "Dec." : "Дек.",
     "Settings" : "Настройки",
     "Saving..." : "Запазване...",
+    "Dismiss" : "Затвори",
     "seconds ago" : "преди секунди",
-    "Couldn't send reset email. Please contact your administrator." : "Изпращането на електронна поща е неуспешно. Моля, свържете се с вашия администратор.",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Връзката за възстановяване на паролата беше изпратена до вашата електронна поща. Ако не я получите в разумен период от време, проверете папките си за спам и junk.<br>Ако не я откривате и там, се свържете с местния администратор.",
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Файловете Ви са криптирани. Ако не сте настроили ключ за възстановяване, няма да е възможно да се възстановят данните Ви след смяна на паролата.<br />Ако не сте сигурни какво да направите, моля, свържете се с Вашия администратор преди да продължите. <br/>Наистина ли искате да продължите?",
     "I know what I'm doing" : "Знам какво правя",
@@ -88,19 +91,19 @@ OC.L10N.register(
     "Strong password" : "Сигурна парола",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Вашият web сървър все още не е удачно настроен да позволява синхронизация на файлове, защото WebDAV интерфейсът изглежда не работи.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Сървърът няма работеща интернет връзка. Това означава, че някои функции като прикачването на външни дискови устройства, уведомления за обновяване или инсталиране на външни приложения няма да работят. Достъпът на файлове отвън или изпращане на имейли за уведомление вероятно също няма да работят. Препоръчваме да включиш интернет връзката за този сървър ако искаш да използваш всички тези функции.",
-    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Твоята директория за данни и файлове вероятно са достъпни от интернет. .htaccess файла не функционира. Силно препоръчваме да настроиш уебсъръра по такъв начин, че директорията за данни да не бъде достъпна или да я преместиш извън директорията корен на сървъра.",
     "Error occurred while checking server setup" : "Настъпи грешка при проверката на настройките на сървъра.",
+    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Твоята директория за данни и файлове вероятно са достъпни от интернет. .htaccess файла не функционира. Силно препоръчваме да настроиш уебсъръра по такъв начин, че директорията за данни да не бъде достъпна или да я преместиш извън директорията корен на сървъра.",
     "Shared" : "Споделено",
     "Shared with {recipients}" : "Споделено с {recipients}.",
     "Error" : "Грешка",
     "Error while sharing" : "Грешка при споделяне",
     "Error while unsharing" : "Грешка при премахване на споделянето",
-    "Error while changing permissions" : "Грешка при промяна на привилегиите",
     "Error setting expiration date" : "Грешка при настройване на датата за изтичане",
     "The public link will expire no later than {days} days after it is created" : "Общодостъпната връзка ще изтече не по-късно от {days} дни след създаването ѝ.",
     "Set expiration date" : "Задаване на дата на изтичане",
     "Expiration" : "Изтичане",
     "Expiration date" : "Дата на изтичане",
+    "Choose a password for the public link" : "Изберете парола за общодостъпната връзка",
     "Sending ..." : "Изпращане ...",
     "Email sent" : "Електронната поща е изпратена",
     "Resharing is not allowed" : "Повторно споделяне не е разрешено.",
@@ -108,13 +111,11 @@ OC.L10N.register(
     "Link" : "Връзка",
     "Password protect" : "Защитено с парола",
     "Password" : "Парола",
-    "Choose a password for the public link" : "Изберете парола за общодостъпната връзка",
     "Allow editing" : "Позволяване на редактиране",
     "Email link to person" : "Имейл връзка към човек",
     "Send" : "Изпращане",
     "Shared with you and the group {group} by {owner}" : "Споделено от {owner} с Вас и групата {group} .",
     "Shared with you by {owner}" : "Споделено с Вас от {owner}.",
-    "Shared in {item} with {user}" : "Споделено в {item} с {user}.",
     "group" : "група",
     "remote" : "отдалечен",
     "notify by email" : "уведомяване по електронна поща",
@@ -127,9 +128,10 @@ OC.L10N.register(
     "access control" : "контрол на достъпа",
     "Share" : "Споделяне",
     "Warning" : "Предупреждение",
+    "Delete" : "Изтриване",
+    "Rename" : "Преименуване",
     "The object type is not specified." : "Видът на обекта не е избран.",
     "Enter new" : "Въвеждане на нов",
-    "Delete" : "Изтриване",
     "Add" : "Добавяне",
     "Edit tags" : "Промяна на етикетите",
     "Error loading dialog template: {error}" : "Грешка при зареждането на шаблон за диалог: {error}.",
@@ -144,14 +146,6 @@ OC.L10N.register(
     "Please reload the page." : "Моля, презаредете страницата.",
     "The update was unsuccessful. " : "Обновяването бе неуспешно.",
     "The update was successful. Redirecting you to ownCloud now." : "Обновяването е успешно. Сега Ви пренасочваме към ownCloud.",
-    "Couldn't reset password because the token is invalid" : "Промяната на паролата е невъзможно, защото връзката за удостоверение не е валидна",
-    "Couldn't send reset email. Please make sure your username is correct." : "Неуспешно изпращане на имейл за възстановяване на паролата. Моля, уверете се, че потребителското име е правилно.",
-    "Couldn't send reset email because there is no email address for this username. Please contact your administrator." : "Неуспешно изпращане на имейл за възстановяване на паролата, защото липсва имейл, свързан с това потребителско име. Моля, свържете се с администратора.",
-    "%s password reset" : "Паролата на %s е променена.",
-    "Use the following link to reset your password: {link}" : "Използвайте следната връзка, за да възстановите паролата си: {link}",
-    "New password" : "Нова парола",
-    "New Password" : "Нова Парола",
-    "Reset password" : "Възстановяване на паролата",
     "Searching other places" : "Търсене в други места",
     "Personal" : "Лични",
     "Users" : "Потребители",
@@ -203,21 +197,23 @@ OC.L10N.register(
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Особено, когато използвате клиент за работен плот за синхронизация, използването на SQLite e непрепоръчително.",
     "Finish setup" : "Завършване на настройките",
     "Finishing …" : "Завършване...",
+    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Здрасти,<br><br>само да те уведомя, че %s сподели <strong>%s</strong> с теб.\n<br><a href=\"%s\">Разгледай го!</a><br><br>.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Това приложение изисква JavaScript, за да функционира правилно. Моля, {linkstart}включи JavaScript{linkend} и презареди страницата.",
     "Log out" : "Отписване",
     "Search" : "Търсене",
     "Server side authentication failed!" : "Удостоверяването от страна на сървъра е неуспешно!",
     "Please contact your administrator." : "Моля, свържете се с администратора.",
     "Log in" : "Вписване",
-    "remember" : "запомняне",
     "Alternative Logins" : "Алтернативни методи на вписване",
-    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Здрасти,<br><br>само да те уведомя, че %s сподели <strong>%s</strong> с теб.\n<br><a href=\"%s\">Разгледай го!</a><br><br>.",
+    "Use the following link to reset your password: {link}" : "Използвайте следната връзка, за да възстановите паролата си: {link}",
+    "New password" : "Нова парола",
+    "New Password" : "Нова Парола",
+    "Reset password" : "Възстановяване на паролата",
     "This ownCloud instance is currently in single user mode." : "В момента този ownCloud е в режим допускащ само един потребител.",
     "This means only administrators can use the instance." : "Това означава, че само администраторът може да го използва.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Свържи се със системния си администратор ако това съобщение се задържи твърде дълго или се е появило неочаквано.",
     "Thank you for your patience." : "Благодарим за търпението.",
     "You are accessing the server from an untrusted domain." : "Свръзваш се със сървъра от неодобрен домейн.",
-    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domain\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Моля, свържи се с администратора. Ако ти си администраторът, на този сървър, промени \"trusted_domain\" настройките в  config/config.php. Примерна конфигурация е приложена в config/config.sample.php.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "В зависимост от конфигурацията ти, като администратор може натискайки бутонът по-долу да отбележиш домейнът като сигурен.",
     "Add \"%s\" as trusted domain" : "Добави \"%s\" като сигурен домейн",
     "The theme %s has been disabled." : "Темата %s бе изключена.",
