@@ -3,30 +3,44 @@ OC.L10N.register(
     {
     "Couldn't send mail to following users: %s " : "An folgende Benutzer konnte keine E-Mail gesendet werden: %s",
     "Preparing update" : "Update vorbereiten",
-    "Migration tests are skipped - \"update.skip-migration-test\" is activated in config.php" : "Migrationstests wurden übersprungen - \"update.skip-migration-test\" ist in der config.php aktiviert",
     "Turned on maintenance mode" : "Wartungsmodus eingeschaltet ",
     "Turned off maintenance mode" : "Wartungsmodus ausgeschaltet",
-    "Maintenance mode is kept active" : "Wartungsmodus wird aktiv gehalten",
+    "Maintenance mode is kept active" : "Wartungsmodus bleibt aktiviert",
+    "Updating database schema" : "Das Datenbankschema wird aktualisiert",
     "Updated database" : "Datenbank aktualisiert",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Prüft, ob das Datenbankschema aktualisiert werden kann (dies kann je nach Datenbankgröße sehr lange dauern)",
     "Checked database schema update" : "Datenbankschema-Aktualisierung überprüft",
+    "Checking updates of apps" : "Es wird nach Updates für die Apps gesucht",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Prüft, ob das Datenbankschema für %s aktualisiert werden kann (dies kann je nach Datenbankgröße sehr lange dauern)",
     "Checked database schema update for apps" : "Datenbankschema-Aktualisierung für Apps überprüft",
     "Updated \"%s\" to %s" : "„%s“ zu %s aktualisiert",
     "Repair warning: " : "Reperaturwarnung:",
     "Repair error: " : "Reperaturfehler:",
-    "Set log level to debug - current level: \"%s\"" : "Log-Level auf Debug gesetzt - aktuelles Level: \"%s\"",
-    "Reset log level to  \"%s\"" : "Log-Level auf \"%s\" zurückgesetzt",
-    "Following incompatible apps have been disabled: %s" : "Die folgenden inkompatiblen Apps sind deaktiviert worden: %s",
+    "Set log level to debug" : "Log-Level auf \"debug\" gesetzt",
+    "Reset log level" : "Ursprüngliches Log-Level wiederhergestellt",
+    "Starting code integrity check" : "Code-Integrität wird überprüft",
+    "Finished code integrity check" : "Code-Integritätsprüfung abgeschlossen",
+    "%s (3rdparty)" : "%s (Drittanbieter)",
+    "%s (incompatible)" : "%s (inkompatibel)",
     "Following apps have been disabled: %s" : "Die folgenden Apps sind deaktiviert worden: %s",
     "Already up to date" : "Bereits aktuell",
+    "Please select a file." : "Bitte wählen Sie eine Datei aus.",
     "File is too big" : "Datei ist zu groß",
     "Invalid file provided" : "Ungültige Datei zur Verfügung gestellt",
     "No image or file provided" : "Es wurde weder ein Bild noch eine Datei zur Verfügung gestellt",
     "Unknown filetype" : "Unbekannter Dateityp",
     "Invalid image" : "Ungültiges Bild",
+    "An error occurred. Please contact your admin." : "Es ist ein Fehler aufgetreten, bitte kontaktieren Sie Ihren Administrator.",
     "No temporary profile picture available, try again" : "Kein temporäres Profilbild verfügbar, bitte versuchen Sie es noch einmal",
     "No crop data provided" : "Keine Beschnittdaten zur Verfügung gestellt",
     "No valid crop data provided" : "Keine gültigen Zuschnittdaten zur Verfügung gestellt",
     "Crop is not square" : "Zuschnitt ist nicht quadratisch",
+    "Couldn't reset password because the token is invalid" : "Das Passwort konnte aufgrund eines ungültigen Tokens nicht zurückgesetzt werden",
+    "Couldn't reset password because the token is expired" : "Das Passwort konnte nicht zurückgesetzt werden, da der Token abgelaufen ist",
+    "Couldn't send reset email. Please make sure your username is correct." : "E-Mail zum Zurücksetzen kann nicht versendet werden. Bitte stellen Sie sicher, dass Ihr Benutzername richtig ist.",
+    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Es konnte keine E-Mail verschickt werden um das Passwort zurückzusetzten, da keine E-Mail im Benutzerkonto hinterlegt ist. Bitte kontaktieren Sie den Administrator.",
+    "%s password reset" : "%s-Passwort zurücksetzen",
+    "Couldn't send reset email. Please contact your administrator." : "Die E-Mail zum Zurücksetzen konnte nicht versendet werden. Bitte kontaktieren Sie Ihren Administrator.",
     "Sunday" : "Sonntag",
     "Monday" : "Montag",
     "Tuesday" : "Dienstag",
@@ -74,8 +88,8 @@ OC.L10N.register(
     "Dec." : "Dez.",
     "Settings" : "Einstellungen",
     "Saving..." : "Speichervorgang…",
+    "Dismiss" : "Ausblenden",
     "seconds ago" : "Gerade eben",
-    "Couldn't send reset email. Please contact your administrator." : "Die E-Mail zum Zurücksetzen konnte nicht versendet werden. Bitte kontaktieren Sie Ihren Administrator.",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Der Link zum Rücksetzen Ihres Passworts ist an Ihre E-Mail-Adresse versandt worden. Sollten Sie ihn innerhalb eines annehmbaren Zeitraums nicht empfangen, prüfen Sie bitte Ihren Spam-Ordner.<br>Wenn er sich nicht darin befindet, fragen Sie bitte bei Ihrem lokalen Administrator nach.",
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Ihre Dateien sind verschlüsselt. Wenn Sie den Wiederherstellungsschlüssel nicht aktiviert haben, wird es keine Möglichkeit geben, um Ihre Daten wieder zu erhalten, nachdem Ihr Passwort zurückgesetzt wurde.<br />Wenn Sie sich nicht sicher sind, was Sie tun sollen, wenden Sie sich bitte an Ihren Administrator, bevor Sie fortfahren.<br />Wollen Sie wirklich fortfahren?",
     "I know what I'm doing" : "Ich weiß, was ich mache",
@@ -105,25 +119,22 @@ OC.L10N.register(
     "Strong password" : "Starkes Passwort",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Ihr Webserver ist noch nicht hinreichend für Datei-Synchronisation konfiguriert, weil die WebDAV-Schnittstelle vermutlich defekt ist.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Dieser Server hat keine funktionierende Internetverbindung. Dies bedeutet, dass einige Funktionen wie das Einhängen externen Speicherplatzes, Update-Benachrichtigungen oder die Installation von Drittanbieter-Apps nicht funktionieren werden. Der Fernzugriff auf Dateien und der Versand von E-Mail-Benachrichtigungen kann ebenfalls nicht funktionieren. Es wird empfohlen, die Internetverbindung dieses Servers zu aktivieren, wenn Sie alle Funktionen nutzen möchten.",
-    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Ihr Datenverzeichnis und Ihre Dateien sind wahrscheinlich vom Internet aus erreichbar. Die .htaccess-Datei funktioniert nicht. Es wird dringend empfohlen, Ihren Webserver dahingehend zu konfigurieren, dass das Datenverzeichnis nicht mehr vom Internet aus erreichbar ist oder dass Sie es aus dem Document-Root-Verzeichnis des Webservers herausverschieben.",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "Es wurde kein PHP Memory Cache konfiguriert. Konfiguriere zur Erhöhung der Leistungsfähigkeit, soweit verfügbar, einen Memory Cache. Weitere Informationen finden Sie in unserer <a href=\"{docLink}\">Dokumentation</a>.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "/dev/urandom ist von PHP nicht lesbar, wovon aus Sicherheitsgründen dringend abgeraten wird. Weitere Informationen hierzu finden Sie in unserer <a href=\"{docLink}\">Dokumentation</a>.",
-    "Your PHP version ({version}) is no longer <a href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "Ihre PHP Version ({version}) wird nicht länger <a href=\"{phpLink}\">unterstützt</a>. Wir empfehlen ein Upgrade ihrer PHP Version, um die volle Performance und Sicherheit zu gewährleisten.",
+    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Es wurde kein Memory Cache konfiguriert. Um die Leistung zu verbessern, konfigurieren Sie bitte einen Cache-Speicher, sofern vorhanden. Weitere Informationen finden Sie in unserer <a target=\"_blank\" href=\"{docLink}\">Dokumentation</a>.",
     "Error occurred while checking server setup" : "Fehler beim Überprüfen der Servereinrichtung",
+    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Ihr Datenverzeichnis und Ihre Dateien sind wahrscheinlich vom Internet aus erreichbar. Die .htaccess-Datei funktioniert nicht. Es wird dringend empfohlen, Ihren Webserver dahingehend zu konfigurieren, dass das Datenverzeichnis nicht mehr vom Internet aus erreichbar ist oder dass Sie es aus dem Document-Root-Verzeichnis des Webservers herausverschieben.",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "Der „{header}“-HTTP-Header ist nicht so konfiguriert, dass er „{expected}“ entspricht. Dies ist ein potentielles Sicherheitsrisiko und es wird empfohlen, diese Einstellung zu ändern.",
-    "The \"Strict-Transport-Security\" HTTP header is not configured to least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "Der „Strict-Transport-Security“-HTTP-Header ist nicht auf mindestens „{seconds}“ Sekunden eingestellt. Für umfassende Sicherheit wird das Aktivieren von HSTS empfohlen, wie es in unseren <a href=\"{docUrl}\">Sicherheitshinweisen</a> erläutert ist.",
     "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Sie greifen auf diese Site über HTTP zu. Wir raten dringend dazu, Ihren Server so zu konfigurieren, dass er stattdessen nur HTTPS akzeptiert, wie es in unseren <a href=\"{docUrl}\">Sicherheitshinweisen</a> beschrieben ist.",
     "Shared" : "Geteilt",
     "Shared with {recipients}" : "Geteilt mit {recipients}",
     "Error" : "Fehler",
     "Error while sharing" : "Fehler beim Teilen",
     "Error while unsharing" : "Fehler beim Aufheben der Freigabe",
-    "Error while changing permissions" : "Fehler bei der Änderung der Rechte",
     "Error setting expiration date" : "Fehler beim Setzen des Ablaufdatums",
     "The public link will expire no later than {days} days after it is created" : "Der öffentliche Link wird spätestens {days} Tage nach seiner Erstellung ablaufen",
     "Set expiration date" : "Ein Ablaufdatum setzen",
     "Expiration" : "Ablaufdatum",
     "Expiration date" : "Ablaufdatum",
+    "Choose a password for the public link" : "Wählen Sie ein Passwort für den öffentlichen Link",
     "Sending ..." : "Senden…",
     "Email sent" : "E-Mail gesendet",
     "Resharing is not allowed" : "Das Weiterverteilen ist nicht erlaubt",
@@ -131,13 +142,11 @@ OC.L10N.register(
     "Link" : "Link",
     "Password protect" : "Passwortschutz",
     "Password" : "Passwort",
-    "Choose a password for the public link" : "Wählen Sie ein Passwort für den öffentlichen Link",
     "Allow editing" : "Bearbeitung erlauben",
     "Email link to person" : "Link per E-Mail verschicken",
     "Send" : "Senden",
     "Shared with you and the group {group} by {owner}" : "Von {owner} mit Ihnen und der Gruppe {group} geteilt.",
     "Shared with you by {owner}" : "Von {owner} mit Ihnen geteilt.",
-    "Shared in {item} with {user}" : "Freigegeben in {item} von {user}",
     "group" : "Gruppe",
     "remote" : "Entfernte Freigabe",
     "notify by email" : "per E-Mail benachrichtigen",
@@ -148,6 +157,7 @@ OC.L10N.register(
     "change" : "Ändern",
     "delete" : "löschen",
     "access control" : "Zugriffskontrolle",
+    "No users or groups found for {search}" : "Keine Benutzer oder Gruppen für {search} gefunden",
     "An error occured. Please try again" : "Es ist ein Fehler aufgetreten. Bitte versuchen Sie es noch einmal",
     "Share" : "Teilen",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Mit Benutzern anderer ownClouds unter Verwendung der Syntax benutzername@beispiel.com/owncloud teilen",
@@ -155,9 +165,14 @@ OC.L10N.register(
     "Share with users, groups or remote users …" : "Mit Benutzern, Gruppen oder entfernten Benutzern teilen…",
     "Warning" : "Warnung",
     "Error while sending notification" : "Fehler beim Senden der Benachrichtigung",
+    "not assignable" : "nicht zuweisbar",
+    "invisible" : "unsichtbar",
+    "({scope})" : "({scope})",
+    "Delete" : "Löschen",
+    "Rename" : "Umbenennen",
+    "Collaborative tags" : "Gemeinschaftliche Tags",
     "The object type is not specified." : "Der Objekttyp ist nicht angegeben.",
     "Enter new" : "Neuen eingeben",
-    "Delete" : "Löschen",
     "Add" : "Hinzufügen",
     "Edit tags" : "Schlagwörter bearbeiten",
     "Error loading dialog template: {error}" : "Fehler beim Laden der Dialogvorlage: {error}",
@@ -168,21 +183,13 @@ OC.L10N.register(
     "Hello {name}, the weather is {weather}" : "Hallo {name}, das Wetter ist {weather}",
     "Hello {name}" : "Hallo {name}",
     "_download %n file_::_download %n files_" : ["Lade %n Datei herunter","Lade %n Dateien herunter"],
-    "{version} is available. Get more information on how to update." : "{version} ist verfügbar. Holen Sie weitere Informationen zu Aktualisierungen ein.",
+    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Das Upgrade läuft noch , diese Seite zu verlassen könnte das Verfahren in einigen Umgebungen unterbrechen.",
     "Updating {productName} to version {version}, this may take a while." : "{productName} wird auf Version {version} aktualisiert. Das könnte eine Weile dauern.",
+    "An error occurred." : "Ein Fehler ist aufgetreten.",
     "Please reload the page." : "Bitte laden Sie die Seite neu.",
     "The update was unsuccessful. " : "Die Aktualisierung war nicht erfolgreich.",
     "The update was successful. There were warnings." : "Das Update war erfolgreich. Warnungen wurden ausgegeben.",
     "The update was successful. Redirecting you to ownCloud now." : "Das Update war erfolgreich. Sie werden nun zu ownCloud weitergeleitet.",
-    "Couldn't reset password because the token is invalid" : "Das Passwort konnte aufgrund eines ungültigen Tokens nicht zurückgesetzt werden",
-    "Couldn't reset password because the token is expired" : "Das Passwort konnte nicht zurückgesetzt werden, da der Token abgelaufen ist",
-    "Couldn't send reset email. Please make sure your username is correct." : "E-Mail zum Zurücksetzen kann nicht versendet werden. Bitte stellen Sie sicher, dass Ihr Benutzername richtig ist.",
-    "Couldn't send reset email because there is no email address for this username. Please contact your administrator." : "Die E-Mail zum Zurücksetzen konnte nicht versandt werden, weil für diesen Benutzernamen keine E-Mail-Adresse hinterlegt ist. Bitte kontaktieren Sie Ihren Administrator.",
-    "%s password reset" : "%s-Passwort zurücksetzen",
-    "Use the following link to reset your password: {link}" : "Benutzen Sie den folgenden Link, um Ihr Passwort zurückzusetzen: {link}",
-    "New password" : "Neues Passwort",
-    "New Password" : "Neues Passwort",
-    "Reset password" : "Passwort zurücksetzen",
     "Searching other places" : "Andere Orte durchsuchen",
     "No search results in other folders" : "Keine Suchergebnisse in anderen Ordnern",
     "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} Suchergebnis in anderen Ordnern","{count} Suchergebnisse in anderen Ordnern"],
@@ -242,6 +249,7 @@ OC.L10N.register(
     "Finishing …" : "Abschließen…",
     "Need help?" : "Hilfe nötig?",
     "See the documentation" : "Schauen Sie in die Dokumentation",
+    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hallo,<br><br>hier nur kurz die Mitteilung, dass %s <strong>%s</strong> mit Ihnen geteilt hat.<br><a href=\"%s\">Sehen Sie es sich an!</a><br><br>",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Diese Anwendung benötigt zum ordnungsgemäßen Betrieb JavaScript. Bitte {linkstart}aktivieren Sie JavaScript{linkend} und laden Sie die Seite neu.",
     "Log out" : "Abmelden",
     "Search" : "Suche",
@@ -251,15 +259,18 @@ OC.L10N.register(
     "Please try again or contact your administrator." : "Bitte versuchen Sie es noch einmal oder kontaktieren Sie Ihren Administrator.",
     "Log in" : "Einloggen",
     "Wrong password. Reset it?" : "Falsches Passwort. Soll es zurückgesetzt werden?",
-    "remember" : "merken",
+    "Wrong password." : "Falsches Passwort.",
+    "Stay logged in" : "Angemeldet bleiben",
     "Alternative Logins" : "Alternative Logins",
-    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hallo,<br><br>hier nur kurz die Mitteilung, dass %s <strong>%s</strong> mit Ihnen geteilt hat.<br><a href=\"%s\">Sehen Sie es sich an!</a><br><br>",
+    "Use the following link to reset your password: {link}" : "Benutzen Sie den folgenden Link, um Ihr Passwort zurückzusetzen: {link}",
+    "New password" : "Neues Passwort",
+    "New Password" : "Neues Passwort",
+    "Reset password" : "Passwort zurücksetzen",
     "This ownCloud instance is currently in single user mode." : "Diese ownClound-Instanz befindet sich derzeit im Einzelbenutzermodus.",
     "This means only administrators can use the instance." : "Das bedeutet, dass diese Instanz nur von Administratoren benutzt werden kann.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktieren Sie Ihren Systemadministrator, wenn diese Meldung dauerhaft oder unerwartet erscheint.",
     "Thank you for your patience." : "Vielen Dank für Ihre Geduld.",
     "You are accessing the server from an untrusted domain." : "Sie greifen von einer nicht vertrauenswürdigen Domain auf den Server zu.",
-    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domain\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Bitte kontaktieren Sie Ihren Administrator. Wenn Sie Administrator dieser Instanz sind, konfigurieren Sie bitte die „trusted_domain“-Einstellung in config/config.php. Eine Beispielkonfiguration wird unter config/config.sample.php bereitgestellt.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Wenn es Ihre Konfiguration zulässt, können Sie als Administrator gegebenenfalls den Button unten benutzen, um diese Domain als vertrauenswürdig einzustufen.",
     "Add \"%s\" as trusted domain" : "„%s“ als vertrauenswürdige Domain hinzufügen",
     "App update required" : "App-Update notwendig",
