@@ -3,30 +3,44 @@ OC.L10N.register(
     {
     "Couldn't send mail to following users: %s " : "Sähköpostin lähetys seuraaville käyttäjille epäonnistui: %s",
     "Preparing update" : "Valmistellaan päivitystä",
-    "Migration tests are skipped - \"update.skip-migration-test\" is activated in config.php" : "Migraatiotestit ohitetaan - \"update.skip-migration-test\" on aktiivisena config.php-tiedostossa",
     "Turned on maintenance mode" : "Siirrytty huoltotilaan",
     "Turned off maintenance mode" : "Huoltotila asetettu pois päältä",
     "Maintenance mode is kept active" : "Huoltotila pidetään aktiivisena",
+    "Updating database schema" : "Päivitetään tietokannan skeemaa",
     "Updated database" : "Tietokanta ajan tasalla",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Tarkistetaan onko tietokannan skeemaa mahdollista päivittää (tämä saattaa kestää kauan riippuen tietokannan koosta)",
     "Checked database schema update" : "Tarkistettu tietokannan skeemapäivitys",
+    "Checking updates of apps" : "Tarkistetaan sovellusten päivityksiä",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Tarkistetaan onko kohteen %s tietokannan skeemaa mahdollista päivittää (tämä saattaa kestää kauan riippuen tietokannan koosta)",
     "Checked database schema update for apps" : "Tarkistettu tietokannan skeemapäivitys sovelluksille",
     "Updated \"%s\" to %s" : "Päivitetty \"%s\" versioon %s",
     "Repair warning: " : "Korjausvaroitus:",
     "Repair error: " : "Korjausvirhe:",
-    "Set log level to debug - current level: \"%s\"" : "Aseta lokitasoksi vianjäljitys - nykyinen taso: \"%s\"",
-    "Reset log level to  \"%s\"" : "Palauta lokitasoksi  \"%s\"",
-    "Following incompatible apps have been disabled: %s" : "Seuraavat yhteensopimattomat sovellukset on poistettu käytöstä: %s",
+    "Set log level to debug" : "Aseta lokitustasoksi vianetsintä",
+    "Reset log level" : "Nollaa lokitustaso",
+    "Starting code integrity check" : "Aloitetaan koodin eheystarkistus",
+    "Finished code integrity check" : "Koodin eheystarkistus suoritettu",
+    "%s (3rdparty)" : "%s (kolmannen osapuolen)",
+    "%s (incompatible)" : "%s (ei yhteensopiva)",
     "Following apps have been disabled: %s" : "Seuraavat sovellukset on poistettu käytöstä: %s",
     "Already up to date" : "Kaikki on jo ajan tasalla",
+    "Please select a file." : "Valitse tiedosto.",
     "File is too big" : "Tiedosto on liian suuri",
     "Invalid file provided" : "Määritetty virheellinen tiedosto",
     "No image or file provided" : "Kuvaa tai tiedostoa ei määritelty",
     "Unknown filetype" : "Tuntematon tiedostotyyppi",
     "Invalid image" : "Virhellinen kuva",
+    "An error occurred. Please contact your admin." : "Tapahtui virhe. Ota yhteys ylläpitoon.",
     "No temporary profile picture available, try again" : "Väliaikaista profiilikuvaa ei ole käytettävissä, yritä uudelleen",
     "No crop data provided" : "Puutteellinen tieto",
     "No valid crop data provided" : "Kelvollisia leikkaustietoja ei määritetty",
     "Crop is not square" : "Leikkaus ei ole neliö",
+    "Couldn't reset password because the token is invalid" : "Salasanaa ei voitu palauttaa koska valtuutus on virheellinen",
+    "Couldn't reset password because the token is expired" : "Salasanan palauttaminen ei onnistunut, koska valtuutus on vanhentunut",
+    "Couldn't send reset email. Please make sure your username is correct." : "Palautussähköpostin lähettäminen ei onnistunut. Varmista, että käyttäjätunnuksesi on oikein.",
+    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Salasanan palautusiviestiä ei voitu lähettää sähköpostitse, koska tälle käyttäjätunnukselle ei ole määritetty sähköpostiosoitetta. Ota yhteys ylläpitäjään.",
+    "%s password reset" : "%s salasanan palautus",
+    "Couldn't send reset email. Please contact your administrator." : "Palautussähköpostin lähettäminen ei onnistunut. Ota yhteys ylläpitäjään.",
     "Sunday" : "sunnuntai",
     "Monday" : "maanantai",
     "Tuesday" : "tiistai",
@@ -72,10 +86,11 @@ OC.L10N.register(
     "Oct." : "Loka",
     "Nov." : "Marras",
     "Dec." : "Joulu",
+    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Eheystarkistus tuotti ongelmia. Lisätietoja…</a>",
     "Settings" : "Asetukset",
     "Saving..." : "Tallennetaan...",
+    "Dismiss" : "Hylkää",
     "seconds ago" : "sekuntia sitten",
-    "Couldn't send reset email. Please contact your administrator." : "Palautussähköpostin lähettäminen ei onnistunut. Ota yhteys ylläpitäjään.",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Linkki salasanan palauttamista varten on lähetetty sähköpostitse. Jos et saa sähköpostiviestiä kohtuullisessa ajassa, tarkista roskapostikansiot.<br>Jos et saa sähköpostiviestiä, ota yhteys paikalliseen ylläpitäjään.",
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Tiedostosi on salattu. Jos et ole ottanut käyttöön palautusavainta, tietojasi ei ole mahdollista palauttaa salasanan nollaamisen jälkeen.<br />Jos et ole varma mitä tehdä, ota yhteys ylläpitäjään.<br />Haluatko varmasti jatkaa?",
     "I know what I'm doing" : "Tiedän mitä teen",
@@ -104,28 +119,30 @@ OC.L10N.register(
     "Good password" : "Hyvä salasana",
     "Strong password" : "Vahva salasana",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "HTTP-palvelinta ei ole määritetty oikein tiedostojen synkronointia varten, koska WebDAV-liittymä vaikuttaa olevan rikki.",
+    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "HTTP-palvelintasi ei ole määritetty kelvollisesti selvittämään osoitetta \"{url}\". Lisätietoja on saatavilla <a target=\"_blank\" href=\"{docLink}\">dokumentaatiosta</a>.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Tällä palvelimella ei ole toimivaa internetyhteyttä. Sen seurauksena jotkin ominaisuudet, kuten erillinen tallennustila, ilmoitukset päivityksistä ja kolmansien osapuolten sovellusten asennus eivät toimi. Tiedostojen käyttö etänä tai ilmoitusten lähetys sähköpostitse eivät välttämättä toimi myöskään. Suosittelemme kytkemään palvelimen internetyhteyteen, jos haluat käyttää kaikkia ownCloudin ominaisuuksia.",
-    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Datahakemistosi ja tiedostosi ovat luultavasti käytettävissä suoraan internetistä. .htaccess-tiedosto ei toimi oikein. Suosittelemme määrittämään http-palvelimen asetukset siten, ettei datahakemisto ole suoraan käytettävissä internetistä, tai siirtämään datahakemiston http-palvelimen juurihakemiston ulkopuolelle.",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "Muistissa toimivaa cachea ei ole määritetty. Paranna suorituskykyä ottamalla memcache käyttöön. Lisätietoja on saatavilla <a href=\"{docLink}\">dokumentaatiosta</a>.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "/dev/urandom ei ole luettavissa PHP:n toimesta. Turvallisuussyistä tämä ei ole suositeltava asetus. Lisätietoja on tarjolla <a href=\"{docLink}\">dokumentaatiossa</a>.",
-    "Your PHP version ({version}) is no longer <a href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "Käytössäsi oleva PHP-versio ({version}) ei ole enää <a href=\"{phpLink}\">PHP:n tukema</a>. Päivitä PHP:n versio, jotta hyödyt suorituskykyyn ja tietoturvaan vaikuttavista päivityksistä.",
-    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "Käänteisen välityspalvelimen otsakkaiden asetukset ovat väärin, tai vaihtoehtoisesti käytät ownCloudia luotetun välityspalvelimen kautta. Jos et käytä ownCloudia luotetun välityspalvelimen kautta, kyseessä on tietoturvaongelma, joka mahdollistaa hyökkääjän väärentää ownCloudille näkyvän IP-osoitteen. Lisätietoja on saatavilla <a href=\"{docLink}\">dokumentaatiosta</a>.",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached on määritelty hajautetuksi välimuistiksi, mutta väärä PHP-moduuli \"memcache\" on asennettuna. \\OC\\Memcache\\Memcached tukee vain \"memcached\":ia, ei \"memcache\":a. Lisätietoja <a href=\"{wikiLink}\">memcachedin wikissä molemmista moduuleista</a>.",
+    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Välimuistia ei ole määritetty. Paranna suorituskykyä ottamalla memcache käyttöön. Lisätietoja on saatavilla <a target=\"_blank\" href=\"{docLink}\">dokumentaatiossa</a>.",
+    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "/dev/urandom ei ole PHP:n luettavissa, eikä tätä missään tapauksessa suositella tietoturvasyistä. Lisätietoja on saatavilla <a target=\"_blank\" href=\"{docLink}\">dokumentaatiossa</a>.",
+    "Your PHP version ({version}) is no longer <a target=\"_blank\" href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "PHP-versiosi ({version}) ei ole enää tuettu <a target=\"_blank\" href=\"{phpLink}\"> PHP:n toimesta</a>. Suosittelemme päivittämään PHP:n version, jotta hyödyt suorituskykyparannuksista sekä tietoturvakorjauksista.",
+    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Käänteisen välityspalvelimen otsakemääritykset ovat väärin, tai olet yhteydessä ownCloudiin luotetun välityspalvelimen kautta. Jos et ole yhteydessä luotetun välityspalvelimen kautta, kyseessä on tietoturvaongelma, joka mahdollistaa hyökkääjän väärentävän ownCloudille näkyvän IP-osoitteen. Lisätietoja on saatavilla <a target=\"_blank\" href=\"{docLink}\">dokumentaatiossa</a>.",
+    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached on määritetty hajautetuksi välimuistiksi, mutta väärä PHP-moduuli \"memcache\" on asennettu. \\OC\\Memcache\\Memcached tukee vain moduulia \"memcached\", ei moduulia \"memcache\". Lisätietoja <a target=\"_blank\" href=\"{wikiLink}\">memcachedin wikissä molemmista moduuleista</a>.",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Jotkin tiedostot eivät läpäisseet eheystarkistusta. Lisätietoja ongelman selvittämiseksi on saatavilla <a target=\"_blank\" href=\"{docLink}\">dokumentaatiossa</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Luettelo virheellisistä tiedostoista…</a> / <a href=\"{rescanEndpoint}\">Tarkista uudelleen…</a>)",
     "Error occurred while checking server setup" : "Virhe palvelimen määrityksiä tarkistaessa",
+    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Datahakemistosi ja tiedostosi ovat luultavasti käytettävissä suoraan internetistä. .htaccess-tiedosto ei toimi oikein. Suosittelemme määrittämään http-palvelimen asetukset siten, ettei datahakemisto ole suoraan käytettävissä internetistä, tai siirtämään datahakemiston http-palvelimen juurihakemiston ulkopuolelle.",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "HTTP-otsaketta \"{header}\" ei ole määritetty vastaamaan arvoa \"{expected}\". Kyseessä on mahdollinen tietoturvaan tai -suojaan liittyvä riski, joten suosittelemme muuttamaan asetuksen arvoa.",
-    "The \"Strict-Transport-Security\" HTTP header is not configured to least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "HTTP-otsaketta \"Strict-Transport-Security\" ei ole määritetty vähintään \"{seconds}\" sekuntiin. Suosittelemme HSTS:n käyttöä paremman tietoturvan vuoksi, kuten <a href=\"{docUrl}\">tietoturvavinkeissä</a> neuvotaan.",
+    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "HTTP-otsaketta \"Strict-Transport-Security\" ei ole määritetty vähintään \"{seconds}\" sekunniksi. Suosittelemme lisäturvan vuoksi ottamaan HSTS:n käyttöön <a href=\"{docUrl}\">turvallisuusohjeiden</a> mukaisesti.",
     "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Käytät sivustoa HTTP-yhteydellä. Suosittelemme asettamaan palvelimen vaatimaan HTTPS-yhteyden, kuten <a href=\"{docUrl}\">tietoturvavinkeissä</a> neuvotaan.",
     "Shared" : "Jaettu",
     "Shared with {recipients}" : "Jaettu henkilöiden {recipients} kanssa",
     "Error" : "Virhe",
     "Error while sharing" : "Virhe jaettaessa",
     "Error while unsharing" : "Virhe jakoa peruttaessa",
-    "Error while changing permissions" : "Virhe oikeuksia muuttaessa",
     "Error setting expiration date" : "Virhe päättymispäivää asettaessa",
     "The public link will expire no later than {days} days after it is created" : "Julkinen linkki vanhenee {days} päivän jälkeen sen luomisesta",
     "Set expiration date" : "Aseta päättymispäivä",
     "Expiration" : "Erääntyminen",
     "Expiration date" : "Päättymispäivä",
+    "Choose a password for the public link" : "Valitse salasana julkiselle linkille",
     "Sending ..." : "Lähetetään...",
     "Email sent" : "Sähköposti lähetetty",
     "Resharing is not allowed" : "Jakaminen uudelleen ei ole salittu",
@@ -133,13 +150,11 @@ OC.L10N.register(
     "Link" : "Linkki",
     "Password protect" : "Suojaa salasanalla",
     "Password" : "Salasana",
-    "Choose a password for the public link" : "Valitse salasana julkiselle linkille",
     "Allow editing" : "Salli muokkaus",
     "Email link to person" : "Lähetä linkki sähköpostitse",
     "Send" : "Lähetä",
     "Shared with you and the group {group} by {owner}" : "Jaettu sinun ja ryhmän {group} kanssa käyttäjän {owner} toimesta",
     "Shared with you by {owner}" : "Jaettu kanssasi käyttäjän {owner} toimesta",
-    "Shared in {item} with {user}" : "{item} on jaettu {user} kanssa",
     "group" : "ryhmä",
     "remote" : "etä",
     "notify by email" : "ilmoita sähköpostitse",
@@ -150,17 +165,29 @@ OC.L10N.register(
     "change" : "muuta",
     "delete" : "poista",
     "access control" : "Pääsyn hallinta",
+    "Could not unshare" : "Jakamisen lopettaminen epäonnistui",
     "Share details could not be loaded for this item." : "Tämän kohteen jakamistietoja ei voitu ladata.",
+    "No users or groups found for {search}" : "Haulla {search} ei löytynyt käyttäjiä tai ryhmiä",
     "An error occured. Please try again" : "Tapahtui virhe. Yritä myöhemmin uudestaan",
+    "{sharee} (group)" : "{sharee} (ryhmä)",
+    "{sharee} (at {server})" : "{sharee} (palvelimella {server})",
+    "{sharee} (remote)" : "{sharee} (etä)",
     "Share" : "Jaa",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Jaa toisia ownCloud-järjestelmiä käyttävien kesken käyttäen syntaksia käyttäjätunnus@esimerkki.fi/owncloud",
     "Share with users or groups …" : "Jaa käyttäjien tai ryhmien kanssa…",
     "Share with users, groups or remote users …" : "Jaa käyttäjien, ryhmien tai etäkäyttäjien kanssa…",
+    "Error removing share" : "Virhe jakoa poistaessa",
     "Warning" : "Varoitus",
     "Error while sending notification" : "Virhe ilmoitusta lähettäessä",
+    "Non-existing tag #{tag}" : "Ei olemassa oleva tunniste #{tag}",
+    "not assignable" : "ei määritettävissä",
+    "invisible" : "näkymätön",
+    "({scope})" : "({scope})",
+    "Delete" : "Poista",
+    "Rename" : "Nimeä uudelleen",
+    "Collaborative tags" : "Yhteistyölliset tunnisteet",
     "The object type is not specified." : "The object type is not specified.",
     "Enter new" : "Kirjoita uusi",
-    "Delete" : "Poista",
     "Add" : "Lisää",
     "Edit tags" : "Muokkaa tunnisteita",
     "Error loading dialog template: {error}" : "Virhe ladatessa keskustelupohja: {error}",
@@ -171,21 +198,14 @@ OC.L10N.register(
     "Hello {name}, the weather is {weather}" : "Hei {name}, sää on {weather}",
     "Hello {name}" : "Hei {name}",
     "_download %n file_::_download %n files_" : ["lataa %n tiedosto","lataa %n tiedostoa"],
-    "{version} is available. Get more information on how to update." : "{version} on saatavilla. Tarjolla on lisätietoja päivittämisestä.",
+    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Päivitys on meneillään. Poistuminen tältä sivulta saattaa keskeyttää toimenpiteen joissain käyttöympäristöissä.",
     "Updating {productName} to version {version}, this may take a while." : "Päivitetään {productName} versioon {version}, tämä saattaa kestää hetken.",
+    "An error occurred." : "Tapahtui virhe.",
     "Please reload the page." : "Päivitä sivu.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Päivitys epäonnistui. Katso lisätietoja tähän ongelmaan liittyen <a href=\"{url}\">keskustelupalstan viestistä</a>.",
     "The update was unsuccessful. " : "Päivitys epäonnistui.",
     "The update was successful. There were warnings." : "Päivitys onnistui, tosin ilmeni varoituksia.",
     "The update was successful. Redirecting you to ownCloud now." : "Päivitys onnistui. Selain ohjautuu nyt ownCloudiisi.",
-    "Couldn't reset password because the token is invalid" : "Salasanaa ei voitu palauttaa koska valtuutus on virheellinen",
-    "Couldn't reset password because the token is expired" : "Salasanan nollaaminen ei onnistunut, koska valtuutus on vanhentunut",
-    "Couldn't send reset email. Please make sure your username is correct." : "Palautussähköpostin lähettäminen ei onnistunut. Varmista, että käyttäjätunnuksesi on oikein.",
-    "Couldn't send reset email because there is no email address for this username. Please contact your administrator." : "Palautussähköpostin lähettäminen ei onnistunut, koska tälle käyttäjätunnukselle ei ole määritelty sähköpostiosoitetta. Ota yhteys ylläpitäjään.",
-    "%s password reset" : "%s salasanan palautus",
-    "Use the following link to reset your password: {link}" : "Voit palauttaa salasanasi seuraavassa osoitteessa: {link}",
-    "New password" : "Uusi salasana",
-    "New Password" : "Uusi salasana",
-    "Reset password" : "Palauta salasana",
     "Searching other places" : "Etsitään muista paikoista",
     "No search results in other folders" : "Ei hakutuloksia muissa kansioissa",
     "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} hakutulos muussa kansiossa","{count} hakutulosta muissa kansioissa"],
@@ -245,6 +265,7 @@ OC.L10N.register(
     "Finishing …" : "Valmistellaan…",
     "Need help?" : "Tarvitsetko apua?",
     "See the documentation" : "Tutustu dokumentaatioon",
+    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hei!<br><br>%s jakoi kanssasi kohteen <strong>%s</strong>.<br><a href=\"%s\">Tutustu siihen!</a><br><br>",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Tämä sovellus vaatii toimiakseen JavaScript-tuen. {linkstart}Ota JavaScript käyttöön{linkend} ja päivitä sivu.",
     "Log out" : "Kirjaudu ulos",
     "Search" : "Etsi",
@@ -254,15 +275,19 @@ OC.L10N.register(
     "Please try again or contact your administrator." : "Yritä uudestaan tai ota yhteys ylläpitäjään.",
     "Log in" : "Kirjaudu sisään",
     "Wrong password. Reset it?" : "Väärä salasana. Haluatko palauttaa salasanan?",
-    "remember" : "muista",
+    "Wrong password." : "Väärä salasana.",
+    "Stay logged in" : "Pysy sisäänkirjautuneena",
     "Alternative Logins" : "Vaihtoehtoiset kirjautumiset",
-    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hei!<br><br>%s jakoi kanssasi kohteen <strong>%s</strong>.<br><a href=\"%s\">Tutustu siihen!</a><br><br>",
+    "Use the following link to reset your password: {link}" : "Voit palauttaa salasanasi seuraavassa osoitteessa: {link}",
+    "New password" : "Uusi salasana",
+    "New Password" : "Uusi salasana",
+    "Reset password" : "Palauta salasana",
     "This ownCloud instance is currently in single user mode." : "Tämä ownCloud-asennus on parhaillaan single user -tilassa.",
     "This means only administrators can use the instance." : "Se tarkoittaa, että vain ylläpitäjät voivat nyt käyttää tätä ownCloudia.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Ota yhteys järjestelmän ylläpitäjään, jos tämä viesti ilmenee uudelleen tai odottamatta.",
     "Thank you for your patience." : "Kiitos kärsivällisyydestäsi.",
     "You are accessing the server from an untrusted domain." : "Olet yhteydessä palvelimeen epäluotettavasta verkko-osoitteesta.",
-    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domain\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Ota yhteys ylläpitäjään. Jos olet tämän ownCloudin ylläpitäjä, määritä \"trusted_domain\"-asetus tiedostossa config/config.php. Esimerkkimääritys on nähtävillä tiedostossa config/config.sample.php.",
+    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Ota yhteys ylläpitoon. Jos olet tämän asennuksen ylläpitäjä, määritä \"trusted_domains\"-asetus config/config.php-tiedostossa. Esimerkkimääritys on tarjolla tiedostossa config/config.sample.php.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Riippuen määrityksistä, ylläpitäjänä saatat kyetä käyttämään alla olevaa painiketta luodaksesi luottamussuhteen tähän toimialueeseen.",
     "Add \"%s\" as trusted domain" : "Lisää \"%s\" luotetuksi toimialueeksi",
     "App update required" : "Sovelluksen päivittäminen vaaditaan",
