@@ -3,30 +3,44 @@ OC.L10N.register(
     {
     "Couldn't send mail to following users: %s " : "Impossible d'envoyer un courriel aux utilisateurs suivants : %s",
     "Preparing update" : "Préparation de la mise à jour",
-    "Migration tests are skipped - \"update.skip-migration-test\" is activated in config.php" : "Les tests de migration sont ignorés - \"update.skip-migration-test\" est activé dans config.php",
     "Turned on maintenance mode" : "Mode de maintenance activé",
     "Turned off maintenance mode" : "Mode de maintenance désactivé",
     "Maintenance mode is kept active" : "Le mode de maintenance est laissé actif",
+    "Updating database schema" : "Mise à jour du schéma de la base de données",
     "Updated database" : "Base de données mise à jour",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Vérification de la possibilité de mettre à jour le schéma de la base de données (cela peut prendre un certain temps selon la taille de la base de données)",
     "Checked database schema update" : "Mise à jour du schéma de la base de données vérifiée",
+    "Checking updates of apps" : "Recherche de mises à jour d'applications",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Vérification de la possibilité de mettre à jour le schéma de la base de données pour %s (cela peut prendre un certain temps selon la taille de la base de données)",
     "Checked database schema update for apps" : "Mise à jour du schéma de la base de données pour les applications vérifiée",
     "Updated \"%s\" to %s" : "Mise à jour de « %s » vers %s",
     "Repair warning: " : "Avertissement de réparation :",
     "Repair error: " : "Erreur de réparation :",
-    "Set log level to debug - current level: \"%s\"" : "Réglage du niveau de log à \"debug\" - niveau actuel: \"%s\"",
-    "Reset log level to  \"%s\"" : "Réglage du niveau de log à \"%s\"",
-    "Following incompatible apps have been disabled: %s" : "Les applications incompatibles suivantes ont été désactivées : %s",
+    "Set log level to debug" : "Réglage du niveau de log à \"debug\"",
+    "Reset log level" : "Réinitialisation du niveau de journalisation",
+    "Starting code integrity check" : "Lancement de la vérification d'intégrité du code",
+    "Finished code integrity check" : "Fin de la vérification d’intégrité du code",
+    "%s (3rdparty)" : "%s (origine tierce)",
+    "%s (incompatible)" : "%s (non compatible)",
     "Following apps have been disabled: %s" : "Les applications suivantes ont été désactivées : %s",
     "Already up to date" : "Déjà à jour",
+    "Please select a file." : "Veuillez sélectionner un fichier.",
     "File is too big" : "Fichier trop volumineux",
     "Invalid file provided" : "Fichier non valide",
     "No image or file provided" : "Aucun fichier fourni",
     "Unknown filetype" : "Type de fichier inconnu",
     "Invalid image" : "Image non valable",
+    "An error occurred. Please contact your admin." : "Une erreur est survenue. Veuillez contacter votre administrateur.",
     "No temporary profile picture available, try again" : "Aucune image temporaire disponible pour le profil. Essayez à nouveau.",
     "No crop data provided" : "Aucune donnée de recadrage fournie",
     "No valid crop data provided" : "Données de recadrage non valides",
     "Crop is not square" : "Le recadrage n'est pas carré",
+    "Couldn't reset password because the token is invalid" : "Impossible de réinitialiser le mot de passe car le jeton n'est pas valable.",
+    "Couldn't reset password because the token is expired" : "Impossible de réinitialiser le mot de passe car le jeton a expiré.",
+    "Couldn't send reset email. Please make sure your username is correct." : "Impossible d'envoyer le courriel de réinitialisation. Veuillez vérifier que votre nom d'utilisateur est correct.",
+    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Impossible d'envoyer le courriel de réinitialisation car il n'y a aucune adresse de courriel pour cet utilisateur. Veuillez contacter votre administrateur.",
+    "%s password reset" : "Réinitialisation de votre mot de passe %s",
+    "Couldn't send reset email. Please contact your administrator." : "Impossible d'envoyer le courriel de réinitialisation. Veuillez contacter votre administrateur.",
     "Sunday" : "Dimanche",
     "Monday" : "Lundi",
     "Tuesday" : "Mardi",
@@ -72,10 +86,11 @@ OC.L10N.register(
     "Oct." : "Oct.",
     "Nov." : "Nov.",
     "Dec." : "Déc.",
+    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Il y a eu des problèmes à la vérification d’intégrité du code. Plus d'infos...</a>",
     "Settings" : "Paramètres",
     "Saving..." : "Enregistrement…",
+    "Dismiss" : "Ignorer",
     "seconds ago" : "à l'instant",
-    "Couldn't send reset email. Please contact your administrator." : "Impossible d'envoyer le courriel de réinitialisation. Veuillez contacter votre administrateur.",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Un lien permettant de réinitialiser votre mot de passe vient de vous être envoyé par courriel.<br>Si vous ne le recevez pas dans un délai raisonnable, contactez votre administrateur.<br>N'oubliez pas de vérifier dans votre dossier pourriel / spam!",
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Vos fichiers sont chiffrés. Si vous n'avez pas activé la clef de récupération, il n'y aura aucun moyen de récupérer vos données une fois le mot de passe réinitialisé.<br />Si vous n'êtes pas sûr de ce que vous faites, veuillez contacter votre administrateur avant de continuer. <br />Voulez-vous vraiment continuer ?",
     "I know what I'm doing" : "Je sais ce que je fais",
@@ -104,27 +119,29 @@ OC.L10N.register(
     "Good password" : "Mot de passe de sécurité suffisante",
     "Strong password" : "Mot de passe fort",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Votre serveur web n'est pas correctement configuré pour la synchronisation de fichiers : l'interface WebDAV semble ne pas fonctionner.",
+    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "La configuration du serveur web ne permet pas d'atteindre \"{url}\". Consultez la <a target=\"_blank\" href=\"{docLink}\">documentation</a> pour avoir plus d'informations à ce sujet.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Ce serveur ne peut se connecter à internet. Cela signifie que certaines fonctionnalités, telles que le montage de supports de stockage distants, les notifications de mises à jour ou l'installation d'applications tierces ne fonctionneront pas. L'accès aux fichiers à distance, ainsi que les notifications par mail peuvent aussi être indisponibles. Il est recommandé d'activer la connexion internet pour ce serveur si vous souhaitez disposer de l'ensemble des fonctionnalités offertes.",
-    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Votre dossier de données et vos fichiers sont probablement accessibles depuis internet. Le fichier .htaccess ne fonctionne pas. Nous vous recommandons vivement de configurer votre serveur web de façon à ce que ce dossier de données ne soit plus accessible, ou de le déplacer hors de la racine du serveur web.",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "Aucun cache de la mémoire n'est configuré. Si possible, configurez un \"memcache\" pour augmenter les performances. Pour plus d'information consultez la <a href=\"{docLink}\">documentation</a>.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "/dev/urandom n'est pas lisible par PHP, ce qui est fortement déconseillé pour des raisons de sécurité. Plus d'informations peuvent être trouvées dans notre <a href=\"{docLink}\">documentation</a>.",
-    "Your PHP version ({version}) is no longer <a href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "La version de PHP utilisée ({version}) <a href=\"{phpLink}\">n'est plus prise en charge par les créateurs de PHP</a>. Nous vous recommandons de mettre à niveau votre installation de PHP pour bénéficier de meilleures performances et des mises à jour de sécurité fournies par PHP.",
-    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "La configuration des headers du reverse proxy est incorrecte, ou vous accédez ownCloud depuis un proxy de confiance. Si vous n'êtes pas en train d’accéder à ownCloud depuis un proxy de confiance, ceci est un problème de sécurité qui peut permettre à un attaquant de masquer sa véritable adresse IP. <a href=\"{docLink}\">Plus d'info dans la documentation.</a>",
+    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Aucun cache mémoire n'est configuré. Si possible, configurez un cache pour augmenter les performances. Consultez la <a target=\"_blank\" href=\"{docLink}\">documentation</a> pour avoir plus d'informations à ce sujet.",
+    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "/dev/urandom n'est pas lisible par PHP, ce qui est fortement déconseillé pour des raisons de sécurité. Consultez la <a target=\"_blank\" href=\"{docLink}\">documentation</a> pour avoir plus d'informations à ce sujet.",
+    "Your PHP version ({version}) is no longer <a target=\"_blank\" href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "Votre version de PHP ({version}) <a target=\"_blank\" href=\"{phpLink}\">n'est plus prise en charge par les créateurs de PHP</a>. Nous vous recommandons de mettre à niveau votre installation de PHP pour bénéficier de meilleures performances et des mises à jour de sécurité fournies par PHP.",
+    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "La configuration des entêtes du proxy inverse est incorrecte, ou vous accédez à ownCloud depuis un proxy de confiance. Si vous n'êtes pas en train d’accéder à ownCloud depuis un proxy de confiance, ceci est un problème de sécurité qui peut permettre à un attaquant de masquer sa véritable adresse IP. Consultez la <a target=\"_blank\" href=\"{docLink}\">documentation</a> pour avoir plus d'informations à ce sujet.",
+    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "\"memcached\" est configuré comme cache distribué, mais  le module installé est \"memcache\".  \\OC\\Memcache\\Memcached ne prend en charge que \"memcached\" et non \"memcache\". <a target=\"_blank\" href=\"{wikiLink}\">Consulter le wiki de memcached à propos de ces deux modules.</a>",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Des fichiers n'ont pas passé la vérification d’intégrité. \nConsultez la <a target=\"_blank\" href=\"{docLink}\">documentation</a> pour avoir plus d'informations sur comment résoudre ce problème. \n(<a target=\"_blank\" href=\"{codeIntegrityDownloadEndpoint}\">Liste des fichiers non valides…</a> / <a href=\"{rescanEndpoint}\">Relancer…</a>)",
     "Error occurred while checking server setup" : "Une erreur s'est produite lors de la vérification de la configuration du serveur",
+    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Votre dossier de données et vos fichiers sont probablement accessibles depuis internet. Le fichier .htaccess ne fonctionne pas. Nous vous recommandons vivement de configurer votre serveur web de façon à ce que ce dossier de données ne soit plus accessible, ou de le déplacer hors de la racine du serveur web.",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "L'en-tête HTTP \"{header}\" n'est pas configurée pour être égale à \"{expected}\" créant potentiellement un risque relié à la sécurité et à la vie privée. Il est donc recommandé d'ajuster ce paramètre.",
-    "The \"Strict-Transport-Security\" HTTP header is not configured to least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "L'en-tête HTTP \"Strict-Transport-Security\" n'est pas configurée à \"{seconds}\" secondes. Pour renforcer la sécurité nous recommandons d'activer HSTS comme décrit dans notre <a href=\"{docUrl}\">Guide pour le renforcement et la sécurité</a>.",
     "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Vous accédez à ce site via HTTP. Nous vous recommandons fortement de configurer votre serveur pour forcer l'utilisation de HTTPS, comme expliqué dans notre <a href=\"{docUrl}\">Guide pour le renforcement et la sécurité</a>.",
     "Shared" : "Partagé",
     "Shared with {recipients}" : "Partagé avec {recipients}",
     "Error" : "Erreur",
     "Error while sharing" : "Erreur lors de la mise en partage",
     "Error while unsharing" : "Erreur lors de l'annulation du partage",
-    "Error while changing permissions" : "Erreur lors du changement des permissions",
     "Error setting expiration date" : "Erreur lors de la spécification de la date d'expiration",
     "The public link will expire no later than {days} days after it is created" : "Ce lien public expirera au plus tard {days} jours après sa création.",
     "Set expiration date" : "Spécifier une date d'expiration",
     "Expiration" : "Expiration",
     "Expiration date" : "Date d'expiration",
+    "Choose a password for the public link" : "Choisissez un mot de passe pour le lien public",
     "Sending ..." : "Envoi…",
     "Email sent" : "Courriel envoyé",
     "Resharing is not allowed" : "Le repartage n'est pas autorisé",
@@ -132,13 +149,11 @@ OC.L10N.register(
     "Link" : "Lien",
     "Password protect" : "Protéger par un mot de passe",
     "Password" : "Mot de passe",
-    "Choose a password for the public link" : "Choisissez un mot de passe pour le lien public",
     "Allow editing" : "Permettre la modification",
     "Email link to person" : "Envoyer le lien par courriel",
     "Send" : "Envoyer",
     "Shared with you and the group {group} by {owner}" : "Partagé avec vous et le groupe {group} par {owner}",
     "Shared with you by {owner}" : "Partagé avec vous par {owner}",
-    "Shared in {item} with {user}" : "Partagé dans {item} avec {user}",
     "group" : "groupe",
     "remote" : "distant",
     "notify by email" : "notifier par courriel",
@@ -149,17 +164,28 @@ OC.L10N.register(
     "change" : "modification",
     "delete" : "suppression",
     "access control" : "contrôle d'accès",
+    "Could not unshare" : "Impossible d'arrêter de partager",
     "Share details could not be loaded for this item." : "Les informations de partage n'ont pu être chargées pour cet élément.",
+    "No users or groups found for {search}" : "Pas d'utilisateur ou de groupe trouvé pour {search}",
     "An error occured. Please try again" : "Une erreur est survenue. Merci de réessayer",
+    "{sharee} (group)" : "{sharee} (groupe)",
+    "{sharee} (at {server})" : "{sharee} (sur {server})",
+    "{sharee} (remote)" : "{sharee} (distant)",
     "Share" : "Partager",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Partagez avec des personnes sur d'autres ownClouds en utilisant la syntaxe utilisateur@exemple.com/owncloud",
     "Share with users or groups …" : "Partager avec des utilisateurs ou groupes...",
     "Share with users, groups or remote users …" : "Partager avec des utilisateurs, groupes, ou utilisateurs distants",
+    "Error removing share" : "Erreur lors de l'arrêt du partage",
     "Warning" : "Attention",
     "Error while sending notification" : "Erreur lors de l'envoi de la notification",
+    "Non-existing tag #{tag}" : "Étiquette #{tag} inexistante",
+    "not assignable" : "inassignable",
+    "invisible" : "invisible",
+    "({scope})" : "({scope})",
+    "Delete" : "Supprimer",
+    "Rename" : "Renommer",
     "The object type is not specified." : "Le type d'objet n'est pas spécifié.",
     "Enter new" : "Saisir un nouveau",
-    "Delete" : "Supprimer",
     "Add" : "Ajouter",
     "Edit tags" : "Modifier les étiquettes",
     "Error loading dialog template: {error}" : "Erreur lors du chargement du modèle de dialogue : {error}",
@@ -170,23 +196,17 @@ OC.L10N.register(
     "Hello {name}, the weather is {weather}" : "Bonjour {name}, le temps est {weather}",
     "Hello {name}" : "Hello {name}",
     "_download %n file_::_download %n files_" : ["Télécharger %n fichier","Télécharger %n fichiers"],
-    "{version} is available. Get more information on how to update." : "La version {version} est disponible. Cliquez ici pour plus d'informations à propos de cette mise à jour.",
+    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "La mise à jour est en cours. Selon la configuration, le fait de quitter cette page peut entraîner l'interruption de la procédure.",
     "Updating {productName} to version {version}, this may take a while." : "La mise à jour de {productName} vers la version {version} est en cours. Cela peut prendre un certain temps.",
+    "An error occurred." : "Une erreur est survenue.",
     "Please reload the page." : "Veuillez recharger la page.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "La mise à jour a échoué. Pour plus d'informations <a href=\"{url}\">consultez notre publication sur le forum</a> à propos de ce problème.",
     "The update was unsuccessful. " : "La mise à jour a échoué.",
     "The update was successful. There were warnings." : "La mise à jour a réussi, mais il y a eu des avertissements",
     "The update was successful. Redirecting you to ownCloud now." : "La mise à jour a réussi. Vous êtes maintenant redirigé vers ownCloud.",
-    "Couldn't reset password because the token is invalid" : "Impossible de réinitialiser le mot de passe car le jeton n'est pas valable.",
-    "Couldn't reset password because the token is expired" : "Impossible de réinitialiser le mot de passe car le jeton a expiré.",
-    "Couldn't send reset email. Please make sure your username is correct." : "Impossible d'envoyer le courriel de réinitialisation. Veuillez vérifier que votre nom d'utilisateur est correct.",
-    "Couldn't send reset email because there is no email address for this username. Please contact your administrator." : "Impossible d'envoyer le courriel de réinitialisation car il n'y a aucune adresse de courriel pour cet utilisateur. Veuillez contacter votre administrateur.",
-    "%s password reset" : "Réinitialisation de votre mot de passe %s",
-    "Use the following link to reset your password: {link}" : "Utilisez le lien suivant pour réinitialiser votre mot de passe : {link}",
-    "New password" : "Nouveau mot de passe",
-    "New Password" : "Nouveau mot de passe",
-    "Reset password" : "Réinitialiser le mot de passe",
     "Searching other places" : "Recherche en cours dans d'autres emplacements",
     "No search results in other folders" : "Aucun résultat dans d'autres dossiers",
+    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} résultat dans un autre dossier","{count} résultats dans d'autres dossiers"],
     "Personal" : "Personnel",
     "Users" : "Utilisateurs",
     "Apps" : "Applications",
@@ -243,6 +263,7 @@ OC.L10N.register(
     "Finishing …" : "Finalisation …",
     "Need help?" : "Besoin d'aide ?",
     "See the documentation" : "Lire la documentation",
+    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Bonjour,<br><br>Nous vous informons que %s a partagé <strong>%s</strong> avec vous.<br><a href=\"%s\">Cliquez ici pour y accéder !</a><br><br>",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Cette application requiert JavaScript pour fonctionner correctement. Veuillez {linkstart}activer JavaScript{linkend} et recharger la page.",
     "Log out" : "Se déconnecter",
     "Search" : "Rechercher",
@@ -252,15 +273,19 @@ OC.L10N.register(
     "Please try again or contact your administrator." : "Veuillez réessayer ou contacter votre administrateur.",
     "Log in" : "Se connecter",
     "Wrong password. Reset it?" : "Mot de passe incorrect. Réinitialiser ?",
-    "remember" : "se souvenir de moi",
+    "Wrong password." : "Mot de passe incorrect.",
+    "Stay logged in" : "Rester connecté",
     "Alternative Logins" : "Identifiants alternatifs",
-    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Bonjour,<br><br>Nous vous informons que %s a partagé <strong>%s</strong> avec vous.<br><a href=\"%s\">Cliquez ici pour y accéder !</a><br><br>",
+    "Use the following link to reset your password: {link}" : "Utilisez le lien suivant pour réinitialiser votre mot de passe : {link}",
+    "New password" : "Nouveau mot de passe",
+    "New Password" : "Nouveau mot de passe",
+    "Reset password" : "Réinitialiser le mot de passe",
     "This ownCloud instance is currently in single user mode." : "Cette instance de ownCloud est actuellement en mode utilisateur unique.",
     "This means only administrators can use the instance." : "Cela signifie que seuls les administrateurs peuvent utiliser l'instance.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Veuillez contacter votre administrateur système si ce message persiste ou apparaît de façon inattendue.",
     "Thank you for your patience." : "Merci de votre patience.",
     "You are accessing the server from an untrusted domain." : "Vous accédez au serveur à partir d'un domaine non approuvé.",
-    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domain\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Veuillez contacter votre administrateur. Si vous êtes administrateur de cette instance, configurez le paramètre « trusted_domain » dans le fichier config/config.php. Un exemple de configuration est fourni dans le fichier config/config.sample.php.",
+    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Veuillez contacter votre administrateur. Si vous être l'administrateur de cette instance, configurez la variable \"trusted_domains\" dans le fichier config/config.php. Un exemple de configuration est fournit dans le fichier config/config.sample.php.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "En fonction de votre configuration, en tant qu'administrateur vous pouvez également utiliser le bouton ci-dessous pour approuver ce domaine.",
     "Add \"%s\" as trusted domain" : "Ajouter \"%s\" à la liste des domaines approuvés",
     "App update required" : "Mise à jour de l'application nécessaire",
