@@ -3,30 +3,44 @@ OC.L10N.register(
     {
     "Couldn't send mail to following users: %s " : "Impossibile inviare email ai seguenti utenti: %s",
     "Preparing update" : "Preparazione aggiornamento",
-    "Migration tests are skipped - \"update.skip-migration-test\" is activated in config.php" : "I test di migrazione sono saltati - \"update.skip-migration-test\" è attivato in config.php",
     "Turned on maintenance mode" : "Modalità di manutenzione attivata",
     "Turned off maintenance mode" : "Modalità di manutenzione disattivata",
     "Maintenance mode is kept active" : "La modalità di manutenzione è lasciata attiva",
+    "Updating database schema" : "Aggiornamento schema database",
     "Updated database" : "Database aggiornato",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Controllo che lo schema del database possa essere aggiornato (ciò potrebbe richiedere molto tempo in base alla dimensione del database)",
     "Checked database schema update" : "Verificato l'aggiornamento dello schema del database",
+    "Checking updates of apps" : "Controllo degli aggiornamenti delle applicazioni",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Controllo che lo schema del database di %s possa essere aggiornato (ciò potrebbe richiedere molto tempo in base alla dimensione del database)",
     "Checked database schema update for apps" : "Verificato l'aggiornamento dello schema del database per le applicazioni",
     "Updated \"%s\" to %s" : "Aggiornato \"%s\" a %s",
     "Repair warning: " : "Avviso di riparazione",
     "Repair error: " : "Errore di riparazione:",
-    "Set log level to debug - current level: \"%s\"" : "Imposta il livello del log a debug - livello attuale: \"%s\"",
-    "Reset log level to  \"%s\"" : "Ripristina il livello del log a \"%s\"",
-    "Following incompatible apps have been disabled: %s" : "Le seguenti applicazioni incompatibili sono state disabilitate: %s",
+    "Set log level to debug" : "Imposta il livello del log a debug",
+    "Reset log level" : "Ripristina il livello del log",
+    "Starting code integrity check" : "Avvio del controllo di integrità del codice",
+    "Finished code integrity check" : "Controllo di integrità del codice terminato",
+    "%s (3rdparty)" : "%s (Terze parti)",
+    "%s (incompatible)" : "%s (incompatibile)",
     "Following apps have been disabled: %s" : "Le seguenti applicazioni sono state disabilitate: %s",
     "Already up to date" : "Già aggiornato",
+    "Please select a file." : "Seleziona un file.",
     "File is too big" : "Il file è troppo grande",
     "Invalid file provided" : "File non valido fornito",
     "No image or file provided" : "Non è stata fornita alcun immagine o file",
     "Unknown filetype" : "Tipo di file sconosciuto",
     "Invalid image" : "Immagine non valida",
+    "An error occurred. Please contact your admin." : "Si è verificato un errore. Contatta il tuo amministratore.",
     "No temporary profile picture available, try again" : "Nessuna immagine di profilo provvisoria disponibile, riprova",
     "No crop data provided" : "Non sono stati forniti dati di ritaglio",
     "No valid crop data provided" : "Non sono stati forniti dati di ritaglio validi",
     "Crop is not square" : "Il ritaglio non è quadrato",
+    "Couldn't reset password because the token is invalid" : "Impossibile reimpostare la password poiché il token non è valido",
+    "Couldn't reset password because the token is expired" : "Impossibile reimpostare la password poiché il token è scaduto",
+    "Couldn't send reset email. Please make sure your username is correct." : "Impossibile inviare l'email di reimpostazione. Assicurati che il nome utente sia corretto.",
+    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Impossibile inviare l'email di reimpostazione poiché non è presente un indirizzo email per questo nome utente. Contatta il tuo amministratore.",
+    "%s password reset" : "Ripristino password di %s",
+    "Couldn't send reset email. Please contact your administrator." : "Impossibile inviare l'email di reimpostazione. Contatta il tuo amministratore.",
     "Sunday" : "Domenica",
     "Monday" : "Lunedì",
     "Tuesday" : "Martedì",
@@ -72,10 +86,11 @@ OC.L10N.register(
     "Oct." : "Ott.",
     "Nov." : "Nov.",
     "Dec." : "Dic.",
+    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Si sono verificati errori con il controllo di integrità del codice. Ulteriori informazioni…</a>",
     "Settings" : "Impostazioni",
     "Saving..." : "Salvataggio in corso...",
+    "Dismiss" : "Annulla",
     "seconds ago" : "secondi fa",
-    "Couldn't send reset email. Please contact your administrator." : "Impossibile inviare l'email di reimpostazione. Contatta il tuo amministratore.",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Il collegamento per reimpostare la password è stato inviato al tuo indirizzo di posta. Se non lo ricevi in tempi ragionevoli, controlla le cartelle della posta indesiderata.<br>Se non dovesse essere nemmeno lì, contatta il tuo amministratore locale.",
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "I tuoi file sono cifrati. Se non hai precedentemente abilitato la chiave di ripristino, non sarà più possibile ritrovare i tuoi dati una volta che la password sarà reimpostata.<br />Se non sei sicuro, contatta l'amministratore prima di proseguire.<br />Vuoi davvero continuare?",
     "I know what I'm doing" : "So cosa sto facendo",
@@ -104,28 +119,30 @@ OC.L10N.register(
     "Good password" : "Password buona",
     "Strong password" : "Password forte",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Il tuo server web non è configurato correttamente per consentire la sincronizzazione dei file poiché l'interfaccia WebDAV sembra essere danneggiata.",
+    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Il tuo server web non è configurato correttamente per risolvere \"{url}\". Ulteriori informazioni sono disponibili nella nostra <a target=\"_blank\" href=\"{docLink}\">documentazione</a>.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Questo server non ha una connessione a Internet funzionante. Ciò significa che alcune delle funzionalità come il montaggio di archivi esterni, le notifiche degli aggiornamenti o l'installazione di applicazioni di terze parti non funzioneranno. L'accesso remoto ai file e l'invio di email di notifica potrebbero non funzionare. Ti suggeriamo di abilitare la connessione a Internet del server se desideri disporre di tutte le funzionalità.",
-    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "La cartella dei dati e i tuoi file sono probabilmente accessibili da Internet.\nIl file .htaccess non funziona. Ti consigliamo vivamente di configurare il server web in modo che la cartella dei dati non sia più accessibile o di spostare la cartella fuori dalla radice del server web.",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "Non è stata configurata alcuna cache di memoria. Per migliorare le prestazioni configura memcache, se disponibile. Ulteriori informazioni sono disponibili nella nostra <a href=\"{docLink}\">documentazione</a>.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "/dev/urandom non è leggibile da PHP e ciò è vivamente sconsigliato per motivi di sicurezza. Ulteriori informazioni sono disponibili nella nostra <a href=\"{docLink}\">documentazione</a>.",
-    "Your PHP version ({version}) is no longer <a href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "La tua versione ({version}) di PHP non è più <a href=\"{phpLink}\">supportata da PHP</a>. Ti esortiamo ad aggiornare la versione di PHP per trarre vantaggio dagli aggiornamenti in termini di prestazioni e sicurezza forniti da PHP.",
-    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "La configurazione delle intestazioni del proxy inverso non è corretta, o stai effettuando l'accesso a ownCloud da un proxy affidabile. Se non stai effettuando l'accesso da un proxy affidabile, questo è un problema di sicurezza e può consentire a un attaccante di falsificare il suo indirizzo IP, rendendo visibile a ownCloud. Ulteriori informazioni sono disponibili nella nostra <a href=\"{docLink}\">documentazione</a>.",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached è configurato come cache distribuita, ma è installato il modulo \"memcache\" errato. \\OC\\Memcache\\Memcached supporta solo \"memcached\" e non \"memcache\". Vedi il  <a href=\"{wikiLink}\">wiki di memcached per informazioni su entrambi i moduli</a>.",
+    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Non è stata configurata alcuna cache di memoria. Per migliorare le prestazioni, configura memcache, se disponibile. Ulteriori informazioni sono disponibili nella nostra <a target=\"_blank\" href=\"{docLink}\">documentazione</a>.",
+    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "/dev/urandom non è leggibile da PHP e ciò è vivamente sconsigliato per motivi di sicurezza. Ulteriori informazioni sono disponibili nella nostra <a target=\"_blank\" href=\"{docLink}\">documentazione</a>.",
+    "Your PHP version ({version}) is no longer <a target=\"_blank\" href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "La tua versione ({version}) di PHP non è più <a target=\"_blank\" href=\"{phpLink}\">supportata da PHP</a>. Ti consigliamo di aggiornare la versione di PHP per trarre vantaggio dagli aggiornamenti in termini di prestazioni e sicurezza forniti da PHP.",
+    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "La configurazione delle intestazioni del proxy inverso non è corretta, o stai effettuando l'accesso a ownCloud da un proxy affidabile. Se non stai effettuando l'accesso da un proxy affidabile, questo è un problema di sicurezza e può consentire a un attaccante di falsificare il suo indirizzo IP, rendendo visibile a ownCloud. Ulteriori informazioni sono disponibili nella nostra <a target=\"_blank\" href=\"{docLink}\">documentazione</a>.",
+    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached è configurato come cache distribuita, ma è installato il modulo \"memcache\" errato. \\OC\\Memcache\\Memcached supporta solo \"memcached\" e non \"memcache\". Vedi il  <a target=\"_blank\" href=\"{wikiLink}\">wiki di memcached per informazioni su entrambi i moduli</a>.",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Alcuni file non hanno superato il controllo di integrità. Ulteriori informazioni su come risolvere questo problema sono disponibili nella nostra <a target=\"_blank\" href=\"{docLink}\">documentazione</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Elenco dei file non validi…</a> / <a href=\"{rescanEndpoint}\">Nuova scansione…</a>)",
     "Error occurred while checking server setup" : "Si è verificato un errore durante il controllo della configurazione del server",
+    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "La cartella dei dati e i tuoi file sono probabilmente accessibili da Internet.\nIl file .htaccess non funziona. Ti consigliamo vivamente di configurare il server web in modo che la cartella dei dati non sia più accessibile o di spostare la cartella fuori dalla radice del server web.",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "L'intestazione HTTP \"{header}\" non è configurata come \"{expected}\". \nQuesto è un potenziale rischio di sicurezza o di riservatezza dei dati e noi consigliamo di modificare questa impostazione.",
-    "The \"Strict-Transport-Security\" HTTP header is not configured to least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "L'intestazione HTTP \"Strict-Transport-Security\" non è configurata con un valore almeno di \"{seconds}\" secondi. Per migliorare la sicurezza, consigliamo di abilitare HSTS come descritto nei nostri <a href=\"{docUrl}\">consigli sulla sicurezza</a>.",
+    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "L'intestazione HTTP \"Strict-Transport-Security\" non è configurata con un valore di almeno \"{seconds}\" secondi. Per migliorare la sicurezza, consigliamo di abilitare HSTS come descritto nei nostri <a href=\"{docUrl}\">consigli sulla sicurezza</a>.",
     "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Sei connesso a questo sito tramite HTTP. Ti suggeriamo vivamente di configurare il tuo server per richiedere invece l'utilizzo del protocollo HTTPS, come descritto nei nostri <a href=\"{docUrl}\">consigli sulla sicurezza</a>.",
     "Shared" : "Condiviso",
     "Shared with {recipients}" : "Condiviso con {recipients}",
     "Error" : "Errore",
     "Error while sharing" : "Errore durante la condivisione",
     "Error while unsharing" : "Errore durante la rimozione della condivisione",
-    "Error while changing permissions" : "Errore durante la modifica dei permessi",
     "Error setting expiration date" : "Errore durante l'impostazione della data di scadenza",
     "The public link will expire no later than {days} days after it is created" : "Il collegamento pubblico scadrà non più tardi di {days} giorni dopo la sua creazione",
     "Set expiration date" : "Imposta data di scadenza",
     "Expiration" : "Scadenza",
     "Expiration date" : "Data di scadenza",
+    "Choose a password for the public link" : "Scegli una password per il collegamento pubblico",
     "Sending ..." : "Invio in corso...",
     "Email sent" : "Messaggio inviato",
     "Resharing is not allowed" : "La ri-condivisione non è consentita",
@@ -133,13 +150,11 @@ OC.L10N.register(
     "Link" : "Collegamento",
     "Password protect" : "Proteggi con password",
     "Password" : "Password",
-    "Choose a password for the public link" : "Scegli una password per il collegamento pubblico",
     "Allow editing" : "Consenti la modifica",
     "Email link to person" : "Invia collegamento via email",
     "Send" : "Invia",
     "Shared with you and the group {group} by {owner}" : "Condiviso con te e con il gruppo {group} da {owner}",
     "Shared with you by {owner}" : "Condiviso con te da {owner}",
-    "Shared in {item} with {user}" : "Condiviso in {item} con {user}",
     "group" : "gruppo",
     "remote" : "remota",
     "notify by email" : "notifica tramite email",
@@ -150,17 +165,29 @@ OC.L10N.register(
     "change" : "cambia",
     "delete" : "elimina",
     "access control" : "controllo d'accesso",
+    "Could not unshare" : "Impossibile rimuovere la condivisione",
     "Share details could not be loaded for this item." : "I dettagli della condivisione non possono essere caricati per questo elemento.",
+    "No users or groups found for {search}" : "Nessun utente o gruppo trovato per {search}",
     "An error occured. Please try again" : "Si è verificato un errore. Prova ancora",
+    "{sharee} (group)" : "{sharee} (group)",
+    "{sharee} (at {server})" : "{sharee} (su {server})",
+    "{sharee} (remote)" : "{sharee} (remote)",
     "Share" : "Condividi",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Condividi con persone su altri ownCloud utilizzando la sintassi nomeutente@esempio.com/owncloud",
     "Share with users or groups …" : "Condividi con utenti o gruppi...",
     "Share with users, groups or remote users …" : "Condividi con utenti, gruppi o utenti remoti...",
+    "Error removing share" : "Errore durante la rimozione della condivisione",
     "Warning" : "Avviso",
     "Error while sending notification" : "Errore durante l'invio della notifica",
+    "Non-existing tag #{tag}" : "Etichetta #{tag} inesistente",
+    "not assignable" : "non assegnabile",
+    "invisible" : "invisibile",
+    "({scope})" : "({scope})",
+    "Delete" : "Elimina",
+    "Rename" : "Rinomina",
+    "Collaborative tags" : "Etichette collaborative",
     "The object type is not specified." : "Il tipo di oggetto non è specificato.",
     "Enter new" : "Inserisci nuovo",
-    "Delete" : "Elimina",
     "Add" : "Aggiungi",
     "Edit tags" : "Modifica etichette",
     "Error loading dialog template: {error}" : "Errore durante il caricamento del modello di finestra: {error}",
@@ -171,21 +198,14 @@ OC.L10N.register(
     "Hello {name}, the weather is {weather}" : "Ciao {name}, il tempo è {weather}",
     "Hello {name}" : "Ciao {name}",
     "_download %n file_::_download %n files_" : ["scarica %n file","scarica %s file"],
-    "{version} is available. Get more information on how to update." : "{version} è disponibile. Ottieni ulteriori informazioni su come eseguire l'aggiornamento.",
+    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "L'aggiornamento è in corso, l'abbandono di questa pagina potrebbe interrompere il processo in alcuni ambienti.",
     "Updating {productName} to version {version}, this may take a while." : "Aggiornamento di {productName} alla versione {version}, potrebbe richiedere del tempo.",
+    "An error occurred." : "Si è verificato un errore.",
     "Please reload the page." : "Ricarica la pagina.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "L'aggiornamento non è riuscito. Per ulteriori informazioni <a href=\"{url}\">controlla l'articolo del nostro forum</a> che riguarda questo problema.",
     "The update was unsuccessful. " : "L'aggiornamento non è riuscito.",
     "The update was successful. There were warnings." : "L'aggiornamento è stato effettuato correttamente. Ci sono degli avvisi.",
     "The update was successful. Redirecting you to ownCloud now." : "L'aggiornamento è stato effettuato correttamente. Stai per essere reindirizzato a ownCloud.",
-    "Couldn't reset password because the token is invalid" : "Impossibile reimpostare la password poiché il token non è valido",
-    "Couldn't reset password because the token is expired" : "Impossibile reimpostare la password poiché il token è scaduto",
-    "Couldn't send reset email. Please make sure your username is correct." : "Impossibile inviare l'email di reimpostazione. Assicurati che il nome utente sia corretto.",
-    "Couldn't send reset email because there is no email address for this username. Please contact your administrator." : "Impossibile inviare l'email di reimpostazione poiché non è presente un indirizzo email per questo nome utente. Contatta il tuo amministratore.",
-    "%s password reset" : "Ripristino password di %s",
-    "Use the following link to reset your password: {link}" : "Usa il collegamento seguente per ripristinare la password: {link}",
-    "New password" : "Nuova password",
-    "New Password" : "Nuova password",
-    "Reset password" : "Ripristina la password",
     "Searching other places" : "Ricerca in altre posizioni",
     "No search results in other folders" : "Nessun risultato di ricerca in altre cartelle",
     "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} risultato di ricerca in altre cartelle","{count} risultati di ricerca in altre cartelle"],
@@ -245,6 +265,7 @@ OC.L10N.register(
     "Finishing …" : "Completamento...",
     "Need help?" : "Ti serve aiuto?",
     "See the documentation" : "Leggi la documentazione",
+    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Ciao,<br><br>volevo informarti che %s ha condiviso <strong>%s</strong> con te.<br><a href=\"%s\">Guarda!</a><br><br>",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Questa applicazione richiede JavaScript per un corretto funzionamento. {linkstart}Abilita JavaScript{linkend} e ricarica la pagina.",
     "Log out" : "Esci",
     "Search" : "Cerca",
@@ -254,15 +275,19 @@ OC.L10N.register(
     "Please try again or contact your administrator." : "Prova ancora o contatta il tuo amministratore.",
     "Log in" : "Accedi",
     "Wrong password. Reset it?" : "Password errata. Vuoi reimpostarla?",
-    "remember" : "ricorda",
+    "Wrong password." : "Password errata.",
+    "Stay logged in" : "Rimani collegato",
     "Alternative Logins" : "Accessi alternativi",
-    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Ciao,<br><br>volevo informarti che %s ha condiviso <strong>%s</strong> con te.<br><a href=\"%s\">Guarda!</a><br><br>",
+    "Use the following link to reset your password: {link}" : "Usa il collegamento seguente per ripristinare la password: {link}",
+    "New password" : "Nuova password",
+    "New Password" : "Nuova password",
+    "Reset password" : "Ripristina la password",
     "This ownCloud instance is currently in single user mode." : "Questa istanza di ownCloud è in modalità utente singolo.",
     "This means only administrators can use the instance." : "Ciò significa che solo gli amministratori possono utilizzare l'istanza.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contatta il tuo amministratore di sistema se questo messaggio persiste o appare inaspettatamente.",
     "Thank you for your patience." : "Grazie per la pazienza.",
     "You are accessing the server from an untrusted domain." : "Stai accedendo al server da un dominio non attendibile.",
-    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domain\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Contatta il tuo amministratore di sistema. Se sei un amministratore di questa istanza, configura l'impostazione \"trusted_domain\" in config/config.php. Un esempio di configurazione è disponibile in config/config.sample.php.",
+    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Contatta il tuo amministratore di sistema. Se sei un amministratore di questa istanza, configura l'impostazione \"trusted_domains\" in config/config.php. Una configurazione di esempio è disponibile in config/config.sample.php.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "In base alla tua configurazione, come amministratore potrai utilizzare anche il pulsante in basso per rendere attendibile questo dominio.",
     "Add \"%s\" as trusted domain" : "Aggiungi \"%s\" come dominio attendibile",
     "App update required" : "Aggiornamento dell'applicazione richiesto",
