@@ -2,26 +2,45 @@ OC.L10N.register(
     "core",
     {
     "Couldn't send mail to following users: %s " : "次のユーザーにメールを送信できませんでした: %s",
+    "Preparing update" : "アップデートの準備中",
     "Turned on maintenance mode" : "メンテナンスモードがオンになりました",
     "Turned off maintenance mode" : "メンテナンスモードがオフになりました",
     "Maintenance mode is kept active" : "メンテナンスモードが継続中です",
+    "Updating database schema" : "データベースのスキーマを更新",
     "Updated database" : "データベース更新済み",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "データベーススキーマーがアップデートできるかどうかチェックしています。(この操作の時間はデータベースの容量によります)",
     "Checked database schema update" : "指定データベースのスキーマを更新",
+    "Checking updates of apps" : "アプリの更新をチェックしています。",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "データベーススキーマー %s がアップデートできるかどうかチェックしています。(この操作の時間はデータベースの容量によります)",
     "Checked database schema update for apps" : "アプリの指定データベースのスキーマを更新",
     "Updated \"%s\" to %s" : "\"%s\" を %s にアップデートしました。",
     "Repair warning: " : "修復警告:",
     "Repair error: " : "修復エラー:",
-    "Following incompatible apps have been disabled: %s" : "次の互換性のないアプリは無効にされています: %s",
+    "Set log level to debug" : "ログをデバッグレベルに設定",
+    "Reset log level" : "ログレベルをリセット",
+    "Starting code integrity check" : "コード整合性の確認を開始",
+    "Finished code integrity check" : "コード整合性の確認が終了",
+    "%s (3rdparty)" : "%s (サードパーティー)",
+    "%s (incompatible)" : "%s (非互換)",
     "Following apps have been disabled: %s" : "以下のアプリが無効にされています: %s",
+    "Already up to date" : "すべて更新済",
+    "Please select a file." : "ファイルを選択してください。",
     "File is too big" : "ファイルが大きすぎます",
     "Invalid file provided" : "無効なファイルが提供されました",
     "No image or file provided" : "画像もしくはファイルが提供されていません",
     "Unknown filetype" : "不明なファイルタイプ",
     "Invalid image" : "無効な画像",
+    "An error occurred. Please contact your admin." : "エラーが発生しました。管理者に連絡してください。",
     "No temporary profile picture available, try again" : "一時的なプロファイル用画像が利用できません。もう一度試してください",
     "No crop data provided" : "クロップデータは提供されません",
     "No valid crop data provided" : "有効なクロップデータは提供されません",
     "Crop is not square" : "クロップが正方形ではありません",
+    "Couldn't reset password because the token is invalid" : "トークンが無効なため、パスワードをリセットできませんでした",
+    "Couldn't reset password because the token is expired" : "トークンが期限切れのため、パスワードをリセットできませんでした",
+    "Couldn't send reset email. Please make sure your username is correct." : "リセットメールを送信できませんでした。ユーザー名が正しいことを確認してください。",
+    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "このユーザー名に紐付けられたメールアドレスがないため、リセットメールを送信できませんでした。管理者に問い合わせてください。",
+    "%s password reset" : "%s パスワードリセット",
+    "Couldn't send reset email. Please contact your administrator." : "リセットメールを送信できませんでした。管理者に問い合わせてください。",
     "Sunday" : "日",
     "Monday" : "月",
     "Tuesday" : "火",
@@ -67,10 +86,11 @@ OC.L10N.register(
     "Oct." : "10月",
     "Nov." : "11月",
     "Dec." : "12月",
+    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">コード整合性の確認で問題が発生しました。詳しくはこちら…</a>",
     "Settings" : "設定",
     "Saving..." : "保存中...",
+    "Dismiss" : "閉じる",
     "seconds ago" : "数秒前",
-    "Couldn't send reset email. Please contact your administrator." : "リセットメールを送信できませんでした。管理者に問い合わせてください。",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "パスワードをリセットするリンクをクリックしたので、メールを送信しました。しばらくたってもメールが届かなかった場合は、スパム/ジャンクフォルダーを確認してください。<br>それでも見つからなかった場合は、管理者に問合わせてください。",
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "ファイルが暗号化されています。リカバリーキーが有効でない場合は、パスワードをリセットした後にあなたのデータを元に戻す方法はありません。<br />どういうことか分からない場合は、操作を継続する前に管理者に問い合わせてください。<br />続けてよろしいでしょうか?",
     "I know what I'm doing" : "どういう操作をしているか理解しています",
@@ -99,27 +119,30 @@ OC.L10N.register(
     "Good password" : "良好なパスワード",
     "Strong password" : "強いパスワード",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "WebDAVインターフェースが動作していないようです。Webサーバーは、ファイルの同期を許可するよう適切に設定されていません。",
+    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Webサーバーは適切に\"{url}\"を解決するように設定されていません.より詳しい情報については、<a target=\"_blank\" href=\"{docLink}\">ドキュメント</a> を参照ください。",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "このサーバーはインターネットに接続していません。この場合、外部ストレージのマウント、更新の通知やサードパーティ製のアプリ、といった一部の機能が利用できません。また、リモート接続でのファイルアクセス、通知メールの送信のような機能も利用できないことがあります。すべての機能を利用するには、このサーバーのインターネット接続を有効にすることをお勧めします。",
-    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "データディレクトリとファイルがインターネットからアクセス可能になっている可能性があります。.htaccessファイルが機能していません。データディレクトリがアクセスされないようにWebサーバーを設定するか、Webサーバーのドキュメントルートからデータディレクトリを移動するように強くお勧めします。",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "メモリキャッシュが設定されていません。パフォーマンスを向上するために、可能であれば memcache を設定してください。 より詳しい情報については、<a href=\"{docLink}\">documentation</a> を参照してください。",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "/dev/urandom は PHP から読み取ることができず、この状態はセキュリティの観点からおすすめできません。より詳しい情報については、<a href=\"{docLink}\">documentation</a> を参照ください。",
-    "Your PHP version ({version}) is no longer <a href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "ご利用のPHPのバージョン ({version}) は、<a href=\"{phpLink}\">PHPでサポート</a> されていません。 我々は、PHPから提供されている新しいバージョンにアップグレードし、それによるセキュリティの確保とパフォーマンスのメリットを受けられることを強くお勧めします。",
-    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "リバースプロキシーのヘッダー設定が間違っているか、または信頼されたプロキシーからownCloudにアクセスしていません。もし、信頼されたプロキシーからアクセスしているのでないなら、セキュリティに問題があり、ownCloudを詐称したIPアドレスから攻撃者に対して見えるよう許可していることになります。詳細な情報は、<a href=\"{docLink}\">ドキュメント</a>を確認してください。",
+    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "メモリキャッシュが設定されていません。パフォーマンスを向上するために、可能であれば memcache を設定してください。 より詳しい情報については、<a target=\"_blank\" href=\"{docLink}\">ドキュメント</a> を参照してください。",
+    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "/dev/urandom は PHP から読み取ることができず、この状態はセキュリティの観点からおすすめできません。より詳しい情報については、<a target=\"_blank\" href=\"{docLink}\">ドキュメント</a> を参照ください。",
+    "Your PHP version ({version}) is no longer <a target=\"_blank\" href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "ご利用のPHPのバージョン ({version}) は、<a target=\"_blank\" href=\"{phpLink}\">PHPでサポート</a> されていません。セキュリティ確保とパフォーマンス向上のために、PHPから提供されている新しいバージョンにアップグレードすることを強くお勧めします。",
+    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "リバースプロキシのヘッダー設定が間違っているか、または信頼されたプロキシからownCloudにアクセスしていません。もし、信頼されたプロキシからアクセスしているのでないなら、セキュリティに問題があり、ownCloudを詐称したIPアドレスから攻撃者に対して見えるよう許可していることになります。詳細な情報は、 <a target=\"_blank\" href=\"{docLink}\">ドキュメント</a>を確認してください。",
+    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached は分散キャッシュとして設定されています。しかし、PHPモジュール \"memcache\"が間違ってインストールされています。  \\OC\\Memcache\\Memcached は、\"memcached\" のみをサポートしています。\"memcache\" ではありません。<a target=\"_blank\" href=\"{wikiLink}\">memcached wiki で両方のモジュール</a> について確認してください。",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "いくつかのファイルで整合性の確認に失敗しました。この問題を解決するための詳細情報は<a target=\"_blank\" href=\"{docLink}\">ドキュメント</a>にあります｡ (<a href=\"{codeIntegrityDownloadEndpoint}\">不適正なファイルのリスト…</a> / <a href=\"{rescanEndpoint}\">再スキャン…</a>)",
     "Error occurred while checking server setup" : "サーバー設定のチェック中にエラーが発生しました",
+    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "データディレクトリとファイルがインターネットからアクセス可能になっている可能性があります。.htaccessファイルが機能していません。データディレクトリがアクセスされないようにWebサーバーを設定するか、Webサーバーのドキュメントルートからデータディレクトリを移動するように強くお勧めします。",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "\"{header}\" HTTP ヘッダは \"{expected}\" に設定されていません。これは潜在的なセキュリティリスクもしくはプライバシーリスクとなる可能性があるため、この設定を見直すことをおすすめします。",
-    "The \"Strict-Transport-Security\" HTTP header is not configured to least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "\"Strict-Transport-Security\" HTTP ヘッダが最小値の \"{seconds}\" 秒に設定されていません。 セキュリティを強化するため、<a href=\"{docUrl}\">security tips</a>を参照して、HSTS を有効にすることをおすすめします。",
+    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "\"Strict-Transport-Security\" HTTP ヘッダが最小値の \"{seconds}\" 秒に設定されていません。 セキュリティを強化するため、<a href=\"{docUrl}\">セキュリティのコツ</a>を参照して、HSTS を有効にすることをおすすめします。",
     "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "HTTP経由でアクセスしています。<a href=\"{docUrl}\">security tips</a>を参照して、代わりにHTTPSを使用するようサーバーを設定することを強くおすすめします。 instead as described in our .",
     "Shared" : "共有中",
     "Shared with {recipients}" : "{recipients} と共有",
     "Error" : "エラー",
     "Error while sharing" : "共有でエラー発生",
     "Error while unsharing" : "共有解除でエラー発生",
-    "Error while changing permissions" : "権限変更でエラー発生",
     "Error setting expiration date" : "有効期限の設定でエラー発生",
     "The public link will expire no later than {days} days after it is created" : "URLによる共有は、作成してから {days} 日以内に有効期限切れになります",
     "Set expiration date" : "有効期限を設定",
     "Expiration" : "期限切れ",
     "Expiration date" : "有効期限",
+    "Choose a password for the public link" : "URLによる共有のパスワードを入力",
     "Sending ..." : "送信中...",
     "Email sent" : "メールを送信しました",
     "Resharing is not allowed" : "再共有は許可されていません",
@@ -127,13 +150,11 @@ OC.L10N.register(
     "Link" : "リンク",
     "Password protect" : "パスワード保護を有効化",
     "Password" : "パスワード",
-    "Choose a password for the public link" : "URLによる共有のパスワードを入力",
-    "Allow editing" : "編集許可",
+    "Allow editing" : "編集を許可",
     "Email link to person" : "メールリンク",
     "Send" : "送信",
     "Shared with you and the group {group} by {owner}" : "あなたと {owner} のグループ {group} で共有中",
     "Shared with you by {owner}" : "{owner} と共有中",
-    "Shared in {item} with {user}" : "{item} 内で {user} と共有中",
     "group" : "グループ",
     "remote" : "リモート",
     "notify by email" : "メールで通知",
@@ -144,15 +165,29 @@ OC.L10N.register(
     "change" : "更新",
     "delete" : "削除",
     "access control" : "アクセス権限",
+    "Could not unshare" : "共有の解除ができませんでした",
+    "Share details could not be loaded for this item." : "共有の詳細はこのアイテムによりロードできませんでした。",
+    "No users or groups found for {search}" : "{search} の検索でユーザー、グループが見つかりません",
     "An error occured. Please try again" : "エラーが発生しました。もう一度トライしてください。",
+    "{sharee} (group)" : "{sharee} (グループ)",
+    "{sharee} (at {server})" : "{sharee} ({server} で)",
+    "{sharee} (remote)" : "{sharee} (リモート)",
     "Share" : "共有",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "次の形式で指定して他のownCloudのユーザーと、共有",
     "Share with users or groups …" : "ユーザーもしくはグループと共有 ...",
     "Share with users, groups or remote users …" : "ユーザー、グループもしくはリモートユーザーと共有 ...",
+    "Error removing share" : "共有の削除エラー",
     "Warning" : "警告",
+    "Error while sending notification" : "通知送信中にエラーが発生",
+    "Non-existing tag #{tag}" : "存在しないタグ#{tag}",
+    "not assignable" : "割り当てできない",
+    "invisible" : "不可視",
+    "({scope})" : "({scope})",
+    "Delete" : "削除",
+    "Rename" : "名前の変更",
+    "Collaborative tags" : "コラボタグ",
     "The object type is not specified." : "オブジェクトタイプが指定されていません。",
     "Enter new" : "新規に入力",
-    "Delete" : "削除",
     "Add" : "追加",
     "Edit tags" : "タグを編集",
     "Error loading dialog template: {error}" : "メッセージテンプレートの読み込みエラー: {error}",
@@ -163,21 +198,17 @@ OC.L10N.register(
     "Hello {name}, the weather is {weather}" : "こんにちは､ {name}､ 天気は{weather}です",
     "Hello {name}" : " {name}さん､こんにちは",
     "_download %n file_::_download %n files_" : ["%n個のファイルをダウンロード"],
-    "{version} is available. Get more information on how to update." : "{version} が利用可能です。アップデート方法について詳細情報を確認してください。",
+    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "アップグレード実行中です。このページを離れると、一部の環境では処理が中断されてしまうことがあります。",
     "Updating {productName} to version {version}, this may take a while." : "{productName} を バージョン {version} に更新しています。しばらくお待ちください。",
+    "An error occurred." : "エラーが発生しました。",
     "Please reload the page." : "ページをリロードしてください。",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "アップデートできませんでした。この問題に対する詳細な情報については、<a href=\"{url}\">フォーラムの投稿を確認してください</a> ",
     "The update was unsuccessful. " : "アップデートに失敗しました。",
     "The update was successful. There were warnings." : "アップデートは成功しました。警告がありました。",
     "The update was successful. Redirecting you to ownCloud now." : "アップデートに成功しました。今すぐownCloudにリダイレクトします。",
-    "Couldn't reset password because the token is invalid" : "トークンが無効なため、パスワードをリセットできませんでした",
-    "Couldn't send reset email. Please make sure your username is correct." : "リセットメールを送信できませんでした。ユーザー名が正しいことを確認してください。",
-    "Couldn't send reset email because there is no email address for this username. Please contact your administrator." : "このユーザー名に紐付けられたメールアドレスがないため、リセットメールを送信できませんでした。管理者に問い合わせてください。",
-    "%s password reset" : "%s パスワードリセット",
-    "Use the following link to reset your password: {link}" : "パスワードをリセットするには次のリンクをクリックしてください: {link}",
-    "New password" : "新しいパスワードを入力",
-    "New Password" : "新しいパスワード",
-    "Reset password" : "パスワードをリセット",
     "Searching other places" : "他の場所の検索",
+    "No search results in other folders" : "他のフォルダーの検索結果はありません",
+    "_{count} search result in another folder_::_{count} search results in other folders_" : ["他のフォルダーの検索件数 {count}"],
     "Personal" : "個人",
     "Users" : "ユーザー",
     "Apps" : "アプリ",
@@ -197,7 +228,7 @@ OC.L10N.register(
     "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "こんにちは、\n\n%s があなたと %s を共有したことをお知らせします。\nそれを表示: %s\n",
     "The share will expire on %s." : "共有は %s で有効期限が切れます。",
     "Cheers!" : "それでは！",
-    "Internal Server Error" : "内部サーバエラー",
+    "Internal Server Error" : "内部サーバーエラー",
     "The server encountered an internal error and was unable to complete your request." : "サーバー内でエラーが発生したため、リクエストを完了できませんでした。",
     "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "このエラーが繰り返し表示されるようであれば、以下の技術情報を添付してサーバー管理者に問い合わせてください。",
     "More details can be found in the server log." : "詳細は、サーバーのログを確認してください。",
@@ -234,6 +265,7 @@ OC.L10N.register(
     "Finishing …" : "作業を完了しています ...",
     "Need help?" : "ヘルプが必要ですか？",
     "See the documentation" : "ドキュメントを確認してください",
+    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "こんにちは、<br><br>%sがあなたと »%s« を共有したことをお知らせします。<br><a href=\"%s\">それを表示</a><br><br>",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "このアプリケーションの動作にはJavaScriptが必要です。\n {linkstart}JavaScriptを有効にし{linkend} 、ページを更新してください。 ",
     "Log out" : "ログアウト",
     "Search" : "検索",
@@ -243,20 +275,24 @@ OC.L10N.register(
     "Please try again or contact your administrator." : "もう一度試してみるか、管理者に問い合わせてください。",
     "Log in" : "ログイン",
     "Wrong password. Reset it?" : "パスワードが間違っています。リセットしますか？",
-    "remember" : "パスワードを保存",
+    "Wrong password." : "パスワードが間違っています。",
+    "Stay logged in" : "ログインしたままにする",
     "Alternative Logins" : "代替ログイン",
-    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "こんにちは、<br><br>%sがあなたと »%s« を共有したことをお知らせします。<br><a href=\"%s\">それを表示</a><br><br>",
+    "Use the following link to reset your password: {link}" : "パスワードをリセットするには次のリンクをクリックしてください: {link}",
+    "New password" : "新しいパスワードを入力",
+    "New Password" : "新しいパスワード",
+    "Reset password" : "パスワードをリセット",
     "This ownCloud instance is currently in single user mode." : "このownCloudインスタンスは、現在シングルユーザーモードです。",
     "This means only administrators can use the instance." : "これは、管理者のみがインスタンスを利用できることを意味しています。",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "このメッセージが引き続きもしくは予期せず現れる場合は、システム管理者に問い合わせてください。",
     "Thank you for your patience." : "しばらくお待ちください。",
     "You are accessing the server from an untrusted domain." : "信頼されていないドメインからサーバーにアクセスしています。",
-    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domain\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "管理者に問い合わせてください。このサーバーの管理者の場合は、\"trusted_domain\" の設定を config/config.php に設定してください。config/config.sample.php にサンプルの設定方法が記載してあります。",
+    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "管理者に問い合わせてください。このサーバーの管理者の場合は、\"trusted_domain\" の設定を config/config.php に設定してください。config/config.sample.php にサンプルの設定方法が記載してあります。",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "環境により、下のボタンで信頼するドメインに追加する必要があるかもしれません。",
     "Add \"%s\" as trusted domain" : "\"%s\" を信頼するドメイン名に追加",
     "App update required" : "アプリの更新が必要",
-    "%s will be updated to version %s" : "%s が %s バーションへ更新される",
-    "These apps will be updated:" : "次のアプリは更新される：",
+    "%s will be updated to version %s" : "%s は バーション %s にアップデートされます",
+    "These apps will be updated:" : "次のアプリはアップデートされます：",
     "These incompatible apps will be disabled:" : "次の非互換のないアプリは無効になる：",
     "The theme %s has been disabled." : "テーマ %s が無効になっています。",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "データベースを確認してください。実行前にconfigフォルダーとdataフォルダーをバックアップします。",
