@@ -3,19 +3,21 @@ OC.L10N.register(
     {
     "Couldn't send mail to following users: %s " : "%s 님에게 메일을 보낼 수 없습니다.",
     "Preparing update" : "업데이트 준비 중",
-    "Migration tests are skipped - \"update.skip-migration-test\" is activated in config.php" : "이전 작업 테스트를 건너뛰었습니다. config.php 파일에 \"update.skip-migration-test\"가 활성화되어 있습니다",
     "Turned on maintenance mode" : "유지 보수 모드 켜짐",
     "Turned off maintenance mode" : "유지 보수 모드 꺼짐",
     "Maintenance mode is kept active" : "유지 보수 모드가 켜져 있음",
+    "Updating database schema" : "데이터베이스 스키마 업데이트 중",
     "Updated database" : "데이터베이스 업데이트 됨",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "데이터베이스 스키마 업데이트 가능 여부 확인 중(데이터베이스 크기에 따라서 오래 걸릴 수도 있습니다)",
     "Checked database schema update" : "데이터베이스 스키마 업데이트 확인됨",
+    "Checking updates of apps" : "앱 업데이트 확인 중",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "%s의 데이터베이스 스키마 업데이트 가능 여부 확인 중(데이터베이스 크기에 따라서 오래 걸릴 수도 있습니다)",
     "Checked database schema update for apps" : "앱용 데이터베이스 스키마 업데이트 확인됨",
     "Updated \"%s\" to %s" : "\"%s\"을(를) %s(으)로 업데이트함",
     "Repair warning: " : "수리 경고:",
     "Repair error: " : "수리 오류:",
-    "Set log level to debug - current level: \"%s\"" : "로그 단계를 디버그로 설정함 - 현재 단계: \"%s\"",
-    "Reset log level to  \"%s\"" : "로그 단계를 \"%s\"(으)로 초기화",
-    "Following incompatible apps have been disabled: %s" : "다음 호환되지 않는 앱이 비활성화되었습니다: %s",
+    "%s (3rdparty)" : "%s(제 3사)",
+    "%s (incompatible)" : "%s(호환 불가)",
     "Following apps have been disabled: %s" : "다음 앱이 비활성화되었습니다: %s",
     "Already up to date" : "최신 상태임",
     "File is too big" : "파일이 너무 큼",
@@ -23,10 +25,16 @@ OC.L10N.register(
     "No image or file provided" : "사진이나 파일이 없음",
     "Unknown filetype" : "알려지지 않은 파일 형식",
     "Invalid image" : "잘못된 사진",
+    "An error occurred. Please contact your admin." : "오류가 발생했습니다. 시스템 관리자에게 연락하십시오.",
     "No temporary profile picture available, try again" : "사용 가능한 프로필 사진이 없습니다. 다시 시도하십시오.",
     "No crop data provided" : "선택된 데이터가 없습니다.",
     "No valid crop data provided" : "올바른 잘라내기 데이터가 지정되지 않음",
     "Crop is not square" : "잘라내는 영역이 사각형이 아님",
+    "Couldn't reset password because the token is invalid" : "토큰이 잘못되었기 때문에 암호를 초기화할 수 없습니다",
+    "Couldn't reset password because the token is expired" : "토큰이 만료되어 암호를 초기화할 수 없습니다",
+    "Couldn't send reset email. Please make sure your username is correct." : "재설정 메일을 보낼 수 없습니다. 사용자 이름이 올바른지 확인하십시오.",
+    "%s password reset" : "%s 암호 재설정",
+    "Couldn't send reset email. Please contact your administrator." : "재설정 메일을 보낼수 없습니다. 관리자에게 문의하십시오.",
     "Sunday" : "일요일",
     "Monday" : "월요일",
     "Tuesday" : "화요일",
@@ -74,8 +82,8 @@ OC.L10N.register(
     "Dec." : "12월",
     "Settings" : "설정",
     "Saving..." : "저장 중...",
+    "Dismiss" : "닫기",
     "seconds ago" : "초 지남",
-    "Couldn't send reset email. Please contact your administrator." : "재설정 메일을 보낼수 없습니다. 관리자에게 문의하십시오.",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "암호 재설정 링크를 포함하고 있는 이메일을 보냈습니다. 이메일이 도착하지 않은 경우 스팸함을 확인해 보십시오.<br>스팸함에도 없는 경우 로컬 관리자에게 문의하십시오.",
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "파일이 암호화되어 있습니다. 복구 키를 활성화하지 않았다면 암호를 초기화한 후 데이터를 복구할 수 없습니다.<br />무엇을 해야 할 지 잘 모르겠으면 계속하기 전에 관리자에게 연락하십시오.<br />그래도 계속 진행하시겠습니까?",
     "I know what I'm doing" : "지금 하려는 것을 알고 있습니다",
@@ -105,26 +113,21 @@ OC.L10N.register(
     "Strong password" : "강력한 암호",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "WebDAV 서비스가 올바르게 작동하지 않아서 웹 서버에서 파일 동기화를 사용할 수 없습니다.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "서버에서 인터넷 연결을 사용할 수 없습니다. 외부 저장소 마운트, 업데이트 알림, 제 3자 앱 설치 등 기능을 사용할 수 없습니다. 원격에서 파일에 접근하거나, 알림 이메일을 보내지 못할 수도 있습니다. 모든 기능을 사용하려면 인터넷에 연결하는 것을 추천합니다.",
-    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "인터넷에서 데이터 디렉터리와 파일에 접근할 수 있습니다. .htaccess 파일이 작동하지 않습니다. 웹 서버 설정을 변경하여 데이터 디렉터리에 직접 접근할 수 없도록 하거나, 데이터 디렉터리를 웹 서버 문서 경로 바깥에 두십시오.",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "메모리 캐시가 설정되지 않았습니다. 성능을 향상시키려면 사용 가능한 경우 메모리 캐시를 설정하십시오. 더 많은 정보를 보려면 <a href=\"{docLink}\">문서</a>를 참고하십시오.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "PHP에서 /dev/urandom을 읽을 수 없으며, 보안상의 이유로 권장되지 않습니다. 더 많은 정보를 보려면 <a href=\"{docLink}\">문서</a>를 참고하십시오.",
-    "Your PHP version ({version}) is no longer <a href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "사용하고 있는 PHP 버전({version})은 더 이상 <a href=\"{phpLink}\">PHP에서 지원하지 않습니다.</a> PHP를 업그레이드하여 성능 및 보안 개선을 누리십시오.",
-    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "역방향 프록시 헤더 설정이 잘못되었거나, 신뢰할 수 있는 프록시에서 ownCloud에 접근하고 있습니다. 신뢰할 수 있는 프록시에서 ownCloud에 접근하는 것이 아니라면, 이 상황은 보안 문제이며 공격자가 ownCloud에 접근하는 IP 주소를 속일 수 있습니다. 더 많은 정보를 보려면 <a href=\"{docLink}\">문서</a>를 참고하십시오.",
     "Error occurred while checking server setup" : "서버 설정을 확인하는 중 오류 발생",
+    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "인터넷에서 데이터 디렉터리와 파일에 접근할 수 있습니다. .htaccess 파일이 작동하지 않습니다. 웹 서버 설정을 변경하여 데이터 디렉터리에 직접 접근할 수 없도록 하거나, 데이터 디렉터리를 웹 서버 문서 경로 바깥에 두십시오.",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "\"{header}\" HTTP 헤더가 \"{expected}\"와(과) 같이 설정되지 않았습니다. 잠재적인 보안 위협이 될 수 있으므로 설정을 변경하는 것을 추천합니다.",
-    "The \"Strict-Transport-Security\" HTTP header is not configured to least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "HTTP 헤더 \"Strict-Transport-Security\"가 최소한 \"{seconds}\"초 이상으로 설정되어야 합니다. 강화된 보안을 위해서 <a href=\"{docUrl}\">보안 팁</a>에 나타난 것처럼 HSTS를 활성화하는 것을 추천합니다.",
     "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "이 사이트를 HTTP로 접근하고 있습니다. <a href=\"{docUrl}\">보안 팁</a>에 나타난 것처럼 서버 설정을 변경하여 HTTPS를 사용하는 것을 강력히 추천합니다.",
     "Shared" : "공유됨",
     "Shared with {recipients}" : "{recipients} 님과 공유됨",
     "Error" : "오류",
     "Error while sharing" : "공유하는 중 오류 발생",
     "Error while unsharing" : "공유 해제하는 중 오류 발생",
-    "Error while changing permissions" : "권한 변경하는 중 오류 발생",
     "Error setting expiration date" : "만료 날짜 설정 오류",
     "The public link will expire no later than {days} days after it is created" : "공개 링크를 만든 후 최대 {days}일까지 유지됩니다",
     "Set expiration date" : "만료 날짜 설정",
     "Expiration" : "만료",
     "Expiration date" : "만료 날짜",
+    "Choose a password for the public link" : "공개 링크 암호를 입력하십시오",
     "Sending ..." : "전송 중...",
     "Email sent" : "이메일 발송됨",
     "Resharing is not allowed" : "다시 공유할 수 없습니다",
@@ -132,13 +135,11 @@ OC.L10N.register(
     "Link" : "링크",
     "Password protect" : "암호 보호",
     "Password" : "암호",
-    "Choose a password for the public link" : "공개 링크 암호를 입력하십시오",
     "Allow editing" : "편집 허용",
     "Email link to person" : "이메일 주소",
     "Send" : "전송",
     "Shared with you and the group {group} by {owner}" : "{owner} 님이 여러분 및 그룹 {group}와(과) 공유 중",
     "Shared with you by {owner}" : "{owner} 님이 공유 중",
-    "Shared in {item} with {user}" : "{user} 님과 {item}에서 공유 중",
     "group" : "그룹",
     "remote" : "원격",
     "notify by email" : "이메일로 알림",
@@ -150,16 +151,17 @@ OC.L10N.register(
     "delete" : "삭제",
     "access control" : "접근 제어",
     "Share details could not be loaded for this item." : "이 항목의 공유 정보를 불러올 수 없습니다.",
-    "An error occured. Please try again" : "오류가 발생하였습니다. 다시 시도하십시오.",
+    "An error occured. Please try again" : "오류가 발생했습니다. 다시 시도하십시오.",
     "Share" : "공유",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "username@example.com/owncloud 형식으로 다른 ownCloud 사용자와 공유할 수 있습니다",
     "Share with users or groups …" : "사용자 및 그룹과 공유...",
     "Share with users, groups or remote users …" : "사용자, 그룹 및 원격 사용자와 공유...",
     "Warning" : "경고",
     "Error while sending notification" : "알림을 보내는 중 오류 발생",
+    "Delete" : "삭제",
+    "Rename" : "이름 바꾸기",
     "The object type is not specified." : "객체 유형이 지정되지 않았습니다.",
     "Enter new" : "새로운 값 입력",
-    "Delete" : "삭제",
     "Add" : "추가",
     "Edit tags" : "태그 편집",
     "Error loading dialog template: {error}" : "대화 상자 템플릿을 불러오는 중 오류 발생: {error}",
@@ -170,21 +172,13 @@ OC.L10N.register(
     "Hello {name}, the weather is {weather}" : "{name} 님 안녕하세요, 오늘 날씨는 {weather}입니다",
     "Hello {name}" : "{name} 님 안녕하세요",
     "_download %n file_::_download %n files_" : ["파일 %n개 다운로드"],
-    "{version} is available. Get more information on how to update." : "{version}을(를) 사용할 수 있습니다. 업데이트하는 방법에 대해서 알아보십시오.",
+    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "업그레이드 중입니다. 이 페이지를 열어 두면 일부 환경에서 진행 과정을 중단시킬 수 있습니다.",
     "Updating {productName} to version {version}, this may take a while." : "{productName}을(를) 버전 {version}으로 업데이트하고 있습니다. 시간이 걸릴 수 있습니다.",
+    "An error occurred." : "오류가 발생했습니다.",
     "Please reload the page." : "페이지를 새로 고치십시오.",
-    "The update was unsuccessful. " : "업데이트가 실패하였습니다. ",
-    "The update was successful. There were warnings." : "업데이트가 성공하였습니다. 일부 경고가 있습니다.",
-    "The update was successful. Redirecting you to ownCloud now." : "업데이트가 성공하였습니다. ownCloud로 돌아갑니다.",
-    "Couldn't reset password because the token is invalid" : "토큰이 잘못되었기 때문에 암호를 초기화할 수 없습니다",
-    "Couldn't reset password because the token is expired" : "토큰이 만료되어 암호를 초기화할 수 없습니다",
-    "Couldn't send reset email. Please make sure your username is correct." : "재설정 메일을 보낼 수 없습니다. 사용자 이름이 올바른지 확인하십시오.",
-    "Couldn't send reset email because there is no email address for this username. Please contact your administrator." : "해당 사용자 이름에 등록된 이메일 주소가 없어서 재설정 메일을 보낼 수 없습니다. 관리자에게 문의하십시오.",
-    "%s password reset" : "%s 암호 재설정",
-    "Use the following link to reset your password: {link}" : "다음 링크를 사용하여 암호를 재설정할 수 있습니다: {link}",
-    "New password" : "새 암호",
-    "New Password" : "새 암호",
-    "Reset password" : "암호 재설정",
+    "The update was unsuccessful. " : "업데이트가 실패했습니다. ",
+    "The update was successful. There were warnings." : "업데이트가 성공했습니다. 일부 경고가 있습니다.",
+    "The update was successful. Redirecting you to ownCloud now." : "업데이트가 성공했습니다. ownCloud로 돌아갑니다.",
     "Searching other places" : "다른 장소 찾는 중",
     "No search results in other folders" : "다른 폴더에 검색 결과 없음",
     "_{count} search result in another folder_::_{count} search results in other folders_" : ["다른 폴더의 검색 결과 {count}개"],
@@ -244,24 +238,27 @@ OC.L10N.register(
     "Finishing …" : "완료 중 ...",
     "Need help?" : "도움이 필요한가요?",
     "See the documentation" : "문서 보기",
+    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "안녕하세요,<br><br>%s 님이 <strong>%s</strong>을(를) 공유하였음을 알려 드립니다.<br><a href=\"%s\">보러 가기!</a><br><br>",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "이 프로그램이 올바르게 작동하려면 JavaScript가 필요합니다. {linkstart}JavaScript를 활성화{linkend}한 다음 페이지를 새로 고치십시오.",
     "Log out" : "로그아웃",
     "Search" : "검색",
     "Server side authentication failed!" : "서버 인증 실패!",
     "Please contact your administrator." : "관리자에게 문의하십시오.",
-    "An internal error occured." : "내부 오류가 발생하였습니다.",
+    "An internal error occured." : "내부 오류가 발생했습니다.",
     "Please try again or contact your administrator." : "다시 시도하거나 관리자에게 연락하십시오.",
     "Log in" : "로그인",
     "Wrong password. Reset it?" : "암호가 잘못되었습니다. 다시 설정하시겠습니까?",
-    "remember" : "기억하기",
+    "Stay logged in" : "로그인 유지",
     "Alternative Logins" : "대체 로그인",
-    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "안녕하세요,<br><br>%s 님이 <strong>%s</strong>을(를) 공유하였음을 알려 드립니다.<br><a href=\"%s\">보러 가기!</a><br><br>",
+    "Use the following link to reset your password: {link}" : "다음 링크를 사용하여 암호를 재설정할 수 있습니다: {link}",
+    "New password" : "새 암호",
+    "New Password" : "새 암호",
+    "Reset password" : "암호 재설정",
     "This ownCloud instance is currently in single user mode." : "ownCloud 인스턴스가 현재 단일 사용자 모드로 동작 중입니다.",
     "This means only administrators can use the instance." : "현재 시스템 관리자만 인스턴스를 사용할 수 있습니다.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "이 메시지가 계속 표시되거나, 예상하지 못하였을 때 표시된다면 시스템 관리자에게 연락하십시오",
     "Thank you for your patience." : "기다려 주셔서 감사합니다.",
     "You are accessing the server from an untrusted domain." : "신뢰할 수 없는 도메인으로 서버에 접근하고 있습니다.",
-    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domain\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "관리자에게 연락해 주십시오. 만약 이 인스턴스 관리자라면 config/config.php에서 \"trusted_domain\" 설정을 편집하십시오. 예제 설정 파일은 config/config.sample.php에 있습니다.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "설정에 따라서 관리자 권한으로 아래 단추를 눌러서 이 도메인을 신뢰하도록 설정할 수 있습니다.",
     "Add \"%s\" as trusted domain" : "\"%s\"을(를) 신뢰할 수 있는 도메인으로 추가",
     "App update required" : "앱 업데이트 필요",
