@@ -3,30 +3,44 @@ OC.L10N.register(
     {
     "Couldn't send mail to following users: %s " : "Kon geen e-mail sturen aan de volgende gebruikers: %s",
     "Preparing update" : "Update voorbereiden",
-    "Migration tests are skipped - \"update.skip-migration-test\" is activated in config.php" : "Migratietests worden overgeslagen - \"update.skip-migration-test\" is geactiveerd in config.php",
     "Turned on maintenance mode" : "Onderhoudsmodus ingeschakeld",
     "Turned off maintenance mode" : "Onderhoudsmodus uitgeschakeld",
     "Maintenance mode is kept active" : "Onderhoudsmodus blijft actief",
+    "Updating database schema" : "Database schema aan het updaten",
     "Updated database" : "Database bijgewerkt",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Controleert of het database schema geüpdatet kan worden (dit kan lang duren afhankelijk van de grootte van de de database)",
     "Checked database schema update" : "Database schema-update gecontroleerd",
+    "Checking updates of apps" : "Controleert of er updates voor apps zijn",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Controleert of het database schema voor %s geüpdatet kan worden ( dit kan lang duren afhankelijk van de grootte van de database )",
     "Checked database schema update for apps" : "Database schema-update voor apps gecontroleerd",
     "Updated \"%s\" to %s" : "Bijgewerkt \"%s\" naar %s",
     "Repair warning: " : "Reparatiewaarschuwing:",
     "Repair error: " : "Reparatiefout:",
-    "Set log level to debug - current level: \"%s\"" : "Instellen logniveau op debug - huidige niveau: \"%s\"",
-    "Reset log level to  \"%s\"" : "Terugzetten logniveau op \"#%s\"",
-    "Following incompatible apps have been disabled: %s" : "De volgende incompatibele apps zijn uitgeschakeld: %s",
+    "Set log level to debug" : "Logniveau instellen op debug",
+    "Reset log level" : "Terugzetten logniveau",
+    "Starting code integrity check" : "Starten code betrouwbaarheidscontrole",
+    "Finished code integrity check" : "Gereed met code betrouwbaarheidscontrole",
+    "%s (3rdparty)" : "%s (3rdparty)",
+    "%s (incompatible)" : "%s (incompatibel)",
     "Following apps have been disabled: %s" : "De volgende apps zijn gedeactiveerd: %s",
     "Already up to date" : "Al bijgewerkt",
+    "Please select a file." : "Selecteer een bestand.",
     "File is too big" : "Bestand te groot",
     "Invalid file provided" : "Ongeldig bestand opgegeven",
     "No image or file provided" : "Geen afbeelding of bestand opgegeven",
     "Unknown filetype" : "Onbekend bestandsformaat",
     "Invalid image" : "Ongeldige afbeelding",
+    "An error occurred. Please contact your admin." : "Er trad een fout op. Neem contact op met uw beheerder.",
     "No temporary profile picture available, try again" : "Geen tijdelijke profielafbeelding beschikbaar. Probeer het opnieuw",
     "No crop data provided" : "Geen bijsnijdingsgegevens opgegeven",
     "No valid crop data provided" : "Geen geldige bijsnijdingsgegevens opgegeven",
     "Crop is not square" : "Bijsnijding is niet vierkant",
+    "Couldn't reset password because the token is invalid" : "Kon het wachtwoord niet herstellen, omdat het token ongeldig is",
+    "Couldn't reset password because the token is expired" : "Kon het wachtwoord niet herstellen, omdat het token verlopen is",
+    "Couldn't send reset email. Please make sure your username is correct." : "Kon e-mail niet versturen. Verifieer of uw gebruikersnaam correct is.",
+    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Kon geen herstel e-mail versturen, omdat er geen e-mailadres bekend is bij deze gebruikersnaam. Neem contact op met uw beheerder.",
+    "%s password reset" : "%s wachtwoord reset",
+    "Couldn't send reset email. Please contact your administrator." : "Kon herstel e-mail niet versturen. Neem contact op met uw beheerder.",
     "Sunday" : "zondag",
     "Monday" : "maandag",
     "Tuesday" : "dinsdag",
@@ -72,10 +86,11 @@ OC.L10N.register(
     "Oct." : "Okt.",
     "Nov." : "Nov.",
     "Dec." : "Dec.",
+    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Er traden problemen op tijdens de code betrouwbaarheidscontrole. Meer informatie…</a>",
     "Settings" : "Instellingen",
     "Saving..." : "Opslaan",
+    "Dismiss" : "Terzijde leggen",
     "seconds ago" : "seconden geleden",
-    "Couldn't send reset email. Please contact your administrator." : "Kon herstel e-mail niet versturen. Neem contact op met uw beheerder.",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "De link om uw wachtwoord te herstellen is per e-mail naar u verstuurd. Als u dit bericht niet binnen redelijke tijd hebt ontvangen, controleer dan uw spammap. <br>Als het daar niet in zit, neem dan contact op met uw beheerder.",
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Uw bestanden zijn versleuteld. Als u de herstelsleutel niet hebt geactiveerd, is er geen mogelijk om uw gegevens terug te krijgen nadat uw wachtwoord is hersteld. <br>Als u niet weet wat u moet doen, neem dan eerst contact op met uw beheerder. <br>Wilt u echt verder gaan?",
     "I know what I'm doing" : "Ik weet wat ik doe",
@@ -104,27 +119,30 @@ OC.L10N.register(
     "Good password" : "Goed wachtwoord",
     "Strong password" : "Sterk wachtwoord",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Uw webserver is nog niet goed ingesteld voor bestandssynchronisatie omdat de WebDAV interface verstoord lijkt.",
+    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Uw webserver is niet goed ingesteld om \"{url}\" te vinden. Meer informatie is te vinden in onze <a target=\"_blank\" href=\"{docLink}\">documentatie</a>.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Deze server heeft geen actieve internetverbinding. Dat betekent dat sommige functies, zoals aankoppelen van externe opslag, notificaties over updates of installatie van apps van 3e partijen niet werken. Ook het benaderen van bestanden vanaf een remote locatie en het versturen van notificatie emails kan mislukken. We adviseren om de internetverbinding voor deze server in te schakelen als u alle functies wilt gebruiken.",
-    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Uw data folder en uw bestanden zijn waarschijnlijk vanaf het internet bereikbaar.  Het .htaccess-bestand werkt niet.  We raden ten zeerste aan aan om uw webserver zodanig te configureren, dat de datadirectory niet bereikbaar is vanaf het internet of om uw datadirectory te verplaatsen naar een locatie buiten de document root van de webserver.",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "Er is geen geheugencache geconfigureerd. Om de prestaties te verhogen kunt u de memcache configureren als die beschikbaar is. Meer informatie vind u in onze <a href=\"{docLink}\">documentatie</a>.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "/dev/urandom is niet leesbaar door PHP, hetgeen wordt afgeraden wegens beveiligingsredenen. Meer informatie in onze <a href=\"{docLink}\">documentatie</a>.",
-    "Your PHP version ({version}) is no longer <a href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "UwPHP versie ({version}) wordt niet langer <a href=\"{phpLink}\">ondersteund door PHP</a>. We adviseren u om uw PHP versie te upgraden voor betere prestaties en security updates geleverd door PHP.",
-    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "De reverse proxy headerconfiguratie is onjuist, of u hebt toegang tot ownCloud via een vertrouwde proxy. Als u ownCloud niet via een vertrouwde proxy benadert, dan levert dan een beveiligingsrisico op, waardoor een aanvaller het IP-adres dat ownCloud ziet kan spoofen. Meer informatie is te vinden in onze <a href=\"{docLink}\">documentatie</a>.",
+    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Er is geen geheugencache geconfigureerd. Om de prestaties te verhogen kunt u de memcache configureren als die beschikbaar is. Meer informatie vind u in onze <a target=\"_blank\" href=\"{docLink}\">documentatie</a>.",
+    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "/dev/urandom is niet leesbaar door PHP, hetgeen wordt afgeraden wegens beveiligingsredenen. Meer informatie in onze <a target=\"_blank\" href=\"{docLink}\">documentatie</a>.",
+    "Your PHP version ({version}) is no longer <a target=\"_blank\" href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "UwPHP versie ({version}) wordt niet langer <a target=\"_blank\" href=\"{phpLink}\">ondersteund door PHP</a>. We adviseren u om uw PHP versie te upgraden voor betere prestaties en security updates geleverd door PHP.",
+    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "De reverse proxy headerconfiguratie is onjuist, of u hebt toegang tot ownCloud via een vertrouwde proxy. Als u ownCloud niet via een vertrouwde proxy benadert, dan levert dan een beveiligingsrisico op, waardoor een aanvaller het IP-adres dat ownCloud ziet kan spoofen. Meer informatie is te vinden in onze <a target=\"_blank\" href=\"{docLink}\">documentatie</a>.",
+    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached is geconfigureerd als gedistribueerde cache, maar de verkeerde PHP module \"memcache\" is geïnstalleerd. \\OC\\Memcache\\Memcached ondersteunt alleen \"memcached\" en niet \"memcache\". Zie de <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki over beide modules</a>.",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Sommige bestanden kwamen niet door de code betrouwbaarheidscontrole. Meer informatie over het oplossen van dit probleem kan worden gevonden in onze <a target=\"_blank\" href=\"{docLink}\">documentatie</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Lijst met ongeldige bestanden…</a> / <a href=\"{rescanEndpoint}\">Opnieuw…</a>)",
     "Error occurred while checking server setup" : "Een fout trad op bij checken serverconfiguratie",
+    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Uw data folder en uw bestanden zijn waarschijnlijk vanaf het internet bereikbaar.  Het .htaccess-bestand werkt niet.  We raden ten zeerste aan aan om uw webserver zodanig te configureren, dat de datadirectory niet bereikbaar is vanaf het internet of om uw datadirectory te verplaatsen naar een locatie buiten de document root van de webserver.",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "De \"{header}\" HTTP header is niet overeenkomstig met \"{expected}\" geconfigureerd. Dit is een potentieel security of privacy risico en we adviseren om deze instelling te wijzigen.",
-    "The \"Strict-Transport-Security\" HTTP header is not configured to least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "De \"Strict-Transport-Security\" HTTP header is niet geconfigureerd als minimaal \"{seconds}\" seconden. Voor verbeterde beveiliging adviseren we HSTS in te schakelen zoals beschreven in onze <a href=\"{docUrl}\">security tips</a>.",
+    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "De \"Strict-Transport-Security\" HTTP header is niet geconfigureerd met minimaal \"{seconds}\" seconden. Voor verbeterde beveiliging adviseren we HSTS in te schakelen zoals beschreven in onze <a href=\"{docUrl}\">security tips</a>.",
     "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "U bent met deze site verbonden over HTTP. We adviseren met klem uw server zo te configureren dat HTTPS wordt vereist, zoals beschreven in onze <a href=\"{docUrl}\">security tips</a>.",
     "Shared" : "Gedeeld",
     "Shared with {recipients}" : "Gedeeld met {recipients}",
     "Error" : "Fout",
     "Error while sharing" : "Fout tijdens het delen",
     "Error while unsharing" : "Fout tijdens het stoppen met delen",
-    "Error while changing permissions" : "Fout tijdens het veranderen van permissies",
     "Error setting expiration date" : "Fout tijdens het instellen van de vervaldatum",
     "The public link will expire no later than {days} days after it is created" : "De openbare link vervalt niet eerder dan {days} dagen na het aanmaken",
     "Set expiration date" : "Stel vervaldatum in",
     "Expiration" : "Vervaltermijn",
     "Expiration date" : "Vervaldatum",
+    "Choose a password for the public link" : "Kies een wachtwoord voor de openbare link",
     "Sending ..." : "Versturen ...",
     "Email sent" : "E-mail verzonden",
     "Resharing is not allowed" : "Verder delen is niet toegestaan",
@@ -132,13 +150,11 @@ OC.L10N.register(
     "Link" : "Link",
     "Password protect" : "Wachtwoord beveiligd",
     "Password" : "Wachtwoord",
-    "Choose a password for the public link" : "Kies een wachtwoord voor de openbare link",
     "Allow editing" : "Toestaan bewerken",
     "Email link to person" : "E-mail link naar persoon",
     "Send" : "Versturen",
     "Shared with you and the group {group} by {owner}" : "Gedeeld met u en de groep {group} door {owner}",
     "Shared with you by {owner}" : "Gedeeld met u door {owner}",
-    "Shared in {item} with {user}" : "Gedeeld in {item} met {user}",
     "group" : "groep",
     "remote" : "extern",
     "notify by email" : "melden per e-mail",
@@ -149,17 +165,28 @@ OC.L10N.register(
     "change" : "wijzig",
     "delete" : "verwijderen",
     "access control" : "toegangscontrole",
+    "Could not unshare" : "Kon delen niet ongedaan maken",
     "Share details could not be loaded for this item." : "Details van shares voor dit object konden niet worden geladen.",
+    "No users or groups found for {search}" : "Geen gebruikers of groepen gevonden voor {search}",
     "An error occured. Please try again" : "Er trad een fout op. Probeer het opnieuw",
+    "{sharee} (group)" : "{sharee} (groep)",
+    "{sharee} (at {server})" : "{sharee} (op {server})",
+    "{sharee} (remote)" : "{sharee} (extern)",
     "Share" : "Delen",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Delen met mensen op andere ownClouds via de syntax gebruikersnaam@voorbeeld.org/owncloud",
     "Share with users or groups …" : "Delen met gebruikers of groepen ...",
     "Share with users, groups or remote users …" : "Delen met gebruikers, groepen of externe gebruikers ...",
+    "Error removing share" : "Fout bij verwijderen share",
     "Warning" : "Waarschuwing",
     "Error while sending notification" : "Fout bij versturen melding",
+    "Non-existing tag #{tag}" : "Niet bestaande tag #{tag}",
+    "not assignable" : "niet toewijsbaar",
+    "invisible" : "onzichtbaar",
+    "({scope})" : "({scope})",
+    "Delete" : "Verwijder",
+    "Rename" : "Naam wijzigen",
     "The object type is not specified." : "Het object type is niet gespecificeerd.",
     "Enter new" : "Opgeven nieuw",
-    "Delete" : "Verwijder",
     "Add" : "Toevoegen",
     "Edit tags" : "Bewerken tags",
     "Error loading dialog template: {error}" : "Fout bij laden dialoog sjabloon: {error}",
@@ -170,21 +197,14 @@ OC.L10N.register(
     "Hello {name}, the weather is {weather}" : "Hallo {name}, het is hier {weather}",
     "Hello {name}" : "Hallo {name}",
     "_download %n file_::_download %n files_" : ["download %n bestand","download %n bestanden"],
-    "{version} is available. Get more information on how to update." : "{version} is beschikbaar. Meer informatie over het bijwerken.",
+    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "De update is bezig, deze pagina verlaten kan het updateproces in sommige omgevingen onderbreken.",
     "Updating {productName} to version {version}, this may take a while." : "Bijwerken {productName} naar versie {version}, dit kan even duren.",
+    "An error occurred." : "Er heeft zich een fout voorgedaan.",
     "Please reload the page." : "Herlaad deze pagina.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "De update was niet succesvol. Voor meer informatie <a href=\"{url}\">zie ons bericht op het forum</a> over dit probleem.",
     "The update was unsuccessful. " : "De update is niet geslaagd.",
     "The update was successful. There were warnings." : "De update is geslaagd. Er zijn wel waarschuwingen.",
     "The update was successful. Redirecting you to ownCloud now." : "De update is geslaagd. U wordt teruggeleid naar uw eigen ownCloud.",
-    "Couldn't reset password because the token is invalid" : "Kon het wachtwoord niet herstellen, omdat het token ongeldig is",
-    "Couldn't reset password because the token is expired" : "Kon het wachtwoord niet herstellen, omdat het token verlopen is",
-    "Couldn't send reset email. Please make sure your username is correct." : "Kon e-mail niet versturen. Verifieer of uw gebruikersnaam correct is.",
-    "Couldn't send reset email because there is no email address for this username. Please contact your administrator." : "Kon geen herstel e-mail versturen, omdat er geen e-mailadres bekend is bij deze gebruikersnaam. Neem contact op met uw beheerder.",
-    "%s password reset" : "%s wachtwoord reset",
-    "Use the following link to reset your password: {link}" : "Gebruik de volgende link om uw wachtwoord te resetten: {link}",
-    "New password" : "Nieuw wachtwoord",
-    "New Password" : "Nieuw wachtwoord",
-    "Reset password" : "Reset wachtwoord",
     "Searching other places" : "Zoeken op andere plaatsen",
     "No search results in other folders" : "Geen zoekresultaten in andere mappen",
     "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} zoekresultaat in een andere map","{count} zoekresultaten in andere mappen"],
@@ -244,6 +264,7 @@ OC.L10N.register(
     "Finishing …" : "Afronden ...",
     "Need help?" : "Hulp nodig?",
     "See the documentation" : "Zie de documentatie",
+    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hallo,<br><br>%s deelt <strong>%s</strong> met u.<br><a href=\"%s\">Bekijk hier!</a><br><br>",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Deze applicatie heeft JavaScript nodig. {linkstart}Activeer JavaScript{linkend} en ververs deze pagina.",
     "Log out" : "Afmelden",
     "Search" : "Zoeken",
@@ -253,15 +274,19 @@ OC.L10N.register(
     "Please try again or contact your administrator." : "Probeer het opnieuw of neem contact op met uw beheerder.",
     "Log in" : "Meld u aan",
     "Wrong password. Reset it?" : "Onjuist wachtwoord. Resetten?",
-    "remember" : "onthoud gegevens",
+    "Wrong password." : "Onjuist wachtwoord.",
+    "Stay logged in" : "Ingelogd blijven",
     "Alternative Logins" : "Alternatieve inlogs",
-    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hallo,<br><br>%s deelt <strong>%s</strong> met u.<br><a href=\"%s\">Bekijk hier!</a><br><br>",
+    "Use the following link to reset your password: {link}" : "Gebruik de volgende link om uw wachtwoord te resetten: {link}",
+    "New password" : "Nieuw wachtwoord",
+    "New Password" : "Nieuw wachtwoord",
+    "Reset password" : "Reset wachtwoord",
     "This ownCloud instance is currently in single user mode." : "Deze ownCloud werkt momenteel in enkele gebruiker modus.",
     "This means only administrators can use the instance." : "Dat betekent dat alleen beheerders deze installatie kunnen gebruiken.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Neem contact op met uw systeembeheerder als deze melding aanhoudt of onverwacht verscheen.",
     "Thank you for your patience." : "Bedankt voor uw geduld.",
     "You are accessing the server from an untrusted domain." : "U benadert de server vanaf een niet vertrouwd domein.",
-    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domain\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Neem contact op met uw beheerder. Als u de beheerder van deze service bent, configureer dan de \"trusted_domain\" instelling in config/config.php. Een voorbeeldconfiguratie is gegeven in config/config.sample.php.",
+    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Neem contact op met uw beheerder. Als u de beheerder van deze service bent, configureer dan de \"trusted_domains\" instelling in config/config.php. Een voorbeeldconfiguratie is gegeven in config/config.sample.php.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Afhankelijk van uw configuratie zou u als beheerder ook de onderstaande knop kunnen gebruiken om dit domein te vertrouwen.",
     "Add \"%s\" as trusted domain" : "\"%s\" toevoegen als vertrouwd domein",
     "App update required" : "Bijwerken App vereist",
