@@ -3,30 +3,44 @@ OC.L10N.register(
     {
     "Couldn't send mail to following users: %s " : "Não foi possível enviar e-mail para os seguintes usuários: %s",
     "Preparing update" : "Preparando atualização",
-    "Migration tests are skipped - \"update.skip-migration-test\" is activated in config.php" : "Os ensaios de migração forão ignoradas - \"update.skip-migration-test\" está ativado no config.php",
     "Turned on maintenance mode" : "Ativar modo de manutenção",
     "Turned off maintenance mode" : "Desligar o modo de manutenção",
     "Maintenance mode is kept active" : "O modo de manutenção está sendo mantido como ativo",
+    "Updating database schema" : "Actualização de esquema do banco de dados",
     "Updated database" : "Atualizar o banco de dados",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Verificar se o esquema do banco de dados pode ser atualizado (isso pode levar muito tempo, dependendo do tamanho do banco de dados)",
     "Checked database schema update" : "Verificado atualização do esquema de banco de dados",
+    "Checking updates of apps" : "Verificar atualizações de aplicativos",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Verificar se o esquema do banco de dados para %s pode ser atualizado (isso pode levar muito tempo, dependendo do tamanho do banco de dados)",
     "Checked database schema update for apps" : "Verificar atualização do esquema de banco de dados para aplicativos",
     "Updated \"%s\" to %s" : "Atualizado \"%s\" para %s",
     "Repair warning: " : "Aviso de reparação:",
     "Repair error: " : "Reparação de erro:",
-    "Set log level to debug - current level: \"%s\"" : "Configure o nível de log para debug - nível corrente: \"%s\"",
-    "Reset log level to  \"%s\"" : "Reconfigurar o nível de log para \"%s\"",
-    "Following incompatible apps have been disabled: %s" : "Seguir aplicativos incompatíveis foi desativado: %s",
+    "Set log level to debug" : "Definir o nível de log para debug",
+    "Reset log level" : "Redefinição do nível do log",
+    "Starting code integrity check" : "Inicializando verificação da integridade do código",
+    "Finished code integrity check" : "Finalizada a verificação de integridade do código",
+    "%s (3rdparty)" : "%s (3ºterceiros)",
+    "%s (incompatible)" : "%s (incompatível)",
     "Following apps have been disabled: %s" : "Os seguintes aplicativos foram desabilitados: %s",
     "Already up to date" : "Já está atualizado",
+    "Please select a file." : "Por favor selecione um arquivo.",
     "File is too big" : "O arquivo é muito grande",
     "Invalid file provided" : "Arquivo fornecido inválido",
     "No image or file provided" : "Nenhuma imagem ou arquivo fornecido",
     "Unknown filetype" : "Tipo de arquivo desconhecido",
     "Invalid image" : "Imagem inválida",
+    "An error occurred. Please contact your admin." : "Ocorreu um erro. Entre em contato com seu administrador.",
     "No temporary profile picture available, try again" : "Nenhuma imagem temporária disponível no perfil, tente novamente",
     "No crop data provided" : "Nenhum dado para coleta foi fornecido",
     "No valid crop data provided" : "Nenhum dado recortado válido",
     "Crop is not square" : "Recorte não é quadrado",
+    "Couldn't reset password because the token is invalid" : "Não foi possível redefinir a senha porque o token é inválido",
+    "Couldn't reset password because the token is expired" : "Não foi possível redefinir a senha porque o token expirou",
+    "Couldn't send reset email. Please make sure your username is correct." : "Não foi possível enviar e-mail de redefinição. Verifique se o seu nome de usuário está correto.",
+    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Não foi possível enviar email de redefinição porque não há nenhum endereço de e-mail para este nome de usuário. Entre em contato com o administrador.",
+    "%s password reset" : "%s redefinir senha",
+    "Couldn't send reset email. Please contact your administrator." : "Não foi possível enviar e-mail de redefinição. Por favor, contate o administrador.",
     "Sunday" : "Domingo",
     "Monday" : "Segunda-feira",
     "Tuesday" : "Terça-feira",
@@ -72,10 +86,11 @@ OC.L10N.register(
     "Oct." : "Out.",
     "Nov." : "Nov.",
     "Dec." : "Dez.",
+    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Houve problemas com a verificação de integridade do código. Mais informações…</a>",
     "Settings" : "Configurações",
     "Saving..." : "Salvando...",
+    "Dismiss" : "Dispensar",
     "seconds ago" : "segundos atrás",
-    "Couldn't send reset email. Please contact your administrator." : "Não foi possível enviar e-mail de redefinição. Por favor, contate o administrador.",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "O link para redefinir sua senha foi enviada para o seu e-mail. Se você não recebê-lo dentro de um período razoável de tempo, verifique suas pastas de spam/lixo. <br> Se ele não estiver lá, pergunte ao administrador do local.",
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Seus arquivos são criptografados. Se você não ativou a chave de recuperação, não haverá maneira de obter seus dados de volta após a sua senha ser redefinida. <br/> Se você não tem certeza do que fazer, por favor, contate o administrador antes de continuar. <br/> Você realmente deseja continuar?",
     "I know what I'm doing" : "Eu sei o que estou fazendo",
@@ -104,28 +119,30 @@ OC.L10N.register(
     "Good password" : "Boa senha",
     "Strong password" : "Senha forte",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Seu servidor web ainda não está configurado corretamente para permitir a sincronização de arquivos, pois a interface WebDAV parece ser desconfigurada.",
+    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "O seu servidor web não está configurado corretamente para resolver \"{url}\". Mais informações podem ser encontradas em nossa <a target=\"_blank\" href=\"{docLink}\">documentação</a>.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Este servidor não tem nenhuma conexão com a Internet. Isto significa que algumas das características como a montagem de armazenamento externo, notificações sobre atualizações ou instalação de aplicativos de terceiros não vai funcionar. Acessar arquivos remotamente e envio de e-mails de notificação pode não funcionar, também. Sugerimos permitir conexão com a Internet para este servidor, se você quer ter todas as funcionalidades.",
-    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "O seu diretório de dados e os arquivos estão, provavelmente, acessíveis a partir da Internet. O arquivo .htaccess não está funcionando. Nós sugerimos que você configure o servidor web de uma forma que o diretório de dados não seja acessível ou mova o diretório de dados para fora do diretório raiz de documentos do servidor web.",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "Nenhum cache de memória foi configurado. Para melhorar o seu desempenho, por favor configurar um cache de memória, se disponível. Mais informações podem ser encontradas em nossa <a href=\"{docLink}\"> documentação </a>.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "/dev/urandom não pode ser lido por PHP o que é altamente desencorajado por razões de segurança. Mais informações podem ser encontradas em nossa <a href=\"{docLink}\">documentation</a>.",
-    "Your PHP version ({version}) is no longer <a href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "A sua versão do PHP ({version}) não é <a href=\"{phpLink}\">suportada pela PHP</a>. Nós o incentivamos a atualizar sua versão do PHP para tirar proveito de atualizações de desempenho e de segurança fornecidos pela PHP.",
-    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "A configuração de cabeçalhos do proxy reverso está incorreta, ou você está acessando ownCloud de um proxy confiável. Se você não está acessando ownCloud de um proxy confiável, esta é uma questão de segurança e pode permitir a um invasor falsificar seu endereço IP como visível para ownCloud. Mais informações podem ser encontradas em nossa <a href=\"{docLink}\">documentação</a>.",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached está configurado como cache distribuído, mas o módulo PHP errado \"memcache\" está instalado. \\OC\\Memcache\\Memcached somente suporta \"memcached\" e não \"memcache\". Veja o <a href=\"{wikiLink}\">memcached wiki sobre esse módulo</a>.",
+    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Nenhuma memória cache foi configurada. Para melhorar o seu desempenho, por favor configure um cache de memória, se disponível. Mais informação podem ser encontradas em nossa <a target=\"_blank\" href=\"{docLink}\">documentação</a>.",
+    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "/dev/urandom não pode ser lido pelo PHP o que é altamente desencorajado por razões de segurança. Mais informações podem ser encontradas na nossa <a target=\"_blank\" href=\"{docLink}\">documentação</a>.",
+    "Your PHP version ({version}) is no longer <a target=\"_blank\" href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "A sua versão do PHP ({version}) não é mais <a target=\"_blank\" href=\"{phpLink}\">suportada pelo PHP</a>. Nós o incentivamos a atualizar sua versão do PHP para tirar proveito de atualizações de desempenho e de segurança fornecidas pelo PHP.",
+    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "A configuração de cabeçalhos do proxy reverso está incorreta, ou você está acessando ownCloud de um proxy confiável. Se você não está acessando ownCloud de um proxy confiável, esta é uma questão de segurança e pode permitir a um invasor falsificar seu endereço IP como visível para ownCloud. Mais informação pode ser encontrada na nossa <a target=\"_blank\" href=\"{docLink}\">documentação</a>.",
+    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached está configurado como cache distribuído, mas o módulo PHP \"memcache\" errado está instalado. \\OC\\Memcache\\Memcached suporta apenas \"memcached\" e não \"memcache\". Veja a <a target=\"_blank\" href=\"{wikiLink}\">o wiki sobre memcached sobre ambos os módulos</a>.",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Alguns arquivos não passaram na verificação de integridade. Mais informações sobre como resolver este problema podem ser encontradas na nossa <a target=\"_blank\" href=\"{docLink}\">documentação</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Lista de arquivos inválidos…</a> / <a href=\"{rescanEndpoint}\">Reexaminar…</a>)",
     "Error occurred while checking server setup" : "Erro ao verificar a configuração do servidor",
+    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "O seu diretório de dados e os arquivos estão, provavelmente, acessíveis a partir da Internet. O arquivo .htaccess não está funcionando. Nós sugerimos que você configure o servidor web de uma forma que o diretório de dados não seja acessível ou mova o diretório de dados para fora do diretório raiz de documentos do servidor web.",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "O \"{header}\" cabeçalho HTTP não está configurado igual ao \"{expected}\". Este é um risco potencial para a segurança e recomendamos ajustar essa configuração.",
-    "The \"Strict-Transport-Security\" HTTP header is not configured to least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "O cabeçalho \"Transporte-de-Segurança-Restrita\"HTTP não está configurada para menos de \"{seconds}\" segundos. Para uma maior segurança recomendamos a ativação HSTS conforme descrito em nossas  <a href=\"{docUrl}\">dicas de segurança</a>.",
+    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "O \"Strict-Transport-Security\" cabeçalho HTTP não está configurado para pelo menos \"{seconds}\" segundos. Para maior segurança recomendamos a ativação HSTS como descrito em nossas <a href=\"{docUrl}\">dicas de segurança</a>.",
     "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Você está acessando este site via HTTP. Nós fortemente sugerimos que você ao invéz, configure o servidor para exigir o uso de HTTPS como descrito em nossas  <a href=\"{docUrl}\">dicas de segurança</a>.",
-    "Shared" : "Compartilhados",
+    "Shared" : "Compartilhado",
     "Shared with {recipients}" : "Compartilhado com {recipients}",
     "Error" : "Erro",
     "Error while sharing" : "Erro ao compartilhar",
     "Error while unsharing" : "Erro ao descompartilhar",
-    "Error while changing permissions" : "Erro ao mudar permissões",
     "Error setting expiration date" : "Erro ao definir data de expiração",
     "The public link will expire no later than {days} days after it is created" : "O link público irá expirar não antes de {days} depois de ser criado",
     "Set expiration date" : "Definir data de expiração",
     "Expiration" : "Expiração",
     "Expiration date" : "Data de expiração",
+    "Choose a password for the public link" : "Escolha uma senha para o link público",
     "Sending ..." : "Enviando ...",
     "Email sent" : "E-mail enviado",
     "Resharing is not allowed" : "Não é permitido re-compartilhar",
@@ -133,13 +150,11 @@ OC.L10N.register(
     "Link" : "Link",
     "Password protect" : "Proteger com senha",
     "Password" : "Senha",
-    "Choose a password for the public link" : "Escolha uma senha para o link público",
     "Allow editing" : "Permitir edição",
     "Email link to person" : "Enviar link por e-mail",
     "Send" : "Enviar",
     "Shared with you and the group {group} by {owner}" : "Compartilhado com você e com o grupo {group} por {owner}",
     "Shared with you by {owner}" : "Compartilhado com você por {owner}",
-    "Shared in {item} with {user}" : "Compartilhado em {item} com {user}",
     "group" : "grupo",
     "remote" : "remoto",
     "notify by email" : "notificar por e-mail",
@@ -150,17 +165,29 @@ OC.L10N.register(
     "change" : "mudança",
     "delete" : "remover",
     "access control" : "controle de acesso",
+    "Could not unshare" : "Não foi possível descompartilhar",
     "Share details could not be loaded for this item." : "Detalhes de compartilhamento não puderam ser carregados para este item.",
+    "No users or groups found for {search}" : "Nenhum usuário grupo encontrado para {search}",
     "An error occured. Please try again" : "Ocorreu um erro. Por favor tente novamente",
+    "{sharee} (group)" : "{sharee} (grupo)",
+    "{sharee} (at {server})" : "{sharee} (no {server})",
+    "{sharee} (remote)" : "{sharee} (remoto)",
     "Share" : "Compartilhar",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Compartilhar com usuários em outros ownClouds usando a sintaxe username@example.com/owncloud",
     "Share with users or groups …" : "Compartilhar com usuários ou grupos ...",
     "Share with users, groups or remote users …" : "Compartilhar com usuários, grupos ou usuários remoto ...",
+    "Error removing share" : "Erro na remoção do compartilhamento",
     "Warning" : "Aviso",
     "Error while sending notification" : "Erro ao enviar notificação",
+    "Non-existing tag #{tag}" : "Etiqueta não existente #{tag}",
+    "not assignable" : "não atribuível",
+    "invisible" : "invisível",
+    "({scope})" : "({scope})",
+    "Delete" : "Eliminar",
+    "Rename" : "Renomear",
+    "Collaborative tags" : "Etiquetas de colaboração",
     "The object type is not specified." : "O tipo de objeto não foi especificado.",
     "Enter new" : "Entrar uma nova",
-    "Delete" : "Eliminar",
     "Add" : "Adicionar",
     "Edit tags" : "Editar etiqueta",
     "Error loading dialog template: {error}" : "Erro carregando diálogo de formatação: {error}",
@@ -171,21 +198,14 @@ OC.L10N.register(
     "Hello {name}, the weather is {weather}" : "Olá {name}, o clima está {weather}",
     "Hello {name}" : "Olá {name}",
     "_download %n file_::_download %n files_" : ["baixar %n arquivo","baixar %n arquivos"],
-    "{version} is available. Get more information on how to update." : "{version} está disponível. Obtenha mais informações sobre como atualizar.",
+    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "A atualização está em andamento, deixando esta página pode haver interrupção do processo em alguns ambientes.",
     "Updating {productName} to version {version}, this may take a while." : "Atualizando {productName} para a versão {version}, isso pode demorar um pouco.",
+    "An error occurred." : "Ocorreu um erro.",
     "Please reload the page." : "Por favor recarregue a página",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "A atualização não foi bem sucedida. Para mais informações <a href=\"{url}\">verificar o nosso post no fórum</a> que abrange esta questão.",
     "The update was unsuccessful. " : "A atualização não foi bem sucedida.",
     "The update was successful. There were warnings." : "A atualização foi bem sucedida. Havia advertências.",
     "The update was successful. Redirecting you to ownCloud now." : "A atualização teve êxito. Você será redirecionado ao ownCloud agora.",
-    "Couldn't reset password because the token is invalid" : "Não foi possível redefinir a senha porque o token é inválido",
-    "Couldn't reset password because the token is expired" : "Não foi possível redefinir a senha porque o token expirou",
-    "Couldn't send reset email. Please make sure your username is correct." : "Não foi possível enviar e-mail de redefinição. Verifique se o seu nome de usuário está correto.",
-    "Couldn't send reset email because there is no email address for this username. Please contact your administrator." : "Não foi possível enviar e-mail de redefinição, porque não há nenhum endereço de e-mail para este nome de usuário. Por favor, contate o administrador.",
-    "%s password reset" : "%s redefinir senha",
-    "Use the following link to reset your password: {link}" : "Use o seguinte link para redefinir sua senha: {link}",
-    "New password" : "Nova senha",
-    "New Password" : "Nova Senha",
-    "Reset password" : "Redefinir senha",
     "Searching other places" : "Pesquisando em outros lugares",
     "No search results in other folders" : "Nenhum resultado de pesquisa em outras pastas",
     "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} resultado da pesquisa em outras pastas","{count} resultados da pesquisa em outras pastas"],
@@ -207,7 +227,7 @@ OC.L10N.register(
     "You can click here to return to %s." : "Você pode clicar aqui para retornar para %s.",
     "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Olá,\n\ngostaria que você soubesse que %s compartilhou %s com você.\nVeja isto: %s\n\n",
     "The share will expire on %s." : "O compartilhamento irá expirar em %s.",
-    "Cheers!" : "Saúde!",
+    "Cheers!" : "Saudações!",
     "Internal Server Error" : "Erro Interno do Servidor",
     "The server encountered an internal error and was unable to complete your request." : "O servidor encontrou um erro interno e não conseguiu concluir o seu pedido.",
     "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Entre em contato com o administrador do servidor se este erro reaparece várias vezes, por favor, inclua os detalhes técnicos abaixo em seu relatório.",
@@ -245,6 +265,7 @@ OC.L10N.register(
     "Finishing …" : "Finalizando ...",
     "Need help?" : "Precisa de ajuda?",
     "See the documentation" : "Veja a documentação",
+    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Olá,<br><br>só para seu conhecimento que %s compartilhou <strong>%s</strong> com você. <br><a href=\"%s\">Visualize-o!</a><br><br> ",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Esta aplicação requer JavaScript para sua correta operação. Por favor {linkstart}habilite JavaScript{linkend} e recerregue a página.",
     "Log out" : "Sair",
     "Search" : "Perquisar",
@@ -254,15 +275,19 @@ OC.L10N.register(
     "Please try again or contact your administrator." : "Por favor tente novamente ou faça contato com o seu administrador.",
     "Log in" : "Entrar",
     "Wrong password. Reset it?" : "Senha incorreta. Redefini-la?",
-    "remember" : "lembrar",
+    "Wrong password." : "Senha errada",
+    "Stay logged in" : "Permaneça logado",
     "Alternative Logins" : "Logins Alternativos",
-    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Olá,<br><br>só para seu conhecimento que %s compartilhou <strong>%s</strong> com você. <br><a href=\"%s\">Verificar!</a><br><br> ",
+    "Use the following link to reset your password: {link}" : "Use o seguinte link para redefinir sua senha: {link}",
+    "New password" : "Nova senha",
+    "New Password" : "Nova Senha",
+    "Reset password" : "Redefinir senha",
     "This ownCloud instance is currently in single user mode." : "Nesta instância ownCloud está em modo de usuário único.",
     "This means only administrators can use the instance." : "Isso significa que apenas os administradores podem usar esta instância.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacte o seu administrador do sistema se esta mensagem persistir ou aparecer inesperadamente.",
     "Thank you for your patience." : "Obrigado pela sua paciência.",
     "You are accessing the server from an untrusted domain." : "Você está acessando o servidor a partir de um domínio não confiável.",
-    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domain\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Por favor, contate o administrador. Se você é um administrador desta instância, configurre o \"trusted_domain\" em config/config.php. Um exemplo de configuração é fornecido em config/config.sample.php.",
+    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Por favor entre em contato com o administrador. Se você é um administrador deste exemplo, configure a definição \"trusted_domains\" em config/config.php. Um exemplo de configuração é fornecido em config/config.sample.php.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Dependendo da configuração, como administrador, você também pode ser capaz de usar o botão abaixo para confiar neste domínio.",
     "Add \"%s\" as trusted domain" : "Adicionar \"%s\" como um domínio confiavel",
     "App update required" : "Atualização de aplicativo é requerida",
