@@ -6,24 +6,41 @@ OC.L10N.register(
     "Turned on maintenance mode" : "Ativado o modo de manutenção",
     "Turned off maintenance mode" : "Desativado o modo de manutenção",
     "Maintenance mode is kept active" : "O modo de manutenção é mantido ativo",
+    "Updating database schema" : "A actualizar o esquema da base de dados",
     "Updated database" : "Base de dados atualizada",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "A verificar se o esquema da base de dados pode ser atualizado (isto pode demorar algum tempo dependendo do tamanho da base de dados)",
     "Checked database schema update" : "Atualização do esquema da base de dados verificada.",
+    "Checking updates of apps" : "A procurar por atualizações das apps",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "A verificar se o esquema da base de dados para %s pode ser atualizado (isto pode demorar algum tempo dependendo do tamanho da base de dados)",
     "Checked database schema update for apps" : "Atualização do esquema da base de dados verificada.",
     "Updated \"%s\" to %s" : "Atualizado \"%s\" para %s",
     "Repair warning: " : "Aviso de reparação:",
     "Repair error: " : "Corrija o erro:",
-    "Following incompatible apps have been disabled: %s" : "As seguintes apps incompatíveis foram desativadas: %s",
+    "Set log level to debug" : "Definir o nível de log para debug",
+    "Reset log level" : "Reiniciar nível de registo",
+    "Starting code integrity check" : "A iniciar verificação de integridade do código",
+    "Finished code integrity check" : "Terminada a verificação de integridade do código",
+    "%s (3rdparty)" : "%s (terceiros)",
+    "%s (incompatible)" : "%s (incompatível)",
     "Following apps have been disabled: %s" : "As seguintes apps foram desativadas: %s",
     "Already up to date" : "Já está atualizado",
+    "Please select a file." : "Por favor, selecione um ficheiro.",
     "File is too big" : "O ficheiro é muito grande",
     "Invalid file provided" : "Ficheiro indicado inválido",
     "No image or file provided" : "Não foi fornecido nenhum ficheiro ou imagem",
     "Unknown filetype" : "Tipo de ficheiro desconhecido",
     "Invalid image" : "Imagem inválida",
+    "An error occurred. Please contact your admin." : "Ocorreu um erro. Por favor, contacte o seu administrador.",
     "No temporary profile picture available, try again" : "Fotografia temporária do perfil indisponível, tente novamente",
     "No crop data provided" : "Não foram fornecidos dados de recorte",
     "No valid crop data provided" : "Não foram indicados dados de recorte válidos",
     "Crop is not square" : "O recorte não é quadrado",
+    "Couldn't reset password because the token is invalid" : "Não foi possível repor a palavra-passe porque a senha é inválida",
+    "Couldn't reset password because the token is expired" : "Não foi possível repor a palavra-passe porque a senha expirou",
+    "Couldn't send reset email. Please make sure your username is correct." : "Ocorreu um problema com o envio do e-mail, por favor confirme o seu utilizador.",
+    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Não foi possível enviar o email de reposição porque não existe nenhum email associado a este utilizador. Por favor contacte o administrador.",
+    "%s password reset" : "%s reposição da palavra-passe",
+    "Couldn't send reset email. Please contact your administrator." : "Não foi possível enviar o e-mail de reposição. Por favor, contacte o administrador.",
     "Sunday" : "Domingo",
     "Monday" : "Segunda",
     "Tuesday" : "Terça",
@@ -69,10 +86,11 @@ OC.L10N.register(
     "Oct." : "Out.",
     "Nov." : "Nov.",
     "Dec." : "Dez.",
+    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Existiram alguns problemas com a verificação de integridade do código. Mais informação…</a>",
     "Settings" : "Definições",
     "Saving..." : "A guardar ...",
+    "Dismiss" : "Rejeitar",
     "seconds ago" : "segundos atrás",
-    "Couldn't send reset email. Please contact your administrator." : "Não foi possível enviar o e-mail de reposição. Por favor, contacte o administrador.",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "A hiperligação para reiniciar a sua senha foi enviada para o seu correio eletrónico. Se não a receber dentro de um tempo aceitável, verifique as suas pastas de span/lixo.<br> Se não a encontrar, pergunte ao seu administrador local.",
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Os seus ficheiros estão encriptados. Se não ativou a chave de recuperação, não terá nenhum modo para voltar obter os seus dados depois de reiniciar a sua senha. <br />Se não tem a certeza do que fazer, por favor, contacte o seu administrador antes de continuar.<br />  Tem a certeza que quer continuar?",
     "I know what I'm doing" : "Eu sei o que eu estou a fazer",
@@ -101,25 +119,30 @@ OC.L10N.register(
     "Good password" : "Palavra-passe boa",
     "Strong password" : "Palavra-passe forte",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "O seu servidor da Web não está configurado corretamente para permitir a sincronização de ficheiro, porque a interface WebDAV parece estar com problemas.",
+    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "O seu servidor web não está configurado corretamente para resolver \"{url}\". Mais informação pode ser encontrada na nossa <a target=\"_blank\" href=\"{docLink}\">documentação</a>.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Este servidor ownCloud não tem uma ligação de Internet a funcionar. Isto significa que algumas funcionalidades como o acesso a locais externos, notificações sobre actualizações, ou a instalação de aplicações de terceiros não irá funcionar. Aceder aos ficheiros remotamente e enviar notificações de email poderão não funcionar também. Sugerimos que active uma ligação à Internet se pretende obter todas as funcionalidades do ownCloud.",
-    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "A sua pasta com os dados e os seus ficheiros estão provavelmente acessíveis a partir das internet. O seu ficheiro .htaccess não está a funcionar corretamente. Sugerimos veementemente que configure o seu servidor web de maneira a que a pasta com os dados deixe de ficar acessível, ou mova a pasta com os dados para fora da raiz de documentos do servidor web.",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "Nenhuma memória de cache foi configurada. Se possível configure-a de forma a optimizar o desempenho. Mais informações podem ser encontradas na <a href=\"{docLink}\">documentação</a>.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "/dev/urandom não é legível pelo PHP, o que é altamente desanimador por motivos de segurança. Pode ser encontrada mais informação na <a href=\"{docLink}\">documentação</a>.",
-    "Your PHP version ({version}) is no longer <a href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "A sua versão ({version}) do PHP já não é <a href=\"{phpLink}\">suportada pelo PHP</a>. Nós encorajamos-lo a atualizar a sua versão do PHP para aproveitar o desempenho e as atualizações de segurança fornecidas pelo PHP.´«",
+    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Nenhuma memória cache foi configurada. Para melhorar o seu desempenho, por favor configure a memcache, se disponível. Mais informação pode ser encontrada na nossa <a target=\"_blank\" href=\"{docLink}\">documentação</a>.",
+    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "/dev/urandom não é legível pelo PHP, o que é altamente desanimador por motivos de segurança. Pode ser encontrada mais informação na <a target=\"_blank\" href=\"{docLink}\">documentação</a>.",
+    "Your PHP version ({version}) is no longer <a target=\"_blank\" href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "A sua versão ({version}) do PHP já não é <a target=\"_blank\" href=\"{phpLink}\">suportada pelo PHP</a>. Nós encorajamos-lhe a atualizar a sua versão do PHP para aproveitar o desempenho e as atualizações de segurança fornecidas pelo PHP.",
+    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "A configuração dos proxy headers reversos está incorreta, ou então está a aceder ao ownCloud através de um proxy de confiança. Se não está a aceder ao ownCloud através de um proxy de confiança, isto é um problema de segurança e poderá permitir a um invasor falsificar o seu endereço IP como visível para o ownCloud. Mais informação pode ser encontrada na nossa <a target=\"_blank\" href=\"{docLink}\">documentação</a>.",
+    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached está configurada como cache distribuída, mas o módulo \"memcache\" PHP errado está instalado. \\OC\\Memcache\\Memcached apenas suporta \"memcached\" e não \"memcache\". Leia a <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki sobre ambos os módulos</a>.",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Alguns ficheiros não passaram na verificação de integridade. Mais informação sobre este assunto pode ser encontrada na nossa <a target=\"_blank\" href=\"{docLink}\">documentação</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Lists de ficheiros inválidos…</a> / <a href=\"{rescanEndpoint}\">Reverificar…</a>)",
     "Error occurred while checking server setup" : "Ocorreu um erro durante a verificação da configuração do servidor",
+    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "A sua pasta com os dados e os seus ficheiros estão provavelmente acessíveis a partir das internet. O seu ficheiro .htaccess não está a funcionar corretamente. Sugerimos veementemente que configure o seu servidor web de maneira a que a pasta com os dados deixe de ficar acessível, ou mova a pasta com os dados para fora da raiz de documentos do servidor web.",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "O cabeçalho HTTP \"{header}\" não está configurado para igualar \"{expected}\". Isto é um potencial risco de segurança ou privacidade e recomendamos que o corrija.",
+    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "O cabeçalho HTTP \"Strict-Transport-Security\" não está configurado para um mínimo de \"{seconds}\" segundos. Para uma segurança melhorada recomendados a ativação do HSTS como descrito nas nossas <a href=\"{docUrl}\">dicas de segurança</a>.",
     "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Está a aceder a este site via HTTP. Nós recomendamos vivamente que configure o seu servidor para requerer a utilização de HTTPS,  em vez do que está descrito nas nossas <a href=\"{docUrl}\">dicas de segurança</a>.",
     "Shared" : "Partilhado",
     "Shared with {recipients}" : "Partilhado com {recipients}",
     "Error" : "Erro",
     "Error while sharing" : "Erro ao partilhar",
     "Error while unsharing" : "Erro ao remover a partilha",
-    "Error while changing permissions" : "Erro ao mudar permissões",
     "Error setting expiration date" : "Erro ao aplicar a data de expiração",
     "The public link will expire no later than {days} days after it is created" : "O link público expira, o mais tardar {days} dias após sua criação",
     "Set expiration date" : "Definir a data de expiração",
     "Expiration" : "Data de expiração",
     "Expiration date" : "Data de expiração",
+    "Choose a password for the public link" : "Defina a palavra-passe para a hiperligação pública",
     "Sending ..." : "A Enviar...",
     "Email sent" : "Mensagem enviada",
     "Resharing is not allowed" : "Não é permitido partilhar de novo",
@@ -127,13 +150,11 @@ OC.L10N.register(
     "Link" : "Hiperligação",
     "Password protect" : "Proteger com Palavra-passe",
     "Password" : "Palavra-passe",
-    "Choose a password for the public link" : "Defina a palavra-passe para a hiperligação pública",
     "Allow editing" : "Permitir edição",
     "Email link to person" : "Enviar a hiperligação para a pessoa",
     "Send" : "Enviar",
     "Shared with you and the group {group} by {owner}" : "Partilhado consigo e com o grupo {group} por {owner}",
     "Shared with you by {owner}" : "Partilhado consigo por {owner}",
-    "Shared in {item} with {user}" : "Partilhado em {item} com {user}",
     "group" : "grupo",
     "remote" : "remoto",
     "notify by email" : "Notificar por correio eletrónico",
@@ -144,16 +165,29 @@ OC.L10N.register(
     "change" : "alterar",
     "delete" : "apagar",
     "access control" : "controlo de acesso",
+    "Could not unshare" : "Não foi possível cancelar a partilha",
+    "Share details could not be loaded for this item." : "Não foi possível carregar os detalhes de partilha para este item.",
+    "No users or groups found for {search}" : "Nenhuns utilizadores ou grupos encontrados para {search}",
     "An error occured. Please try again" : "Ocorreu um erro. Por favor, tente de novo",
+    "{sharee} (group)" : "{sharee} (grupo)",
+    "{sharee} (at {server})" : "{sharee} (em {server})",
+    "{sharee} (remote)" : "{sharee} (remoto)",
     "Share" : "Compartilhar",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Compartilhe com as pessoas nas outras ownClouds utilizando a sintaxe username@example.com/owncloud",
     "Share with users or groups …" : "Partilhar com utilizadores ou grupos...",
     "Share with users, groups or remote users …" : "Partilhar com utilizadores, grupos ou utilizadores remotos...",
+    "Error removing share" : "Erro ao remover partilha",
     "Warning" : "Aviso",
     "Error while sending notification" : "Erro enquanto estava a enviar a notificação",
+    "Non-existing tag #{tag}" : "Etiqueta não existente #{tag}",
+    "not assignable" : "não atribuível",
+    "invisible" : "invisível",
+    "({scope})" : "({scope})",
+    "Delete" : "Apagar",
+    "Rename" : "Renomear",
+    "Collaborative tags" : "Etiquetas colaborativas",
     "The object type is not specified." : "O tipo de objeto não está especificado.",
     "Enter new" : "Introduza novo",
-    "Delete" : "Apagar",
     "Add" : "Adicionar",
     "Edit tags" : "Editar etiquetas",
     "Error loading dialog template: {error}" : "Ocorreu um erro ao carregar o modelo de janela: {error}",
@@ -164,22 +198,17 @@ OC.L10N.register(
     "Hello {name}, the weather is {weather}" : "Olá {name}, o tempo está {weather}",
     "Hello {name}" : "Olá {name}",
     "_download %n file_::_download %n files_" : ["transferir %n ficheiro","transferir %n ficheiros"],
-    "{version} is available. Get more information on how to update." : "{version} está disponível. Obtenha mais informação sobre como atualizar.",
+    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "A atualização está em curso. Deixar esta página agora poderá interromper o processo nalguns ambientes.",
     "Updating {productName} to version {version}, this may take a while." : "A atualizar {productName} para a versão {version}, isto poderá demorar algum tempo.",
+    "An error occurred." : "Ocorreu um erro.",
     "Please reload the page." : "Por favor, recarregue a página.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "A atualização falhou. Para mais informação <a href=\"{url}\">verifique o nosso fórum</a> sobre como resolver este problema.",
     "The update was unsuccessful. " : "Não foi possível atualizar.",
     "The update was successful. There were warnings." : "A atualização foi bem sucedida. Tem alguns avisos.",
     "The update was successful. Redirecting you to ownCloud now." : "A actualização foi concluída com sucesso. Vai ser redireccionado para o ownCloud agora.",
-    "Couldn't reset password because the token is invalid" : "Não foi possível repor a palavra-passe porque a senha é inválida",
-    "Couldn't reset password because the token is expired" : "Não foi possível repor a palavra-passe porque a senha expirou",
-    "Couldn't send reset email. Please make sure your username is correct." : "Ocorreu um problema com o envio do e-mail, por favor confirme o seu utilizador.",
-    "Couldn't send reset email because there is no email address for this username. Please contact your administrator." : "Ocorreu um problema com o envio do e-mail, por favor contacte o administrador.",
-    "%s password reset" : "%s reposição da palavra-passe",
-    "Use the following link to reset your password: {link}" : "Utilize a seguinte hiperligação para repor a sua palavra-passe: {link}",
-    "New password" : "Nova palavra-chave",
-    "New Password" : "Nova palavra-passe",
-    "Reset password" : "Repor palavra-passe",
     "Searching other places" : "A pesquisar noutros lugares",
+    "No search results in other folders" : "Sem resultados de procura nas outras pastas",
+    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} resultado de pesquisa noutra pasta","{count} resultados de pesquisa noutras pastas"],
     "Personal" : "Pessoal",
     "Users" : "Utilizadores",
     "Apps" : "Apps",
@@ -236,6 +265,7 @@ OC.L10N.register(
     "Finishing …" : "A terminar...",
     "Need help?" : "Precisa de ajuda?",
     "See the documentation" : "Veja a documentação",
+    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Olá,<br><br>apenas para informar que %s partilhou <strong>%s</strong> consigo.<br><a href=\"%s\">Consulte aqui!</a><br><br>",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Esta aplicação requer JavaScript para funcionar correctamente. Por favor, {linkstart}active o JavaScript{linkend} e recarregue a página.",
     "Log out" : "Terminar sessão",
     "Search" : "Procurar",
@@ -245,15 +275,19 @@ OC.L10N.register(
     "Please try again or contact your administrator." : "Por favor tente de novo ou contacte o administrador.",
     "Log in" : "Iniciar Sessão",
     "Wrong password. Reset it?" : "Senha errada. Repô-la?",
-    "remember" : "lembrar",
+    "Wrong password." : "Palavra-passe errada.",
+    "Stay logged in" : "Manter sessão iniciada",
     "Alternative Logins" : "Contas de acesso alternativas",
-    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Olá,<br><br>apenas para informar que %s partilhou <strong>%s</strong> consigo.<br><a href=\"%s\">Consulte aqui!</a><br><br>",
+    "Use the following link to reset your password: {link}" : "Utilize a seguinte hiperligação para repor a sua palavra-passe: {link}",
+    "New password" : "Nova palavra-chave",
+    "New Password" : "Nova palavra-passe",
+    "Reset password" : "Repor palavra-passe",
     "This ownCloud instance is currently in single user mode." : "Esta instância do ownCloud está actualmente configurada no modo de utilizador único.",
     "This means only administrators can use the instance." : "Isto significa que apenas os administradores podem usar a instância.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacte o seu administrador de sistema se esta mensagem continuar a aparecer ou apareceu inesperadamente.",
     "Thank you for your patience." : "Obrigado pela sua paciência.",
     "You are accessing the server from an untrusted domain." : "Está a aceder ao servidor a partir de um domínio que não é de confiança.",
-    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domain\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Por favor contacte o seu administrador. Se é um administrador desta instância, configure as definições \"trusted_domain\" em config/config.php. Um exemplo de configuração é fornecido em config/config.sample.php.",
+    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Por favor contacte o seu administrador. Se é um administrador desta instância, configure as definições \"trusted_domains\" em config/config.php. Um exemplo de configuração é fornecido em config/config.sample.php.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Dependendo da configuração, como administrador, você também pode ser capaz de usar o botão abaixo para confiar neste domínio.",
     "Add \"%s\" as trusted domain" : "Adicionar \"%s\" como um domínio de confiança",
     "App update required" : "É necessário atualizar a app",
