@@ -3,30 +3,44 @@ OC.L10N.register(
     {
     "Couldn't send mail to following users: %s " : "Невозможно отправить письмо следующим пользователям: %s",
     "Preparing update" : "Подготовка к обновлению",
-    "Migration tests are skipped - \"update.skip-migration-test\" is activated in config.php" : "Миграционные тесты пропущены - параметр \"update.skip-migration-test\" указан в config.php",
     "Turned on maintenance mode" : "Режим отладки включён",
     "Turned off maintenance mode" : "Режим отладки отключён",
     "Maintenance mode is kept active" : "Режим обслуживания оставлен включенным",
+    "Updating database schema" : "Обновление схемы базы данных",
     "Updated database" : "База данных обновлена",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Проверка возможности обновления схемы базы данных (это может занять длительное время в зависимости от размера базы данных)",
     "Checked database schema update" : "Проверено обновление схемы БД",
+    "Checking updates of apps" : "Проверка обновлений для приложений",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Проверка возможности обновления схемы базы данных для %s (это может занять длительное время в зависимости от размера базы данных)",
     "Checked database schema update for apps" : "Проверено обновление схемы БД приложений",
     "Updated \"%s\" to %s" : "Обновлено \"%s\" до %s",
     "Repair warning: " : "Предупреждение восстановления:",
     "Repair error: " : "Ошибка восстановления:",
-    "Set log level to debug - current level: \"%s\"" : "Установить отладочное журналирование - текущий уровень: \"%s\"",
-    "Reset log level to  \"%s\"" : "Сбросить уровень журналирования в \"%s\"",
-    "Following incompatible apps have been disabled: %s" : "Следующие несовместимые приложения были отключены: %s",
+    "Set log level to debug" : "Установить журнал в режим отладки",
+    "Reset log level" : "Сбросить уровень журнала",
+    "Starting code integrity check" : "Начинается проверка целостности кода",
+    "Finished code integrity check" : "Проверка целостности кода завершина",
+    "%s (3rdparty)" : "%s (стороннее)",
+    "%s (incompatible)" : "%s (несовместим)",
     "Following apps have been disabled: %s" : "Были отключены следующие приложения: %s",
     "Already up to date" : "Не нуждается в обновлении",
-    "File is too big" : "Файл слишком большой",
+    "Please select a file." : "Пожалуйста выберите файл.",
+    "File is too big" : "Файл слишком велик",
     "Invalid file provided" : "Указан неправильный файл",
     "No image or file provided" : "Не указано изображение или файл",
     "Unknown filetype" : "Неизвестный тип файла",
     "Invalid image" : "Некорректное изображение",
+    "An error occurred. Please contact your admin." : "Произошла ошибка. Пожалуйста, свяжитесь с Вашим администратором.",
     "No temporary profile picture available, try again" : "Временная картинка профиля недоступна, повторите попытку",
     "No crop data provided" : "Не указана информация о кадрировании",
     "No valid crop data provided" : "Не указаны корректные данные о кадрировании",
     "Crop is not square" : "Кадр не является квадратом",
+    "Couldn't reset password because the token is invalid" : "Не удалось сбросить пароль из-за неверного токена",
+    "Couldn't reset password because the token is expired" : "Не удалось сбросить пароль, так как срок действия токена истек.",
+    "Couldn't send reset email. Please make sure your username is correct." : "Не удалось отправить письмо для сброса пароля. Убедитесь, что имя пользователя указано верно.",
+    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Не удалось отправить письмо сброса так как у данного пользователя не задан адрес электронной почты. Пожалуйста, обратитесь к администратору.",
+    "%s password reset" : "Сброс пароля %s",
+    "Couldn't send reset email. Please contact your administrator." : "Не удалось отправить письмо для сброса пароля. Пожалуйста, свяжитесь с вашим администратором.",
     "Sunday" : "Воскресенье",
     "Monday" : "Понедельник",
     "Tuesday" : "Вторник",
@@ -72,11 +86,12 @@ OC.L10N.register(
     "Oct." : "Окт.",
     "Nov." : "Ноя.",
     "Dec." : "Дек.",
+    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\"> Были обнаружены проблемы с проверкой целостности кода. Подробнее ...",
     "Settings" : "Настройки",
     "Saving..." : "Сохранение...",
+    "Dismiss" : "Прекратить",
     "seconds ago" : "несколько секунд назад",
-    "Couldn't send reset email. Please contact your administrator." : "Не удалось отправить письмо для сброса пароля. Пожалуйста, свяжитесь с вашим администратором.",
-    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Ссылка для сброса пароля была отправлена на ваш email. Если вы не получили письмо в течении разумного промежутка времени, проверьте папку спама.<br>Если его там нет, то обратитесь к вашему администратору.",
+    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Ссылка для сброса пароля была отправлена на ваш email. Если вы не получили письмо в течении разумного промежутка времени, проверьте папку со спамом.<br>Если его там нет, то обратитесь к вашему администратору.",
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Ваши файлы зашифрованы. Если вы не включили ключ восстановления, то ваши данные будут недоступны после сброса пароля.<br />Если вы не уверены что делать дальше - обратитесь к вашему администратору.<br />Вы действительно хотите продолжить?",
     "I know what I'm doing" : "Я понимаю, что делаю",
     "Password can not be changed. Please contact your administrator." : "Пароль не может быть изменён. Пожалуйста, свяжитесь с вашим администратором.",
@@ -103,28 +118,30 @@ OC.L10N.register(
     "So-so password" : "Так себе пароль",
     "Good password" : "Хороший пароль",
     "Strong password" : "Устойчивый к взлому пароль",
-    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Ваш веб-сервер еще не настроен должным образом, чтобы позволить синхронизацию файлов, потому что интерфейс WebDAV, кажется, испорчен.",
-    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Этот сервер не имеет подключения к Интернету. Это означает, что некоторые из функций, таких как внешнее хранилище, уведомления об обновлениях и установки сторонних приложений не будут работать. Доступ к файлам удаленно и отправки уведомлений по почте могут не работать. Мы предлагаем включить подключение к Интернету для этого сервера, если вы хотите, чтобы все функции работали.",
-    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Ваш каталог данных и ваши файлы возможно доступны из интернете. .htaccess файл не работает. Мы настоятельно рекомендуем вам настроить ваш веб сервер таким образом, что-бы каталог данных не был больше доступен или переместите каталог данных за пределы корня веб сервера.",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "Не настроена система кеширования. Для увеличения производительности сервера, по возможности, настройте memcache. Более подробную информацию, вы можете посмотреть в нашей <a href=\"{docLink}\">документации</a>.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "/dev/urandom не может быть прочитан PHP, что крайне нежелательно по причинам безопасности. Дополнительную информацию можно найти в a href=\"{docLink}\">документации</a>.",
-    "Your PHP version ({version}) is no longer <a href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "Ваша версия PHP ({version}) более не <a href=\"{phpLink}\">поддерживается PHP</a>. Мы советуем Вам обновить Вашу версию PHP для получения обновлений производительности и безопасности, предоставляемых PHP.",
-    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "Конфигурация заголовков обратного прокси сервера некорректна, либо Вы заходите в ownCloud через доверенный прокси. Если Вы не заходите в ownCloud через доверенный прокси, это может быть небезопасно, так как злоумышленник может подменить видимые Owncloud IP-адреса. Более подробную информацию можно найти в нашей <a href=\"{docLink}\">документации</a>.",
+    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Ваш веб-сервер еще не настроен должным образом чтобы позволить синхронизацию файлов, потому что интерфейс WebDAV, кажется, испорчен.",
+    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Ваш сервер не настроен для правильного разрешения \"{url}\". За дополнительной информацией обратитесь к нашей <a target=\"_blank\" href=\"{docLink}\">документации</a>.",
+    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Этот сервер не имеет подключения к Интернету. Это означает, что некоторые из функций, таких как внешнее хранилище, уведомления об обновлениях и установка сторонних приложений не будут работать. Доступ к файлам удаленно и отправки уведомлений по почте могут не работать. Рекомендуется разрешить данному серверу доступ в Интернет если хотите, чтобы все функции работали.",
+    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Кэш-памяти не настроено. Для повышения производительности, пожалуйста, настройте кэш-памяти (memcache) если есть такая возможность. Дополнительную информацию можно найти в нашей <a target=\"_blank\" href=\"{docLink}\"> документации </a>.",
+    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "/dev/urandom не доступно чтение для PHP, что крайне нежелательно по соображениям безопасности. Дополнительную информацию можно найти в нашей <a target=\"_blank\" href=\"{docLink}\"> документации </a>.",
+    "Your PHP version ({version}) is no longer <a target=\"_blank\" href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "Ваша версия PHP  ({version}) больше не <a target=\"_blank\" href=\"{phpLink}\"> поддерживается разработчиками PHP</a>. Мы рекомендуем Вам обновить версию PHP, чтобы воспользоваться производительностью и безопасностью, предусмотренных в обновленной версии PHP.",
+    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Конфигурация заголовков обратного прокси не верна, либо доступ к ownCloud осуществлён через доверенный прокси. Если ownCloud открыт не через доверенный прокси то это проблема безопасности, которая может позволить атакующему подделать IP адрес, который видит ownCloud. Дополнительная информация доступна в нашей  <a target=\"_blank\" href=\"{docLink}\">документации</a>.",
+    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "В качестве распределённого кеша настроен memcached, но установлен неверный модуль PHP \"memcache\". \\OC\\Memcache\\Memcached поддерживает только \"memcached\", но не \"memcache\". Изучите <a target=\"_blank\" href=\"{wikiLink}\">оба модуля в memcached wiki</a>.",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Некоторые файлы не прошли проверку целостности. Дополнительная информация о том, как устранить данную проблему доступна в нашей <a target=\"_blank\" href=\"{docLink}\">документации</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Список проблемных файлов…</a> / <a href=\"{rescanEndpoint}\">Сканировать ещё раз…</a>)",
     "Error occurred while checking server setup" : "Произошла ошибка при проверке настроек сервера",
-    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "Заголовок HTTP \"{header}\" не настроен на ожидаемый \"{expected}\". Это потенциальная проблема безопасности и мы рекомендуем изменить эти настройки.",
-    "The \"Strict-Transport-Security\" HTTP header is not configured to least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "Заголовок HTTP \"Strict-Transport-Security\" должен быть настроен хотя бы на \"{seconds}\" секунд. Для улучшения безопасности мы рекомендуем включить HSTS согласно нашим <a href=\"{docUrl}\">подсказкам по безопасности</a>.",
+    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Ваш каталог данных и ваши файлы возможно доступны из Интернета. Файл .htaccess не работает. Мы настоятельно рекомендуем Вам настроить веб сервер таким образом, чтобы каталог данных не был больше доступен или переместить каталог данных за пределы корня веб сервера.",
+    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "Заголовок HTTP \"{header}\" не настроен на значение \"{expected}\". Это потенциальная проблема безопасности и мы рекомендуем изменить эти настройки.",
     "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Вы зашли на этот сайт через HTTP. Мы настоятельно рекомендуем настроить ваш сервер на использование HTTPS согласно нашим <a href=\"{docUrl}\">подсказкам по безопасности</a>.",
     "Shared" : "Общий доступ",
     "Shared with {recipients}" : "Вы поделились с {recipients}",
     "Error" : "Ошибка",
     "Error while sharing" : "При попытке поделиться произошла ошибка",
     "Error while unsharing" : "При закрытии доступа произошла ошибка",
-    "Error while changing permissions" : "При изменении прав доступа произошла ошибка",
     "Error setting expiration date" : "Ошибка при установке срока доступа",
     "The public link will expire no later than {days} days after it is created" : "Срок действия публичной ссылки истекает не позже чем через {days} дней после её создания",
     "Set expiration date" : "Установить срок действия",
     "Expiration" : "Срок действия",
     "Expiration date" : "Дата окончания",
+    "Choose a password for the public link" : "Укажите пароль для публичной ссылки",
     "Sending ..." : "Отправляется ...",
     "Email sent" : "Письмо отправлено",
     "Resharing is not allowed" : "Повторное открытие доступа запрещено",
@@ -132,13 +149,11 @@ OC.L10N.register(
     "Link" : "Ссылка",
     "Password protect" : "Защитить паролем",
     "Password" : "Пароль",
-    "Choose a password for the public link" : "Укажите пароль для публичной ссылки",
     "Allow editing" : "Разрешить редактирование",
     "Email link to person" : "Отправить ссылку по электронной почте",
     "Send" : "Отправить",
     "Shared with you and the group {group} by {owner}" : "{owner} поделился с вами и группой {group} ",
     "Shared with you by {owner}" : "С вами поделился {owner} ",
-    "Shared in {item} with {user}" : "Общий доступ в {item} для {user}",
     "group" : "группа",
     "remote" : "удаленный",
     "notify by email" : "уведомить по почте",
@@ -149,17 +164,28 @@ OC.L10N.register(
     "change" : "изменить",
     "delete" : "удалить",
     "access control" : "контроль доступа",
-    "Share details could not be loaded for this item." : "Информация об общем доступе для этого элемента не может быть загружена.",
+    "Could not unshare" : "Не удается отменить доступ",
+    "Share details could not be loaded for this item." : "Не удалось загрузить информацию об общем доступе для этого элемента.",
+    "No users or groups found for {search}" : "Не найдено пользователей или групп по запросу {search}",
     "An error occured. Please try again" : "Произошла ошибка. Попробуйте ещё раз",
+    "{sharee} (group)" : "{sharee} (группа)",
+    "{sharee} (at {server})" : "{sharee} (на {server})",
+    "{sharee} (remote)" : "{sharee} (удалённо)",
     "Share" : "Поделиться",
-    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Поделиться с людьми на других серверах ownCloud используя синтакс username@example.com/owncloud",
+    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Поделиться с людьми на других серверах ownCloud используя формат username@example.com/owncloud",
     "Share with users or groups …" : "Поделиться с пользователями или группами ...",
     "Share with users, groups or remote users …" : "Поделиться с пользователями, группами или удаленными пользователями ...",
+    "Error removing share" : "Ошибка удаления общего доступа",
     "Warning" : "Предупреждение",
-    "Error while sending notification" : "Ошибка отправки уведомления",
+    "Error while sending notification" : "Ошибка при отправке уведомления",
+    "Non-existing tag #{tag}" : "Несуществующий тег #{tag}",
+    "not assignable" : "не назначаемый",
+    "invisible" : "невидимый",
+    "({scope})" : "({scope})",
+    "Delete" : "Удалить",
+    "Rename" : "Переименовать",
     "The object type is not specified." : "Тип объекта не указан",
     "Enter new" : "Ввести новое",
-    "Delete" : "Удалить",
     "Add" : "Добавить",
     "Edit tags" : "Изменить метки",
     "Error loading dialog template: {error}" : "Ошибка загрузки шаблона диалога: {error}",
@@ -170,24 +196,17 @@ OC.L10N.register(
     "Hello {name}, the weather is {weather}" : "Здравствуйте {name}, погода {weather}",
     "Hello {name}" : "Здравствуйте {name}",
     "_download %n file_::_download %n files_" : ["скачать %n файл","скачать %n файла","скачать %n файлов","скачать %n файлов"],
-    "{version} is available. Get more information on how to update." : "Доступна версия {version}. Получить дополнительную информацию о порядке обновления.",
-    "Updating {productName} to version {version}, this may take a while." : "Идет обновление {productName} до версии {version}, пожалуйста, подождите.",
-    "Please reload the page." : "Обновите страницу.",
-    "The update was unsuccessful. " : "Обновление не удалось.",
+    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Идет обновление. Покидая эту страницу, вы можете прервать процесс обновления.",
+    "Updating {productName} to version {version}, this may take a while." : "Идет обновление {productName} до версии {version}, это может занять некоторое время.",
+    "An error occurred." : "Произошла ошибка.",
+    "Please reload the page." : "Пожалуйста, обновите страницу.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Обновление прошло не успешно. За дополнительной информацией по этой проблеме <a href=\"{url}\">обратитесь к нашему форуму</a>.",
+    "The update was unsuccessful. " : "Обновление окончилось неудачей.",
     "The update was successful. There were warnings." : "Обновление прошло успешно. Были предупреждения.",
     "The update was successful. Redirecting you to ownCloud now." : "Обновление прошло успешно. Перенаправляем в ownCloud.",
-    "Couldn't reset password because the token is invalid" : "Невозможно сбросить пароль из-за неверного токена",
-    "Couldn't reset password because the token is expired" : "Не удается сбросить пароль, так как токен истек.",
-    "Couldn't send reset email. Please make sure your username is correct." : "Не удалось отправить письмо для сброса пароля. Убедитесь, что имя пользователя указано верно.",
-    "Couldn't send reset email because there is no email address for this username. Please contact your administrator." : "Невозможно отправить письмо для сброса пароля, для вашей учетной записи не указан адрес электронной почты. Пожалуйста, свяжитесь с администратором.",
-    "%s password reset" : "Сброс пароля %s",
-    "Use the following link to reset your password: {link}" : "Используйте следующую ссылку чтобы сбросить пароль: {link}",
-    "New password" : "Новый пароль",
-    "New Password" : "Новый пароль",
-    "Reset password" : "Сбросить пароль",
     "Searching other places" : "Идет поиск в других местах",
-    "No search results in other folders" : "Нет результатов поиска в других папках",
-    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} результат в другой папке","{count} результата в другой папке","{count} результатов в другой папке","{count} результатов в другой папке"],
+    "No search results in other folders" : "В других папках ничего не найдено",
+    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} результат в другой папке","{count} результата в другой папке","{count} результатов в другой папке","{count} результатов в других папках"],
     "Personal" : "Личное",
     "Users" : "Пользователи",
     "Apps" : "Приложения",
@@ -209,7 +228,7 @@ OC.L10N.register(
     "Cheers!" : "Всего наилучшего!",
     "Internal Server Error" : "Внутренняя ошибка сервера",
     "The server encountered an internal error and was unable to complete your request." : "Запрос не выполнен, на сервере произошла ошибка.",
-    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Пожалуйста, свяжитесь с администратором сервера, если эта ошибка будет повторяться, прикрепите технические детали к своему сообщению.",
+    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Пожалуйста, свяжитесь с администратором сервера если эта ошибка будет повторяться. Прикрепите указанную ниже информацию к своему сообщению.",
     "More details can be found in the server log." : "Больше деталей может быть найдено в журнале сервера.",
     "Technical details" : "Технические детали",
     "Remote Address: %s" : "Удаленный адрес: %s",
@@ -219,10 +238,10 @@ OC.L10N.register(
     "Message: %s" : "Сообщение: %s",
     "File: %s" : "Файл: %s",
     "Line: %s" : "Линия: %s",
-    "Trace" : "След",
+    "Trace" : "Трассировка",
     "Security warning" : "Предупреждение безопасности",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Правила файла .htaccess не выполняются, возможно, каталог данных и файлы свободно доступны из интернета.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Что-бы правильно настроить сервер, руководствуйтесь <a hrev=\"%s\"target=\"blank\">документацией</a>.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Правила файла .htaccess не выполняются. Возможно, каталог данных и файлы свободно доступны из интернета.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Что-бы правильно настроить сервер, воспользуйтесь <a hrev=\"%s\"target=\"blank\">документацией</a>.",
     "Create an <strong>admin account</strong>" : "Создать <strong>учётную запись администратора</strong>",
     "Username" : "Имя пользователя",
     "Storage & database" : "Хранилище и база данных",
@@ -238,31 +257,36 @@ OC.L10N.register(
     "Database host" : "Хост базы данных",
     "Performance warning" : "Предупреждение о производительности",
     "SQLite will be used as database." : "В качестве базы данных будет использована SQLite.",
-    "For larger installations we recommend to choose a different database backend." : "Для крупных проектов мы советуем выбрать другую базу данных.",
-    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Особенно вызывает сомнение использование SQLite при синхронизации файлов с использование клиента для ПК.",
+    "For larger installations we recommend to choose a different database backend." : "Для крупных проектов мы советуем выбрать другой тип базы данных.",
+    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "В частности не рекомендуется использовать SQLite при синхронизации файлов с использованием клиента для ПК.",
     "Finish setup" : "Завершить установку",
     "Finishing …" : "Завершение...",
     "Need help?" : "Нужна помощь?",
     "See the documentation" : "Посмотреть документацию",
-    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Это приложение требует включённый JavaScript для корректной работы. Пожалуйста, <a href=\"http://enable-javascript.com/\" target=\"_blank\">включите JavaScript</a> и перезагрузите интерфейс.",
+    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Здравствуйте,<br><br>%s поделился с вами <strong>%s</strong>.<br>Перейдите по <a href=\"%s\">ссылке</a>, чтобы посмотреть<br><br>",
+    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Для корректной работы приложения требуется JavaScript. Пожалуйста, {linkstart}включите JavaScript{linkend} и обновите страницу.",
     "Log out" : "Выйти",
     "Search" : "Найти",
-    "Server side authentication failed!" : "Неудачная аутентификация с сервером!",
-    "Please contact your administrator." : "Пожалуйста, свяжитесь с вашим администратором.",
-    "An internal error occured." : "Произошла внутренняя ошибка",
+    "Server side authentication failed!" : "Ошибка аутентификации на стороне сервера!",
+    "Please contact your administrator." : "Пожалуйста, обратитесь к администратору.",
+    "An internal error occured." : "Произошла внутренняя ошибка.",
     "Please try again or contact your administrator." : "Пожалуйста попробуйте ещё раз или свяжитесь с вашим администратором",
     "Log in" : "Войти",
     "Wrong password. Reset it?" : "Неправильный пароль. Сбросить его?",
-    "remember" : "запомнить",
+    "Wrong password." : "Неправильный пароль.",
+    "Stay logged in" : "Оставаться в системе",
     "Alternative Logins" : "Альтернативные имена пользователя",
-    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Здравствуйте,<br><br>%s поделился с вами <strong>%s</strong>.<br>Перейдите по <a href=\"%s\">ссылке</a>, чтобы посмотреть<br><br>",
+    "Use the following link to reset your password: {link}" : "Используйте следующую ссылку чтобы сбросить пароль: {link}",
+    "New password" : "Новый пароль",
+    "New Password" : "Новый пароль",
+    "Reset password" : "Сбросить пароль",
     "This ownCloud instance is currently in single user mode." : "Сервер ownCloud в настоящее время работает в однопользовательском режиме.",
     "This means only administrators can use the instance." : "Это значит, что только администраторы могут использовать сервер.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Обратитесь к вашему системному администратору если это сообщение не исчезает или появляется неожиданно.",
     "Thank you for your patience." : "Спасибо за терпение.",
-    "You are accessing the server from an untrusted domain." : "Вы пытаетесь получить доступ к серверу с неподтверждённого домена.",
-    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domain\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Пожалуйста, свяжитесь с вашим администратором. Если вы администратор этого сервера, сконфигурируйте \"trusted_domain\" в config/config.php. Пример настройки можно найти в /config/config.sample.php.",
-    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "В зависимости от конфигурации, как администратор вы можете также внести домен в доверенные с помощью кнопки ниже.",
+    "You are accessing the server from an untrusted domain." : "Вы пытаетесь получить доступ к серверу с недоверенного домена.",
+    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Пожалуйста, обратитесь к администратору. Если вы являетесь администратором этого сервера, настройте параметры \"trusted_domains\" в файле config/config.php. Пример настройки можно найти в config/config.sample.php.",
+    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "В зависимости от конфигурации, как администратор вы можете также внести домен в доверенные с помощью кнопки, расположенной ниже.",
     "Add \"%s\" as trusted domain" : "Добавить \"%s\" как доверенный домен",
     "App update required" : "Требуется обновление приложения",
     "%s will be updated to version %s" : "%s будет обновлен до версии %s",
@@ -271,8 +295,8 @@ OC.L10N.register(
     "The theme %s has been disabled." : "Тема %s была отключена.",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Перед продолжением убедитесь, что вы сделали резервную копию базы данных, каталога конфигурации и каталога с данными.",
     "Start update" : "Запустить обновление",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Чтобы избежать задержек в крупных установках, вы можете выполнить следующую команду в каталоге установки:",
-    "This %s instance is currently in maintenance mode, which may take a while." : "Это %s находится в режиме технического обслуживания, которое может занять некоторое время.",
-    "This page will refresh itself when the %s instance is available again." : "Эта страница обновится, когда экземпляр %s снова станет доступен."
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Чтобы избежать тайм-аутов в крупных установках, вместо этого можно выполнить следующую команду в каталоге установки:",
+    "This %s instance is currently in maintenance mode, which may take a while." : "Этот сервер %s находится в режиме технического обслуживания, которое может занять некоторое время.",
+    "This page will refresh itself when the %s instance is available again." : "Эта страница автоматически обновится, когда сервер %s снова станет доступен."
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
