@@ -3,30 +3,44 @@ OC.L10N.register(
     {
     "Couldn't send mail to following users: %s " : "Şu kullanıcılara posta gönderilemedi: %s",
     "Preparing update" : "Güncelleme hazırlanıyor",
-    "Migration tests are skipped - \"update.skip-migration-test\" is activated in config.php" : "Taşıma testleri atlandı - config.php içerisinde \"update.skip-migration-test\" etkinleştirildi",
     "Turned on maintenance mode" : "Bakım kipi etkinleştirildi",
     "Turned off maintenance mode" : "Bakım kipi kapatıldı",
     "Maintenance mode is kept active" : "Bakım kipi etkin tutuldu",
+    "Updating database schema" : "Veritabanı şeması güncelleniyor",
     "Updated database" : "Veritabanı güncellendi",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Veritabanı şeması güncellenebilirliği denetleniyor (Veritabanının büyüklüğüne bağlı olarak uzun sürebilir)",
     "Checked database schema update" : "Veritabanı şema güncellemesi denetlendi",
+    "Checking updates of apps" : "Uygulamaların güncellemeleri denetleniyor",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "%s için veritabanı güncellenebilirliği denetleniyor (Veritabanının büyüklüğüne bağlı olarak uzun sürebilir)",
     "Checked database schema update for apps" : "Uygulamalar için veritabanı şema güncellemesi denetlendi",
     "Updated \"%s\" to %s" : "\"%s\", %s sürümüne güncellendi",
     "Repair warning: " : "Onarım uyarısı:",
     "Repair error: " : "Onarım hatası:",
-    "Set log level to debug - current level: \"%s\"" : "Günlük seviyesini hata ayıklamaya ayarla - geçerli seviye: \"%s\"",
-    "Reset log level to  \"%s\"" : "Günlük seviyesini \"%s\" olarak sıfırla",
-    "Following incompatible apps have been disabled: %s" : "Aşağıdaki uyumsuz uygulamalar devre dışı bırakıldı: %s",
+    "Set log level to debug" : "Günlük seviyesini hata ayıklama olarak ayarla",
+    "Reset log level" : "Günlük seviyesini sıfırla",
+    "Starting code integrity check" : "Kod bütünlük sınaması başlatılıyor",
+    "Finished code integrity check" : "Kod bütünlük sınaması bitti",
+    "%s (3rdparty)" : "%s (3. parti)",
+    "%s (incompatible)" : "%s (uyumsuz)",
     "Following apps have been disabled: %s" : "Aşağıdaki uygulamalar devre dışı bırakıldı: %s",
     "Already up to date" : "Zaten güncel",
+    "Please select a file." : "Lütfen bir dosya seçin.",
     "File is too big" : "Dosya çok büyük",
     "Invalid file provided" : "Geçersiz dosya sağlandı",
     "No image or file provided" : "Resim veya dosya belirtilmedi",
     "Unknown filetype" : "Bilinmeyen dosya türü",
     "Invalid image" : "Geçersiz resim",
+    "An error occurred. Please contact your admin." : "Bir hata oluştu. Lütfen yöneticinize başvurun.",
     "No temporary profile picture available, try again" : "Kullanılabilir geçici profil resmi yok, tekrar deneyin",
     "No crop data provided" : "Kesme verisi sağlanmamış",
     "No valid crop data provided" : "Geçerli kırpma verisi sağlanmadı",
     "Crop is not square" : "Kırpma kare değil",
+    "Couldn't reset password because the token is invalid" : "Belirteç geçersiz olduğundan parola sıfırlanamadı",
+    "Couldn't reset password because the token is expired" : "Jeton zaman aşımına uğradığından parola sıfırlanamadı",
+    "Couldn't send reset email. Please make sure your username is correct." : "Sıfırlama e-postası gönderilemedi. Lütfen kullanıcı adınızın doğru olduğundan emin olun.",
+    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Sıfırlama e-postası, bu kullanıcı için bir e-posta adresi olmadığından gönderilemedi. Lütfen yöneticiniz ile iletişime geçin.",
+    "%s password reset" : "%s parola sıfırlama",
+    "Couldn't send reset email. Please contact your administrator." : "Sıfırlama e-postası gönderilemedi. Lütfen yöneticiniz ile iletişime geçin.",
     "Sunday" : "Pazar",
     "Monday" : "Pazartesi",
     "Tuesday" : "Salı",
@@ -72,10 +86,11 @@ OC.L10N.register(
     "Oct." : "Eki.",
     "Nov." : "Kas.",
     "Dec." : "Ara.",
+    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Kod bütünlük sınamasında sorunlar oluştu. Daha fazla bilgi…</a>",
     "Settings" : "Ayarlar",
     "Saving..." : "Kaydediliyor...",
+    "Dismiss" : "İptal et",
     "seconds ago" : "saniyeler önce",
-    "Couldn't send reset email. Please contact your administrator." : "Sıfırlama e-postası gönderilemedi. Lütfen yöneticiniz ile iletişime geçin.",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Parolanızı değiştirme bağlantısı e-posta adresinize gönderildi. Makul bir süre içerisinde almadıysanız spam/gereksiz klasörlerini kontrol ediniz.<br>Bu konumlarda da yoksa yerel sistem yöneticinize sorunuz.",
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Dosyalarınız şifrelenmiş. Kurtarma anahtarını etkinleştirmemişseniz, parola sıfırlama işleminden sonra verilerinize erişmeniz imkansız olacak.<br />Ne yaptığınızdan emin değilseniz, devam etmeden önce sistem yöneticiniz ile iletişime geçin.<br />Gerçekten devam etmek istiyor musunuz?",
     "I know what I'm doing" : "Ne yaptığımı biliyorum",
@@ -104,27 +119,29 @@ OC.L10N.register(
     "Good password" : "İyi parola",
     "Strong password" : "Güçlü parola",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Web sunucunuz dosya transferi için düzgün bir şekilde yapılandırılmamış. WevDAV arabirimini sorunlu gözüküyor.",
+    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Web sunucunuz \"{url}\" çözümlemesini yapmak üzere doğru yapılandırılmaış.  Daha fazla bilgi <a href=\"{docLink}\">belgelendirmemizde</a> bulunabilir.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Bu sunucunun çalışan bir İnternet bağlantısı yok. Bu, harici depolama alanı bağlama, güncelleştirme bildirimleri veya üçüncü parti uygulama kurma gibi bazı özellikler çalışmayacak demektir. Uzak dosyalara erişim ve e-posta ile bildirim gönderme de çalışmayacaktır. Eğer bu özelliklerin tamamını kullanmak istiyorsanız, sunucu için İnternet bağlantısını etkinleştirmenizi öneriyoruz.",
-    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "data dizininiz ve dosyalarınız büyük ihtimalle İnternet üzerinden erişilebilir. .htaccess dosyası çalışmıyor. Web sunucunuzu yapılandırarak data dizinine erişimi kapatmanızı veya data dizinini web sunucu belge dizini dışına almanızı şiddetle tavsiye ederiz.",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "Hafıza önbelleği ayarlanmamış. Performansın artması için mümkünse lütfen bir memcache ayarlayın. Detaylı bilgiye <a href=\"{docLink}\">belgelendirmemizden</a> ulaşabilirsiniz.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "Güvenlik sebepleri ile şiddetle kaçınılması gereken /dev/urandom PHP tarafından okunamıyor. Daha fazla bilgi <a href=\"{docLink}\">belgelendirmemizde</a> bulunabilir.",
-    "Your PHP version ({version}) is no longer <a href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "Kullandığınız PHP sürümü ({version}) artık <a href=\"{phpLink}\">PHP tarafından desteklenmiyor</a>. PHP tarafından sağlanan performans ve güvenlik güncellemelerinden faydalanmak için PHP sürümünüzü güncellemenizi öneririz.",
-    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "Ters vekil sunucu başlık yapılandırması hatalı veya ownCloud'a güvenilen bir vekil sunucusundan erişiyorsunuz. ownCloud'a güvenilen bir vekil sunucusundan erişmiyorsanız bu bir güvenlik problemidir ve bir saldırganın IP adresinizi taklit etmesine izin verebilir. Ayrıntılı bilgiyi <a href=\"{docLink}\">belgelendirmemizde</a> bulabilirsiniz.",
+    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Hafıza önbelleği ayarlanmamış. Performansın artması için mümkünse lütfen bir memcache ayarlayın. Detaylı bilgiye <a  target=\"_blank\" href=\"{docLink}\">belgelendirmemizden</a> ulaşabilirsiniz.",
+    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Güvenlik sebepleri ile şiddetle kaçınılması gereken /dev/urandom PHP tarafından okunamıyor. Daha fazla bilgi <a  target=\"_blank\" href=\"{docLink}\">belgelendirmemizde</a> bulunabilir.",
+    "Your PHP version ({version}) is no longer <a target=\"_blank\" href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "Kullandığınız PHP sürümü ({version}) artık <a  target=\"_blank\" href=\"{phpLink}\">PHP tarafından desteklenmiyor</a>. PHP tarafından sağlanan performans ve güvenlik güncellemelerinden faydalanmak için PHP sürümünüzü güncellemenizi öneririz.",
+    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Ters vekil sunucu başlık yapılandırması hatalı veya ownCloud'a güvenilen bir vekil sunucusundan erişiyorsunuz. ownCloud'a güvenilen bir vekil sunucusundan erişmiyorsanız bu bir güvenlik problemidir ve bir saldırganın IP adresinizi taklit etmesine izin verebilir. Ayrıntılı bilgiyi <a  target=\"_blank\" href=\"{docLink}\">belgelendirmemizde</a> bulabilirsiniz.",
+    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached ayrılmış önbellek olarak yapılandırıldı, ancak yanlış PHP modülü \"memcache\" olarak yüklendi. \\OC\\Memcache\\Memcached sadece \"memcached\" olarak desteklenir, \"memcache\" olarak kullanamazsınız.  <a  target=\"_blank\" href=\"{wikiLink}\">memcached wiki about both modules</a> linkine bakınız.",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Bazı dosyalar bütünleme sınamasından geçemedi. Bu sorunu çözmek için daha fazla bilgi <a target=\"_blank\" href=\"{docLink}\">belgelendirmemizde</a> bulunabilir. (<a href=\"{codeIntegrityDownloadEndpoint}\">Geçersiz dosyaların listesi…</a> / <a href=\"{rescanEndpoint}\">Yeniden tara…</a>)",
     "Error occurred while checking server setup" : "Sunucu yapılandırması denetlenirken hata oluştu",
+    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "data dizininiz ve dosyalarınız büyük ihtimalle İnternet üzerinden erişilebilir. .htaccess dosyası çalışmıyor. Web sunucunuzu yapılandırarak data dizinine erişimi kapatmanızı veya data dizinini web sunucu belge dizini dışına almanızı şiddetle tavsiye ederiz.",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "\"{header}\" HTTP başlığı \"{expected}\" ile eşleşmek üzere yapılandırılmamış. Bu muhtemel bir güvenlik veya gizlilik riski olduğundan bu ayarı düzeltmenizi öneririz.",
-    "The \"Strict-Transport-Security\" HTTP header is not configured to least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "\"Strict-Transport-Security\" HTTP başlığı en az \"{seconds}\" saniye olarak ayarlanmış. İyileştirilmiş güvenlik için <a href=\"{docUrl}\">güvenlik ipuçlarımızda</a> belirtilen HSTS etkinleştirmesini öneririz.",
     "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Bu siteye HTTP aracılığıyla erişiyorsunuz. Sunucunuzu <a href=\"{docUrl}\">güvenlik ipuçlarımızda</a> gösterildiği şekilde HTTPS kullanımını zorlamak üzere yapılandırmanızı şiddetle öneririz.",
     "Shared" : "Paylaşılan",
     "Shared with {recipients}" : "{recipients} ile paylaşılmış",
     "Error" : "Hata",
     "Error while sharing" : "Paylaşım sırasında hata",
     "Error while unsharing" : "Paylaşım iptal edilirken hata",
-    "Error while changing permissions" : "İzinleri değiştirirken hata",
     "Error setting expiration date" : "Son kullanma tarihi ayarlama hatası",
     "The public link will expire no later than {days} days after it is created" : "Herkese açık bağlantı, oluşturulduktan en geç {days} gün sonra sona erecek",
     "Set expiration date" : "Son kullanma tarihini ayarla",
     "Expiration" : "Bitiş",
     "Expiration date" : "Son kullanım tarihi",
+    "Choose a password for the public link" : "Herkese açık bağlantı için bir parola seçin",
     "Sending ..." : "Gönderiliyor...",
     "Email sent" : "E-posta gönderildi",
     "Resharing is not allowed" : "Tekrar paylaşmaya izin verilmiyor",
@@ -132,13 +149,11 @@ OC.L10N.register(
     "Link" : "Bağlantı",
     "Password protect" : "Parola koruması",
     "Password" : "Parola",
-    "Choose a password for the public link" : "Herkese açık bağlantı için bir parola seçin",
     "Allow editing" : "Düzenlemeye izin ver",
     "Email link to person" : "Bağlantıyı e-posta ile gönder",
     "Send" : "Gönder",
     "Shared with you and the group {group} by {owner}" : "{owner} tarafından sizinle ve {group} ile paylaştırılmış",
     "Shared with you by {owner}" : "{owner} tarafından sizinle paylaşıldı",
-    "Shared in {item} with {user}" : "{item} içinde {user} ile paylaşılanlar",
     "group" : "grup",
     "remote" : "uzak",
     "notify by email" : "e-posta ile bildir",
@@ -149,17 +164,25 @@ OC.L10N.register(
     "change" : "değiştir",
     "delete" : "sil",
     "access control" : "erişim kontrolü",
+    "Could not unshare" : "Paylaşım kaldırılamadı",
     "Share details could not be loaded for this item." : "Bu öge için paylaşma ayrıntıları yüklenemedi.",
+    "No users or groups found for {search}" : "{search} için kullanıcı veya grup bulunamadı",
     "An error occured. Please try again" : "Bir hata oluştu. Lütfen yeniden deneyin",
     "Share" : "Paylaş",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "kullanıcı@example.com/owncloud şeklinde diğer ownCloud kullanan diğer kullanıcılarla paylaş",
     "Share with users or groups …" : "Kullanıcı ve gruplarla paylaş...",
     "Share with users, groups or remote users …" : "Kullanıcılar, gruplar veya uzak kullanıcılarla paylaş ...",
+    "Error removing share" : "Paylaşım kaldırılırken hata",
     "Warning" : "Uyarı",
     "Error while sending notification" : "Bildirim gönderilirken hata",
+    "Non-existing tag #{tag}" : "Mevcut olmayan etiket #{tag}",
+    "not assignable" : "atanamaz",
+    "invisible" : "görünmez",
+    "({scope})" : "({scope})",
+    "Delete" : "Sil",
+    "Rename" : "Yeniden adlandır",
     "The object type is not specified." : "Nesne türü belirtilmemiş.",
     "Enter new" : "Yeni girin",
-    "Delete" : "Sil",
     "Add" : "Ekle",
     "Edit tags" : "Etiketleri düzenle",
     "Error loading dialog template: {error}" : "İletişim şablonu yüklenirken hata: {error}",
@@ -170,21 +193,14 @@ OC.L10N.register(
     "Hello {name}, the weather is {weather}" : "Merhaba {name}, hava durumu {weather}",
     "Hello {name}" : "Merhaba {name}",
     "_download %n file_::_download %n files_" : ["%n dosya indir","%n dosya indir"],
-    "{version} is available. Get more information on how to update." : "Sürüm {version} hazır. Nasıl güncelleyeceğinizle ilgili daha fazla bilgi alın.",
+    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Güncelleme yapılıyor, sayfadan ayrılmak bazı işlemleri kesebilir.",
     "Updating {productName} to version {version}, this may take a while." : "{productName}, {version} sürümüne güncelleniyor, bu biraz zaman alabilir.",
+    "An error occurred." : "Bir hata oluştu",
     "Please reload the page." : "Lütfen sayfayı yeniden yükleyin.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Güncelleme başarısız oldu. Daha fazla bilgi için bu sorunu kapsayan <a href=\"{url}\">forum gönderimize</a> bakın.",
     "The update was unsuccessful. " : "Güncelleştirme başarısız.",
     "The update was successful. There were warnings." : "Güncelleme başarılı. Uyarılar mevcut.",
     "The update was successful. Redirecting you to ownCloud now." : "Güncelleme başarılı. Şimdi ownCloud'a yönlendiriliyorsunuz.",
-    "Couldn't reset password because the token is invalid" : "Belirteç geçersiz olduğundan parola sıfırlanamadı",
-    "Couldn't reset password because the token is expired" : "Jeton zaman aşımına uğradığından parola sıfırlanamadı",
-    "Couldn't send reset email. Please make sure your username is correct." : "Sıfırlama e-postası gönderilemedi. Lütfen kullanıcı adınızın doğru olduğundan emin olun.",
-    "Couldn't send reset email because there is no email address for this username. Please contact your administrator." : "Sıfırlama e-postası, bu kullanıcı için bir e-posta adresi olmadığından gönderilemedi. Lütfen yöneticiniz ile iletişime geçin.",
-    "%s password reset" : "%s parola sıfırlama",
-    "Use the following link to reset your password: {link}" : "Parolanızı sıfırlamak için bu bağlantıyı kullanın: {link}",
-    "New password" : "Yeni parola",
-    "New Password" : "Yeni Parola",
-    "Reset password" : "Parolayı sıfırla",
     "Searching other places" : "Diğer konumlarda aranıyor",
     "No search results in other folders" : "Diğer klasörlerde arama sonucu yok",
     "_{count} search result in another folder_::_{count} search results in other folders_" : ["Diğer klasörlerde {count} arama sonucu","Diğer bir klasörde {count} arama sonucu"],
@@ -244,6 +260,7 @@ OC.L10N.register(
     "Finishing …" : "Tamamlanıyor ...",
     "Need help?" : "Yardım mı lazım?",
     "See the documentation" : "Belgelendirmeye bak",
+    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Merhaba, <br><br>%s kullanıcısının sizinle <strong>%s</strong> paylaşımında bulunduğunu bildirmek istedik.<br><a href=\"%s\">Paylaşımı gör!</a><br><br>",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Bu uygulama düzgün çalışabilmesi için JavaScript gerektirir. Lütfen {linkstart}JavaScript'i etkinleştirin{linkend} ve sayfayı yeniden yükleyin.",
     "Log out" : "Çıkış yap",
     "Search" : "Ara",
@@ -253,15 +270,19 @@ OC.L10N.register(
     "Please try again or contact your administrator." : "Lütfen yeniden deneyin veya yöneticinizle iletişim kurun.",
     "Log in" : "Giriş yap",
     "Wrong password. Reset it?" : "Hatalı parola. Sıfırlansın mı?",
-    "remember" : "hatırla",
+    "Wrong password." : "Hatalı parola.",
+    "Stay logged in" : "Bağlı kal",
     "Alternative Logins" : "Alternatif Girişler",
-    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Merhaba, <br><br>%s kullanıcısının sizinle <strong>%s</strong> paylaşımında bulunduğunu bildirmek istedik.<br><a href=\"%s\">Paylaşımı gör!</a><br><br>",
+    "Use the following link to reset your password: {link}" : "Parolanızı sıfırlamak için bu bağlantıyı kullanın: {link}",
+    "New password" : "Yeni parola",
+    "New Password" : "Yeni Parola",
+    "Reset password" : "Parolayı sıfırla",
     "This ownCloud instance is currently in single user mode." : "Bu ownCloud örneği şu anda tek kullanıcı kipinde.",
     "This means only administrators can use the instance." : "Bu, örneği sadece yöneticiler kullanabilir demektir.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Eğer bu ileti görünmeye devam ederse veya beklenmedik şekilde ortaya çıkmışsa sistem yöneticinizle iletişime geçin.",
     "Thank you for your patience." : "Sabrınız için teşekkür ederiz.",
     "You are accessing the server from an untrusted domain." : "Sunucuya güvenilmeyen bir alan adından ulaşıyorsunuz.",
-    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domain\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Lütfen yöneticiniz ile iletişime geçin. Eğer bu örneğin bir yöneticisi iseniz, config/config.php dosyası içerisindeki \"trusted_domain\" ayarını yapılandırın. Bu yapılandırmanın bir örneği config/config.sample.php dosyasında verilmiştir.",
+    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Lütfen yöneticiniz ile iletişime geçin. Eğer bu örneğin bir yöneticisi iseniz, config/config.php dosyası içerisindeki \"trusted_domain\" ayarını yapılandırın. Bu yapılandırmanın bir örneği config/config.sample.php dosyasında verilmiştir.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Yapılandırmanıza bağlı olarak, bir yönetici olarak bu alan adına güvenmek için aşağıdaki düğmeyi de kullanabilirsiniz.",
     "Add \"%s\" as trusted domain" : "\"%s\" alan adını güvenilir olarak ekle",
     "App update required" : "Uygulama güncellemesi gerekli",
