@@ -56,10 +56,11 @@ OC.L10N.register(
     "Archives of type %s are not supported" : "Los ficheros de tipo %s no son soportados",
     "Failed to open archive when installing app" : "Falló la apertura ded fichero mientras se instalaba la aplicación",
     "App does not provide an info.xml file" : "La aplicación no suministra un fichero info.xml",
+    "Signature could not get checked. Please contact the app developer and check your admin screen." : "La firma no pudo ser evaluada. Por favor, contacte con el desarrollador de la aplicación y compruebe su pantalla de administración.",
     "App can't be installed because of not allowed code in the App" : "La aplicación no puede ser instalada por tener código no autorizado en la aplicación",
     "App can't be installed because it is not compatible with this version of ownCloud" : "La aplicación no se puede instalar porque no es compatible con esta versión de ownCloud",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "La aplicación no se puede instalar porque contiene la etiqueta\n<shipped>\ntrue\n</shipped>\nque no está permitida para aplicaciones no distribuidas",
-    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "La aplicación no puede ser instalada por que la versión en info.xml/version no es la misma que la establecida en la app store",
+    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "La App no se puede instalar debido a que la versión de info.xml no es la misma que la versión reportada por la App Store.",
     "Application is not enabled" : "La aplicación no está habilitada",
     "Authentication error" : "Error de autenticación",
     "Token expired. Please reload page." : "Token expirado. Por favor, recarge la página.",
@@ -87,7 +88,7 @@ OC.L10N.register(
     "Sharing %s failed, because the backend does not allow shares from type %i" : "No se pudo compartir %s porque el repositorio no permite recursos compartidos del tipo %i",
     "Sharing %s failed, because the file does not exist" : "No se pudo compartir %s porque el archivo no existe",
     "You are not allowed to share %s" : "Usted no está autorizado para compartir %s",
-    "Sharing %s failed, because the user %s is the item owner" : "Se ha fallado al compartir %s, ya que el usuario %s es el dueño del elemento",
+    "Sharing %s failed, because you can not share with yourself" : "Se falló al compartir %s, porque no puedes compartir contigo mismo",
     "Sharing %s failed, because the user %s does not exist" : "Se ha fallado al compartir %s, ya que el usuario %s no existe",
     "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Se ha fallado al compartir %s, ya que el usuario %s no es miembro de ningún grupo del que %s sea miembro",
     "Sharing %s failed, because this item is already shared with %s" : "Se falló al compartir %s, ya que este elemento ya está compartido con %s",
@@ -96,6 +97,7 @@ OC.L10N.register(
     "Sharing %s failed, because %s is not a member of the group %s" : "Se falló al compartir %s, ya que %s no es miembro del grupo %s",
     "You need to provide a password to create a public link, only protected links are allowed" : "Es necesario definir una contraseña para crear un enlace publico. Solo los enlaces protegidos están permitidos",
     "Sharing %s failed, because sharing with links is not allowed" : "Se falló al compartir %s, ya que no está permitida la compartición con enlaces",
+    "Not allowed to create a federated share with the same user" : "No se permite crear un recurso compartido federado con el mismo usuario",
     "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Se falló al compartir %s. No se pudo hallar %s, quizás haya un problema de conexión con el servidor.",
     "Share type %s is not valid for %s" : "Compartir tipo %s no es válido para %s",
     "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "La configuración de permisos para %s ha fallado, ya que los permisos superan los permisos dados a %s",
@@ -106,15 +108,19 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "El motor compartido %s debe implementar la interfaz OCP\\Share_Backend",
     "Sharing backend %s not found" : "El motor compartido %s no se ha encontrado",
     "Sharing backend for %s not found" : "Motor compartido para %s no encontrado",
-    "Sharing %s failed, because the user %s is the original sharer" : "Se ha fallado al compartir %s, ya que el usuario %s es el compartidor original",
+    "Sharing failed, because the user %s is the original sharer" : "Se ha fallado al compartir, ya que el usuario %s es el compartidor original",
     "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Se ha fallado al compartir %s, ya que los permisos superan los permisos otorgados a %s",
     "Sharing %s failed, because resharing is not allowed" : "Se ha fallado al compartir %s, ya que volver a compartir no está permitido",
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Se ha fallado al compartir %s porque el motor compartido para %s podría no encontrar su origen",
     "Sharing %s failed, because the file could not be found in the file cache" : "Se ha fallado al compartir %s, ya que el archivo no pudo ser encontrado en el cache de archivo",
+    "Cannot increase permissions of %s" : "No se pueden incrementar los permisos de %s",
+    "Expiration date is in the past" : "Ha pasado la fecha de caducidad",
+    "Cannot set expiration date more than %s days in the future" : "No se puede fijar la fecha de caducidad más de %s días en el futuro.",
     "Could not find category \"%s\"" : "No puede encontrar la categoría \"%s\"",
     "Apps" : "Aplicaciones",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"" : "Solo los siguientes caracteres están permitidos en un nombre de usuario: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Solo los siguientes caracteres están permitidos en un nombre de usuario: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"",
     "A valid username must be provided" : "Se debe proporcionar un nombre de usuario válido",
+    "Username contains whitespace at the beginning or at the end" : "El nombre de usuario contiene espacios en blanco al principio o al final",
     "A valid password must be provided" : "Se debe proporcionar una contraseña válida",
     "The username is already being used" : "El nombre de usuario ya está en uso",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "No están instalados los drivers de BBDD  (sqlite, mysql, o postgresql)",
@@ -140,14 +146,17 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Consulte al administrador de su servidor para reiniciar el servidor web.",
     "PostgreSQL >= 9 required" : "PostgreSQL 9 o superior requerido.",
     "Please upgrade your database version" : "Actualice su versión de base de datos.",
-    "Error occurred while checking PostgreSQL version" : "Ha ocurrido un error mientras se comprobaba la versión de PostgreSQL",
-    "Please make sure you have PostgreSQL >= 9 or check the logs for more information about the error" : "Por favor, asegúrese de que tiene PostgreSQL 9 o superior, o revise los registros para obtener más información acerca del error.",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Por favor cambie los permisos a 0770 para que el directorio no se pueda mostrar para otros usuarios.",
     "Data directory (%s) is readable by other users" : "El directorio de datos (%s) se puede leer por otros usuarios.",
     "Data directory (%s) must be an absolute path" : "El directorio de datos (%s) debe ser una ruta absoluta",
     "Check the value of \"datadirectory\" in your configuration" : "Compruebe el valor de \"datadirectory\" en su configuración.",
     "Data directory (%s) is invalid" : "El directorio de datos (%s) no es válido",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Verifique que el directorio de datos contiene un archivo \".ocdata\" en su directorio raíz.",
-    "Could not obtain lock type %d on \"%s\"." : "No se pudo realizar el bloqueo %d en \"%s\"."
+    "Could not obtain lock type %d on \"%s\"." : "No se pudo realizar el bloqueo %d en \"%s\".",
+    "Storage unauthorized. %s" : "Almacenamiento no autorizado. %s",
+    "Storage incomplete configuration. %s" : "Configuración de almacenamiento incompleta. %s",
+    "Storage connection error. %s" : "Error de conexión de almacenamiento. %s",
+    "Storage not available" : "Almacenamiento no disponible",
+    "Storage connection timeout. %s" : "Tiempo de conexión de almacenamiento agotado. %s"
 },
 "nplurals=2; plural=(n != 1);");
