@@ -58,7 +58,6 @@ OC.L10N.register(
     "App can't be installed because of not allowed code in the App" : "Non é posíbel instalar a aplicación por mor de conter código non permitido",
     "App can't be installed because it is not compatible with this version of ownCloud" : "Non é posíbel instalar a aplicación por non seren compatíbel  con esta versión do ownCloud.",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Non é posíbel instalar a aplicación por conter a etiqueta <shipped>true</shipped> que non está permitida para as aplicacións non enviadas",
-    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "Non é posíbel instalar a aplicación xa que a versión en info.xml/version non é a mesma que a versión informada desde a App Store",
     "Application is not enabled" : "A aplicación non está activada",
     "Authentication error" : "Produciuse un erro de autenticación",
     "Token expired. Please reload page." : "Testemuña caducada. Recargue a páxina.",
@@ -86,7 +85,6 @@ OC.L10N.register(
     "Sharing %s failed, because the backend does not allow shares from type %i" : "Fallou a compartición de %s, xa que a infraestrutura non permite accións do tipo %i",
     "Sharing %s failed, because the file does not exist" : "Fallou a compartición de %s, o ficheiro non existe",
     "You are not allowed to share %s" : "Non ten permiso para compartir %s",
-    "Sharing %s failed, because the user %s is the item owner" : "Fallou a compartición de %s, o propietario do elemento é o usuario %s",
     "Sharing %s failed, because the user %s does not exist" : "Fallou a compartición de %s, o usuario %s non existe",
     "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Fallou a compartición de %s, o usuario %s non é membro de ningún grupo que sexa membro de %s",
     "Sharing %s failed, because this item is already shared with %s" : "Fallou a compartición de %s, este elemento xa está compartido con %s",
@@ -104,14 +102,12 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "A infraestrutura de compartición %s ten que implementar a interface OCP\\Share_Backend",
     "Sharing backend %s not found" : "Non se atopou a infraestrutura de compartición %s",
     "Sharing backend for %s not found" : "Non se atopou a infraestrutura de compartición para %s",
-    "Sharing %s failed, because the user %s is the original sharer" : "Fallou a compartición de %s, a compartición orixinal é do usuario %s",
     "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Fallou a compartición de %s, os permisos superan os permisos concedidos a %s",
     "Sharing %s failed, because resharing is not allowed" : "Fallou a compartición de %s, non está permitido repetir a compartción",
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Fallou a compartición de %s, a infraestrutura de compartición para %s non foi quen de atopar a orixe",
     "Sharing %s failed, because the file could not be found in the file cache" : "Fallou a compartición de %s, non foi posíbel atopar o ficheiro na caché de ficheiros",
     "Could not find category \"%s\"" : "Non foi posíbel atopar a categoría «%s»",
     "Apps" : "Aplicacións",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"" : "Só se permiten os seguintes caracteres no nome de usuario: «a-z», «A-Z», «0-9», e «_.@-»",
     "A valid username must be provided" : "Debe fornecer un nome de usuario",
     "A valid password must be provided" : "Debe fornecer un contrasinal",
     "The username is already being used" : "Este nome de usuario xa está a ser usado",
@@ -138,14 +134,13 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Pregúntelle ao administrador do servidor polo reinicio do servidor web..",
     "PostgreSQL >= 9 required" : "Requírese PostgreSQL >= 9",
     "Please upgrade your database version" : "Anove a versión da súa base de datos",
-    "Error occurred while checking PostgreSQL version" : "Produciuse un erro mentres comprobaba a versión de PostgreSQL",
-    "Please make sure you have PostgreSQL >= 9 or check the logs for more information about the error" : "Asegúrese de que dispón do PostgreSQL >= 9 ou comprobe os rexistros para obter máis información sobre este erro",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Cambie os permisos a 0770 para que o directorio non poida seren listado por outros usuarios.",
     "Data directory (%s) is readable by other users" : "O directorio de datos (%s) é lexíbel por outros usuarios",
     "Data directory (%s) must be an absolute path" : "O directorio de datos (%s) debe ser unha ruta absoluta",
     "Check the value of \"datadirectory\" in your configuration" : "Comprobe o valor de «datadirectory» na configuración",
     "Data directory (%s) is invalid" : "O directorio de datos (%s) non é correcto",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Comprobe que o directorio de datos conten un ficheiro «.ocdata» na súa raíz.",
-    "Could not obtain lock type %d on \"%s\"." : "Non foi posíbel obter un bloqueo do tipo %d en «%s»."
+    "Could not obtain lock type %d on \"%s\"." : "Non foi posíbel obter un bloqueo do tipo %d en «%s».",
+    "Storage not available" : "Almacenamento non dispoñíbel"
 },
 "nplurals=2; plural=(n != 1);");
