@@ -12,12 +12,10 @@ OC.L10N.register(
     "Log" : "Καταγραφές",
     "Tips & tricks" : "Συμβουλές & τεχνάσματα",
     "Updates" : "Ενημερώσεις",
-    "Authentication error" : "Σφάλμα πιστοποίησης",
-    "Your full name has been changed." : "Το πλήρες όνομά σας άλλαξε.",
-    "Unable to change full name" : "Δεν ήταν δυνατή η αλλαγή του πλήρους ονόματός σας",
     "Couldn't remove app." : "Αδυναμία αφαίρεσης εφαρμογής.",
     "Language changed" : "Η γλώσσα άλλαξε",
     "Invalid request" : "Μη έγκυρο αίτημα",
+    "Authentication error" : "Σφάλμα πιστοποίησης",
     "Admins can't remove themself from the admin group" : "Οι διαχειριστές δεν μπορούν να αφαιρέσουν τους εαυτούς τους από την ομάδα των διαχειριστών",
     "Unable to add user to group %s" : "Αδυναμία προσθήκη χρήστη στην ομάδα %s",
     "Unable to remove user from group %s" : "Αδυναμία αφαίρεσης χρήστη από την ομάδα %s",
@@ -53,6 +51,8 @@ OC.L10N.register(
     "Invalid user" : "Μη έγκυρος χρήστης",
     "Unable to change mail address" : "Αδυναμία αλλαγής διεύθυνσης αλληλογραφίας",
     "Email saved" : "Το email αποθηκεύτηκε ",
+    "Your full name has been changed." : "Το πλήρες όνομά σας άλλαξε.",
+    "Unable to change full name" : "Δεν ήταν δυνατή η αλλαγή του πλήρους ονόματός σας",
     "Are you really sure you want add \"{domain}\" as trusted domain?" : "Είστε πραγματικά σίγουροι ότι θέλετε να προσθέσετε το \"{domain}\" σαν αξιόπιστη περιοχή;",
     "Add trusted domain" : "Προσθέστε αξιόπιστη περιοχή",
     "Migration in progress. Please wait until the migration is finished" : "Μετάβαση σε εξέλιξη. Παρακαλούμε περιμένετε μέχρι να ολοκληρωθεί η μετάβαση",
@@ -62,6 +62,7 @@ OC.L10N.register(
     "Approved" : "Εγκεκριμένο",
     "Experimental" : "Πειραματικό",
     "All" : "Όλες",
+    "No apps found for your version" : "Δεν βρέθηκαν εφαρμογές για αυτή την έκδοση",
     "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Οι επίσημες εφαρμογές αναπτύσσονται από την κοινότητα ownCloud. Προσφέρουν λειτουργικότητα κοντά στο ownCloud και είναι έτοιμες για χρήση.",
     "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Οι εγκεκριμένες εφαρμογές αναπτύχθηκαν από αξιόπιστους προγραμματιστές και έχουν περάσει έναν συνοπτικό έλεγχο ασφαλείας. Διατηρούνται ενεργά σε ένα αποθετήριο ανοιχτού κώδικα και οι συντηρητές θεωρούν οτι είναι σταθερές για κανονική χρήση.",
     "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Η εφαρμογή αυτή δεν ελέγχεται για θέματα ασφάλειας και είναι νέα ή είναι γνωστό ότι είναι ασταθής. Η εγκατάσταση γίνεται με δική σας ευθύνη.",
@@ -79,6 +80,10 @@ OC.L10N.register(
     "Uninstall" : "Απεγκατάσταση",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Η εφαρμογή έχει ενεργοποιηθεί αλλά χρειάζεται ενημέρωση. Θα μεταφερθείτε στη σελίδα ενημέρωσης σε 5 δευτερόλεπτα.",
     "App update" : "Ενημέρωση εφαρμογής",
+    "No apps found for \"{query}\"" : "Δεν βρέθηκαν εφαρμογές για \"{query\"}",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Προέκυψε σφάλμα. Παρακαλούμε μεταφορτώστε ένα πιστοποιητικό PEM κωδικοποιημένο κατά ASCII.",
+    "Valid until {date}" : "Έγκυρο έως {date}",
+    "Delete" : "Διαγραφή",
     "An error occurred: {message}" : "Παρουσιάστηκε σφάλμα: {message}",
     "Select a profile picture" : "Επιλογή εικόνας προφίλ",
     "Very weak password" : "Πολύ αδύναμο συνθηματικό",
@@ -86,12 +91,8 @@ OC.L10N.register(
     "So-so password" : "Μέτριο συνθηματικό",
     "Good password" : "Καλό συνθηματικό",
     "Strong password" : "Δυνατό συνθηματικό",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Προέκυψε σφάλμα. Παρακαλούμε μεταφορτώστε ένα πιστοποιητικό PEM κωδικοποιημένο κατά ASCII.",
-    "Valid until {date}" : "Έγκυρο έως {date}",
-    "Delete" : "Διαγραφή",
     "Groups" : "Ομάδες",
     "Unable to delete {objName}" : "Αδυναμία διαγραφής του {objName}",
-    "Error creating group" : "Σφάλμα δημιουργίας ομάδας",
     "A valid group name must be provided" : "Πρέπει να δοθεί ένα έγκυρο όνομα ομάδας",
     "deleted {groupName}" : "διαγραφή {groupName}",
     "undo" : "αναίρεση",
@@ -101,13 +102,11 @@ OC.L10N.register(
     "add group" : "προσθήκη ομάδας",
     "Changing the password will result in data loss, because data recovery is not available for this user" : "Η αλλαγή του κωδικού πρόσβασης θα έχει ως αποτέλεσμα το χάσιμο δεδομένων, επειδή η ανάκτηση δεδομένων δεν είναι διαθέσιμη γι' αυτόν τον χρήστη",
     "A valid username must be provided" : "Πρέπει να δοθεί έγκυρο όνομα χρήστη",
-    "Error creating user" : "Σφάλμα δημιουργίας χρήστη",
     "A valid password must be provided" : "Πρέπει να δοθεί έγκυρο συνθηματικό",
     "A valid email must be provided" : "Πρέπει να εισαχθεί ένα έγκυρο email",
     "__language_name__" : "__όνομα_γλώσσας__",
-    "Sync clients" : "Συγχρονισμός πελατών",
     "Personal info" : "Προσωπικές Πληροφορίες",
-    "SSL root certificates" : "Πιστοποιητικά SSL root",
+    "Sync clients" : "Συγχρονισμός πελατών",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Όλα (καίρια ζητήματα, σφάλματα, προειδοποιήσεις, πληροφορίες, αποσφαλμάτωση)",
     "Info, warnings, errors and fatal issues" : "Πληροφορίες, προειδοποιήσεις, σφάλματα και καίρια ζητήματα",
     "Warnings, errors and fatal issues" : "Προειδοποιήσεις, σφάλματα και καίρια ζητήματα",
@@ -125,7 +124,6 @@ OC.L10N.register(
     "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "Ο PHP φαίνεται να είναι ρυθμισμένος ώστε να αφαιρεί μπλοκ εσωτερικών κειμένων (inline doc). Αυτό θα καταστήσει κύριες εφαρμογές μη-διαθέσιμες.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Αυτό πιθανόν προκλήθηκε από προσωρινή μνήμη (cache)/επιταχυντή όπως τη Zend OPcache ή τον eAccelerator.",
     "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "Ο διακομιστής σας τρέχει σε Microsoft Windows. Συστήνουμε ιδιαίτερα Linux για τη βέλτιστη εμπειρία του χρήστη.",
-    "%1$s below version %2$s is installed, for stability and performance reasons we recommend to update to a newer %1$s version." : "Είναι εγκατεστημένο το %1$s έκδοση %2$s, για λόγους σταθερότητας και απόδοσης συστήνουμε να αναβαθμίσετε σε νεότερη έκδοση του %1$s.",
     "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Η PHP ενοτητα 'fileinfo' λειπει. Σας συνιστούμε να ενεργοποιήσετε αυτή την ενότητα για να έχετε καλύτερα αποτελέσματα με τον εντοπισμό τύπου MIME. ",
     "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" href=\"%s\">documentation ↗</a> for more information." : "Το Transactional file locking είναι απενεργοποιημένο, αυτό μπορεί να οδηγήσει σε προβλήματα με τις race conditions. Ενεργοποιήστε το 'filelocking.enabled' στο config.php για να αποφύγετε αυτά τα προβλήματα. Δείτε την <a target=\"_blank\" href=\"%s\">τεκμηρίωση ↗</a> για περισσότερες πληροφορίες.",
     "System locale can not be set to a one which supports UTF-8." : "Οι ρυθμίσεις τοποθεσίας συστήματος δεν μπορούν να οριστούν σε κάποιες που δεν υποστηρίζουν UTF-8.",
@@ -133,7 +131,6 @@ OC.L10N.register(
     "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Προτείνουμε ανεπιφύλακτα να εγκαταστήσετε  στο σύστημά σας τα απαιτούμενα πακέτα έτσι ώστε να υποστηρίζεται μια από τις ακόλουθες ρυθμίσεις τοποθεσίας: %s.",
     "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Αν η εγκατάστασή σας δεν έχει γίνει στο root του τομέα  και χρησιμοποιείται το cron του συστήματος, μπορεί να υπάρξουν ζητήματα με τη δημιουργία URL. Για να αποφύγετε αυτά τα προβλήματα, παρακαλώ ρυθμίστε την επιλογή  \"overwrite.cli.url\" στο αρχείο  config.php που βρίσκεται στη διαδρομή webroot της εγκατάστασής σας (Suggested: \"%s\")",
     "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Δεν ήταν δυνατή η εκτέλεση της cronjob μέσω τερματικού. Εμφανίστηκαν τα παρακάτω τεχνικά σφάλματα:",
-    "Transactional file locking is using the database as locking backend, for best performance it's advised to configure a memcache for locking. See the <a target=\"_blank\" href=\"%s\">documentation ↗</a> for more information." : "Το Transactional file locking χρησιμοποιεί τη βάση δεδομένων ως locking backend, για καλύτερες επιδόσεις συστήνουμς τη διαμόρφωση μιας memcache για το κλείδωμα. Δείτε την <a target=\"_blank\" href=\"%s\">τεκμηρίωση ↗</a> για περισσότερες πληροφορίες.",
     "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Παρακαλώ ελέγξτε ξανά <a target=\"_blank\" href=\"%s\">τους οδηγούς εγκατάστασης,  καθώς επίσης και για τυχόν σφάλματα ή προειδοποιήσεις στο <a href=\"#log-section\">log</a>.",
     "All checks passed." : "Όλοι οι έλεγχοι επιτυχείς.",
     "Open documentation" : "Ανοιχτή τεκμηρίωση.",
@@ -160,6 +157,10 @@ OC.L10N.register(
     "Use system's cron service to call the cron.php file every 15 minutes." : "Χρησιμοποιήστε την cron υπηρεσία του συτήματος για να καλέσετε το cron.php αρχείο κάθε 15 λεπτά.",
     "Enable server-side encryption" : "Ενεργοποίηση κρυπτογράφησης από το διακομιστή",
     "Please read carefully before activating server-side encryption: " : "Παρακαλούμε διαβάστε προσεκτικά πριν ενεργοποιήσετε την κρυπτογράφηση στο διακομιστή:",
+    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Μόλις ενεργοποιηθεί η κρυπτογράφηση, όλα τα αρχεία που θα μεταφορτωθούν από αυτό το σημείο και μετά θα κρυπτογραφηθούν στο διακομιστή. Η κρυπτογράφηση είναι δυνατόν να απενεργοποιηθεί αργότερα μόνο αν το ενεργό άρθρωμα κρυπτογράφησης υποστηρίζει αυτή τη λειτουργία και εκπληρούνται όλες οι προϋποθέσεις (πχ ορισμός κλειδιού ανάκτησης).",
+    "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases." : "Η κρυπτογράφηση από΄μ9ονη της δεν εγγυάται την την ασφάλεια του συστήματος. Παρακαλούμε δείτε την τεκμηρίωση του ownCloud για περισσότερες πληροφορίες σχετικά με το πως δουλεύει η εφαρμογή κρυπτογράφησης και τις υποστηριζόμενες περιπτώσεις χρήσης.",
+    "Be aware that encryption always increases the file size." : "Έχετε στο νου σας πως η κρυπτογράφηση πάντα αυξάνει το μέγεθος του αρχείου",
+    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Είναι πάντοτε καλό να δημιουργείτε τακτικά αντίγραφα ασφαλείας των δεδομένων σας, στην περίπτωση της κρυπτογράφησης βεβαιωθείτε ότι έχετε λάβει αντίγραφο ασφαλείας των κλειδιών κρυπτογράφησης παράλληλα με τα δεδομένα σας.",
     "This is the final warning: Do you really want to enable encryption?" : "Αυτή είναι η τελευταία προειδοποίηση: Θέλετε πραγματικά να ενεργοποιήσετε την κρυπτογράφηση;",
     "Enable encryption" : "Ενεργοποίηση κρυπτογράφησης",
     "No encryption module loaded, please enable an encryption module in the app menu." : "Δεν έχει φορτωθεί μονάδα κρυπτογράφησης, παρακαλούμε φορτώστε μια μονάδα κρυπτογράφησης από το μενού εφαρμογών.",
@@ -182,7 +183,6 @@ OC.L10N.register(
     "Store credentials" : "Διαπιστευτήρια αποθήκευσης",
     "Test email settings" : "Δοκιμή ρυθμίσεων email",
     "Send email" : "Αποστολή email",
-    "Log level" : "Επίπεδο καταγραφής",
     "Download logfile" : "Λήψη αρχείου ιστορικού",
     "More" : "Περισσότερα",
     "Less" : "Λιγότερα",
@@ -200,8 +200,6 @@ OC.L10N.register(
     "Developer documentation" : "Τεκμηρίωση προγραμματιστή",
     "Experimental applications ahead" : "Πειραματικές εφαρμογές",
     "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches." : "Οι πειραματικές εφαρμογές δεν ελέγχονται για θέματα ασφάλειας, είναι ασταθείς και υπό συνεχή εξέλιξη.  Η εγκατάσταση τους μπορεί να προκαλέσει απώλεια δεδομένων ή παραβιάσεις της ασφάλειας.",
-    "by" : "από",
-    "licensed" : "Άδεια",
     "Documentation:" : "Τεκμηρίωση:",
     "User documentation" : "Τεκμηρίωση Χρήστη",
     "Admin documentation" : "Τεκμηρίωση Διαχειριστή",
@@ -211,7 +209,11 @@ OC.L10N.register(
     "Enable only for specific groups" : "Ενεργοποίηση μόνο για καθορισμένες ομάδες",
     "Uninstall App" : "Απεγκατάσταση Εφαρμογής",
     "Enable experimental apps" : "Ενεργοποίηση πειραματικών εφαρμογών",
-    "No apps found for your version" : "Δεν βρέθηκαν εφαρμογές για αυτή την έκδοση",
+    "Common Name" : "Κοινό Όνομα",
+    "Valid until" : "Έγκυρο έως",
+    "Issued By" : "Έκδόθηκε από",
+    "Valid until %s" : "Έγκυρο έως %s",
+    "Import root certificate" : "Εισαγωγή Πιστοποιητικού Root",
     "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Χαίρεται,<br><br>απλά σας κάνουμε γνωστό ότι διαθέτετε έναν %s λογαριασμό.<br><br>Το όνομά σας είναι: %s<br>Έχετε πρόσβαση: <a href=\"%s\">%s</a><br><br>",
     "Cheers!" : "Χαιρετισμούς!",
     "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Χαίρεται, \nαπλά σας κάνουμε γνωστό ότι διαθέτετε έναν %s λογαριασμό.\nΤο όνομά σας είναι: %s\nΈχετε πρόσβαση: %s\n",
@@ -220,40 +222,29 @@ OC.L10N.register(
     "Forum" : "Φόρουμ",
     "Issue tracker" : "Ιχνηλάτης ζητημάτων",
     "Commercial support" : "Εμπορική Υποστήριξη",
+    "Profile picture" : "Φωτογραφία προφίλ",
+    "Upload new" : "Μεταφόρτωση νέου",
+    "Remove image" : "Αφαίρεση εικόνας",
+    "Cancel" : "Άκυρο",
+    "Full name" : "Πλήρες όνομα",
+    "No display name set" : "Δεν ορίστηκε όνομα",
+    "Email" : "Ηλεκτρονικό ταχυδρομείο",
+    "Your email address" : "Η διεύθυνση ηλ. ταχυδρομείου σας",
+    "No email address set" : "Δεν ορίστηκε διεύθυνση email",
+    "You are member of the following groups:" : "Είστε μέλος των ακόλουθων ομάδων:",
+    "Password" : "Συνθηματικό",
+    "Unable to change your password" : "Δεν ήταν δυνατή η αλλαγή του κωδικού πρόσβασης",
+    "Current password" : "Τρέχων συνθηματικό",
+    "New password" : "Νέο συνθηματικό",
+    "Change password" : "Αλλαγή συνθηματικού",
+    "Language" : "Γλώσσα",
+    "Help translate" : "Βοηθήστε στη μετάφραση",
     "Get the apps to sync your files" : "Λήψη της εφαρμογής για συγχρονισμό των αρχείων σας",
     "Desktop client" : "Πελάτης σταθερού υπολογιστή",
     "Android app" : "Εφαρμογή Android",
     "iOS app" : "Εφαρμογή iOS",
     "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Εάν θέλετε να υποστηρίξετε το έργο\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">συμμετέχετε στην ανάπτυξη</a>\n\t\tή\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">διαδόστε το μήνυμα</a>!",
     "Show First Run Wizard again" : "Προβολή Οδηγού Πρώτης Εκτέλεσης ξανά",
-    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "Χρησιμοποιήσατε <strong>%s</strong> από τα <strong>%s</strong> διαθέσιμα",
-    "Password" : "Συνθηματικό",
-    "Unable to change your password" : "Δεν ήταν δυνατή η αλλαγή του κωδικού πρόσβασης",
-    "Current password" : "Τρέχων συνθηματικό",
-    "New password" : "Νέο συνθηματικό",
-    "Change password" : "Αλλαγή συνθηματικού",
-    "Full name" : "Πλήρες όνομα",
-    "No display name set" : "Δεν ορίστηκε όνομα",
-    "Email" : "Ηλεκτρονικό ταχυδρομείο",
-    "Your email address" : "Η διεύθυνση ηλ. ταχυδρομείου σας",
-    "Fill in an email address to enable password recovery and receive notifications" : "Συμπληρώστε μια διεύθυνση email για να ενεργοποιήσετε την επαναφορά συνθηματικού και να λαμβάνετε ειδοποιήσεις",
-    "No email address set" : "Δεν ορίστηκε διεύθυνση email",
-    "You are member of the following groups:" : "Είστε μέλος των ακόλουθων ομάδων:",
-    "Profile picture" : "Φωτογραφία προφίλ",
-    "Upload new" : "Μεταφόρτωση νέου",
-    "Select new from Files" : "Επιλογή νέου από τα Αρχεία",
-    "Remove image" : "Αφαίρεση εικόνας",
-    "Either png or jpg. Ideally square but you will be able to crop it. The file is not allowed to exceed the maximum size of 20 MB." : "Είτε png ή jpg. Ιδανικά τετράγωνη αλλά θα είστε σε θέση να την περικόψετε. Το αρχείο δεν θα πρέπει να υπερβαίνει το μέγιστο μέγεθος των 20 MB.",
-    "Your avatar is provided by your original account." : "Το άβατάρ σας παρέχεται από τον αρχικό σας λογαριασμό.",
-    "Cancel" : "Άκυρο",
-    "Choose as profile image" : "Επιλογή εικόνας προφίλ",
-    "Language" : "Γλώσσα",
-    "Help translate" : "Βοηθήστε στη μετάφραση",
-    "Common Name" : "Κοινό Όνομα",
-    "Valid until" : "Έγκυρο έως",
-    "Issued By" : "Έκδόθηκε από",
-    "Valid until %s" : "Έγκυρο έως %s",
-    "Import root certificate" : "Εισαγωγή Πιστοποιητικού Root",
     "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Αναπτύχθηκε από την {communityopen}  κοινότητα του  ownCloud {linkclose}, ο {githubopen}  πηγαίος κώδικας {linkclose} έχει την άδεια της {licenseopen} <abbr title = \"Affero General Public License\"> AGPL </ abbr> {linkclose}.",
     "Show storage location" : "Εμφάνιση τοποθεσίας αποθήκευσης",
     "Show last log in" : "Εμφάνιση τελευταίας εισόδου",
